CacheLevelIdRegister

Struct CacheLevelIdRegister 

pub struct CacheLevelIdRegister(/* private fields */);
The layout of CLIDR_EL1.

Implementations

Source

impl CacheLevelIdRegister

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const TTYPE7_MASK: u64

Unshifted bitmask of ttype7.

pub const TTYPE7_SHIFT: usize = 45

Bit shift (i.e., the low bit) of ttype7.

pub const TTYPE6_MASK: u64

Unshifted bitmask of ttype6.

pub const TTYPE6_SHIFT: usize = 43

Bit shift (i.e., the low bit) of ttype6.

pub const TTYPE5_MASK: u64

Unshifted bitmask of ttype5.

pub const TTYPE5_SHIFT: usize = 41

Bit shift (i.e., the low bit) of ttype5.

pub const TTYPE4_MASK: u64

Unshifted bitmask of ttype4.

pub const TTYPE4_SHIFT: usize = 39

Bit shift (i.e., the low bit) of ttype4.

pub const TTYPE3_MASK: u64

Unshifted bitmask of ttype3.

pub const TTYPE3_SHIFT: usize = 37

Bit shift (i.e., the low bit) of ttype3.

pub const TTYPE2_MASK: u64

Unshifted bitmask of ttype2.

pub const TTYPE2_SHIFT: usize = 35

Bit shift (i.e., the low bit) of ttype2.

pub const TTYPE1_MASK: u64

Unshifted bitmask of ttype1.

pub const TTYPE1_SHIFT: usize = 33

Bit shift (i.e., the low bit) of ttype1.

pub const ICB_MASK: u64

Unshifted bitmask of icb.

pub const ICB_SHIFT: usize = 30

Bit shift (i.e., the low bit) of icb.

pub const LOU_U_MASK: u64

Unshifted bitmask of lou_u.

pub const LOU_U_SHIFT: usize = 27

Bit shift (i.e., the low bit) of lou_u.

pub const LOC_MASK: u64

Unshifted bitmask of loc.

pub const LOC_SHIFT: usize = 24

Bit shift (i.e., the low bit) of loc.

pub const LOU_IS_MASK: u64

Unshifted bitmask of lou_is.

pub const LOU_IS_SHIFT: usize = 21

Bit shift (i.e., the low bit) of lou_is.

pub const CTYPE7_MASK: u64

Unshifted bitmask of ctype7.

pub const CTYPE7_SHIFT: usize = 18

Bit shift (i.e., the low bit) of ctype7.

pub const CTYPE6_MASK: u64

Unshifted bitmask of ctype6.

pub const CTYPE6_SHIFT: usize = 15

Bit shift (i.e., the low bit) of ctype6.

pub const CTYPE5_MASK: u64

Unshifted bitmask of ctype5.

pub const CTYPE5_SHIFT: usize = 12

Bit shift (i.e., the low bit) of ctype5.

pub const CTYPE4_MASK: u64

Unshifted bitmask of ctype4.

pub const CTYPE4_SHIFT: usize = 9

Bit shift (i.e., the low bit) of ctype4.

pub const CTYPE3_MASK: u64

Unshifted bitmask of ctype3.

pub const CTYPE3_SHIFT: usize = 6

Bit shift (i.e., the low bit) of ctype3.

pub const CTYPE2_MASK: u64

Unshifted bitmask of ctype2.

pub const CTYPE2_SHIFT: usize = 3

Bit shift (i.e., the low bit) of ctype2.

pub const CTYPE1_MASK: u64

Unshifted bitmask of ctype1.

pub const CTYPE1_SHIFT: usize = 0

Bit shift (i.e., the low bit) of ctype1.

pub const FIELDS: [FieldMetadata<u64>; 18]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub fn ttype7(&self) -> TagCacheType

The value of CacheLevelIdRegister[46:45].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ttype7 to recover from invalid bit patterns.

pub fn try_ttype7(&self) -> Result<TagCacheType, InvalidBits<u8>>

Fallible variant of Self::ttype7.

pub fn set_ttype7(&mut self, value: TagCacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[46:45].

pub fn ttype6(&self) -> TagCacheType

The value of CacheLevelIdRegister[44:43].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ttype6 to recover from invalid bit patterns.

pub fn try_ttype6(&self) -> Result<TagCacheType, InvalidBits<u8>>

Fallible variant of Self::ttype6.

pub fn set_ttype6(&mut self, value: TagCacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[44:43].

pub fn ttype5(&self) -> TagCacheType

The value of CacheLevelIdRegister[42:41].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ttype5 to recover from invalid bit patterns.

pub fn try_ttype5(&self) -> Result<TagCacheType, InvalidBits<u8>>

Fallible variant of Self::ttype5.

pub fn set_ttype5(&mut self, value: TagCacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[42:41].

pub fn ttype4(&self) -> TagCacheType

The value of CacheLevelIdRegister[40:39].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ttype4 to recover from invalid bit patterns.

pub fn try_ttype4(&self) -> Result<TagCacheType, InvalidBits<u8>>

Fallible variant of Self::ttype4.

pub fn set_ttype4(&mut self, value: TagCacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[40:39].

pub fn ttype3(&self) -> TagCacheType

The value of CacheLevelIdRegister[38:37].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ttype3 to recover from invalid bit patterns.

pub fn try_ttype3(&self) -> Result<TagCacheType, InvalidBits<u8>>

Fallible variant of Self::ttype3.

pub fn set_ttype3(&mut self, value: TagCacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[38:37].

pub fn ttype2(&self) -> TagCacheType

The value of CacheLevelIdRegister[36:35].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ttype2 to recover from invalid bit patterns.

pub fn try_ttype2(&self) -> Result<TagCacheType, InvalidBits<u8>>

Fallible variant of Self::ttype2.

pub fn set_ttype2(&mut self, value: TagCacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[36:35].

pub fn ttype1(&self) -> TagCacheType

The value of CacheLevelIdRegister[34:33].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ttype1 to recover from invalid bit patterns.

pub fn try_ttype1(&self) -> Result<TagCacheType, InvalidBits<u8>>

Fallible variant of Self::ttype1.

pub fn set_ttype1(&mut self, value: TagCacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[34:33].

pub const fn icb(&self) -> u8

The value of CacheLevelIdRegister[32:30].

pub const fn set_icb(&mut self, value: u8) -> &mut Self

Sets the value of CacheLevelIdRegister[32:30].

pub const fn lou_u(&self) -> u8

The value of CacheLevelIdRegister[29:27].

pub const fn set_lou_u(&mut self, value: u8) -> &mut Self

Sets the value of CacheLevelIdRegister[29:27].

pub const fn loc(&self) -> u8

The value of CacheLevelIdRegister[26:24].

pub const fn set_loc(&mut self, value: u8) -> &mut Self

Sets the value of CacheLevelIdRegister[26:24].

pub const fn lou_is(&self) -> u8

The value of CacheLevelIdRegister[23:21].

pub const fn set_lou_is(&mut self, value: u8) -> &mut Self

Sets the value of CacheLevelIdRegister[23:21].

pub fn ctype7(&self) -> CacheType

The value of CacheLevelIdRegister[20:18].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ctype7 to recover from invalid bit patterns.

pub fn try_ctype7(&self) -> Result<CacheType, InvalidBits<u8>>

Fallible variant of Self::ctype7.

pub fn set_ctype7(&mut self, value: CacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[20:18].

pub fn ctype6(&self) -> CacheType

The value of CacheLevelIdRegister[17:15].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ctype6 to recover from invalid bit patterns.

pub fn try_ctype6(&self) -> Result<CacheType, InvalidBits<u8>>

Fallible variant of Self::ctype6.

pub fn set_ctype6(&mut self, value: CacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[17:15].

pub fn ctype5(&self) -> CacheType

The value of CacheLevelIdRegister[14:12].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ctype5 to recover from invalid bit patterns.

pub fn try_ctype5(&self) -> Result<CacheType, InvalidBits<u8>>

Fallible variant of Self::ctype5.

pub fn set_ctype5(&mut self, value: CacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[14:12].

pub fn ctype4(&self) -> CacheType

The value of CacheLevelIdRegister[11:9].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ctype4 to recover from invalid bit patterns.

pub fn try_ctype4(&self) -> Result<CacheType, InvalidBits<u8>>

Fallible variant of Self::ctype4.

pub fn set_ctype4(&mut self, value: CacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[11:9].

pub fn ctype3(&self) -> CacheType

The value of CacheLevelIdRegister[8:6].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ctype3 to recover from invalid bit patterns.

pub fn try_ctype3(&self) -> Result<CacheType, InvalidBits<u8>>

Fallible variant of Self::ctype3.

pub fn set_ctype3(&mut self, value: CacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[8:6].

pub fn ctype2(&self) -> CacheType

The value of CacheLevelIdRegister[5:3].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ctype2 to recover from invalid bit patterns.

pub fn try_ctype2(&self) -> Result<CacheType, InvalidBits<u8>>

Fallible variant of Self::ctype2.

pub fn set_ctype2(&mut self, value: CacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[5:3].

pub fn ctype1(&self) -> CacheType

The value of CacheLevelIdRegister[2:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ctype1 to recover from invalid bit patterns.

pub fn try_ctype1(&self) -> Result<CacheType, InvalidBits<u8>>

Fallible variant of Self::ctype1.

pub fn set_ctype1(&mut self, value: CacheType) -> &mut Self

Sets the value of CacheLevelIdRegister[2:0].

Source

impl CacheLevelIdRegister

pub fn iter(&self) -> CacheLevelIdRegisterIter

Returns an iterator over (metadata, value) pairs for each field.

Source

impl CacheLevelIdRegister

pub const MAX_LEVELS: usize = 7

The number of cache levels described by the register.

pub fn cache_type(&self, level: usize) -> CacheType

Returns the type of cache at level, which is zero-based (L1 is level 0) to match the level field of CacheSizeSelectionRegister.

Panics if level is not below Self::MAX_LEVELS or the field holds a reserved value.

pub fn tag_cache_type(&self, level: usize) -> TagCacheType

Returns the type of allocation tag cache at level, which is zero-based (L1 is level 0).

Panics if level is not below Self::MAX_LEVELS.