CacheSizeIdRegisterCcidx

Struct CacheSizeIdRegisterCcidx 

pub struct CacheSizeIdRegisterCcidx(/* private fields */);
The layout of CCSIDR_EL1_CCIDX.

Implementations

Source

impl CacheSizeIdRegisterCcidx

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const NUM_SETS_MASK: u64

Unshifted bitmask of num_sets.

pub const NUM_SETS_SHIFT: usize = 32

Bit shift (i.e., the low bit) of num_sets.

pub const ASSOCIATIVITY_MASK: u64

Unshifted bitmask of associativity.

pub const ASSOCIATIVITY_SHIFT: usize = 3

Bit shift (i.e., the low bit) of associativity.

pub const LINE_SIZE_MASK: u64

Unshifted bitmask of line_size.

pub const LINE_SIZE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of line_size.

pub const FIELDS: [FieldMetadata<u64>; 3]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn num_sets(&self) -> u32

The value of CacheSizeIdRegisterCcidx[55:32].

pub const fn set_num_sets(&mut self, value: u32) -> &mut Self

Sets the value of CacheSizeIdRegisterCcidx[55:32].

pub const fn associativity(&self) -> u32

The value of CacheSizeIdRegisterCcidx[23:3].

pub const fn set_associativity(&mut self, value: u32) -> &mut Self

Sets the value of CacheSizeIdRegisterCcidx[23:3].

pub const fn line_size(&self) -> u8

log2 of the number of words in a cache line, minus 2. The value of CacheSizeIdRegisterCcidx[2:0].

pub const fn set_line_size(&mut self, value: u8) -> &mut Self

Sets the value of CacheSizeIdRegisterCcidx[2:0].

Source

impl CacheSizeIdRegisterCcidx

pub fn iter(&self) -> CacheSizeIdRegisterCcidxIter

Returns an iterator over (metadata, value) pairs for each field.

Source

impl CacheSizeIdRegisterCcidx

pub const fn sets(&self) -> u32

Returns the number of sets.

pub const fn ways(&self) -> u32

Returns the associativity (number of ways).

pub const fn line_size_bytes(&self) -> usize

Returns the cache line size in bytes.