CacheSizeSelectionRegister

Struct CacheSizeSelectionRegister 

pub struct CacheSizeSelectionRegister(/* private fields */);
The layout of CSSELR_EL1.

Implementations

Source

impl CacheSizeSelectionRegister

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const TND_MASK: u64

Unshifted bitmask of tnd.

pub const TND_SHIFT: usize = 4

Bit shift (i.e., the low bit) of tnd.

pub const LEVEL_MASK: u64

Unshifted bitmask of level.

pub const LEVEL_SHIFT: usize = 1

Bit shift (i.e., the low bit) of level.

pub const IND_MASK: u64

Unshifted bitmask of ind.

pub const IND_SHIFT: usize = 0

Bit shift (i.e., the low bit) of ind.

pub const FIELDS: [FieldMetadata<u64>; 3]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn tnd(&self) -> bool

The value of CacheSizeSelectionRegister4.

pub const fn set_tnd(&mut self, value: bool) -> &mut Self

Sets the value of CacheSizeSelectionRegister4.

pub const fn level(&self) -> u8

The value of CacheSizeSelectionRegister[3:1].

pub const fn set_level(&mut self, value: u8) -> &mut Self

Sets the value of CacheSizeSelectionRegister[3:1].

pub const fn ind(&self) -> bool

The value of CacheSizeSelectionRegister0.

pub const fn set_ind(&mut self, value: bool) -> &mut Self

Sets the value of CacheSizeSelectionRegister0.

Source

impl CacheSizeSelectionRegister

pub fn iter(&self) -> CacheSizeSelectionRegisterIter

Returns an iterator over (metadata, value) pairs for each field.

Source

impl CacheSizeSelectionRegister

pub fn select(level: u8, instruction: bool) -> Self

Returns a value selecting the instruction or data cache at level, which is zero-based (L1 is level 0).