CacheTypeRegister

Struct CacheTypeRegister 

pub struct CacheTypeRegister(/* private fields */);
The layout of CTR_EL0.

Implementations

Source

impl CacheTypeRegister

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const TMIN_LINE_MASK: u64

Unshifted bitmask of tmin_line.

pub const TMIN_LINE_SHIFT: usize = 32

Bit shift (i.e., the low bit) of tmin_line.

pub const DIC_MASK: u64

Unshifted bitmask of dic.

pub const DIC_SHIFT: usize = 29

Bit shift (i.e., the low bit) of dic.

pub const IDC_MASK: u64

Unshifted bitmask of idc.

pub const IDC_SHIFT: usize = 28

Bit shift (i.e., the low bit) of idc.

pub const CWG_MASK: u64

Unshifted bitmask of cwg.

pub const CWG_SHIFT: usize = 24

Bit shift (i.e., the low bit) of cwg.

pub const ERG_MASK: u64

Unshifted bitmask of erg.

pub const ERG_SHIFT: usize = 20

Bit shift (i.e., the low bit) of erg.

pub const DMIN_LINE_MASK: u64

Unshifted bitmask of dmin_line.

pub const DMIN_LINE_SHIFT: usize = 16

Bit shift (i.e., the low bit) of dmin_line.

pub const L1_IP_MASK: u64

Unshifted bitmask of l1_ip.

pub const L1_IP_SHIFT: usize = 14

Bit shift (i.e., the low bit) of l1_ip.

pub const IMIN_LINE_MASK: u64

Unshifted bitmask of imin_line.

pub const IMIN_LINE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of imin_line.

pub const FIELDS: [FieldMetadata<u64>; 8]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn tmin_line(&self) -> u8

The value of CacheTypeRegister[37:32].

pub const fn set_tmin_line(&mut self, value: u8) -> &mut Self

Sets the value of CacheTypeRegister[37:32].

pub const fn dic(&self) -> bool

The value of CacheTypeRegister29.

pub const fn set_dic(&mut self, value: bool) -> &mut Self

Sets the value of CacheTypeRegister29.

pub const fn idc(&self) -> bool

The value of CacheTypeRegister28.

pub const fn set_idc(&mut self, value: bool) -> &mut Self

Sets the value of CacheTypeRegister28.

pub const fn cwg(&self) -> u8

The value of CacheTypeRegister[27:24].

pub const fn set_cwg(&mut self, value: u8) -> &mut Self

Sets the value of CacheTypeRegister[27:24].

pub const fn erg(&self) -> u8

The value of CacheTypeRegister[23:20].

pub const fn set_erg(&mut self, value: u8) -> &mut Self

Sets the value of CacheTypeRegister[23:20].

pub const fn dmin_line(&self) -> u8

log2 of the number of words in the smallest data cache line. The value of CacheTypeRegister[19:16].

pub const fn set_dmin_line(&mut self, value: u8) -> &mut Self

Sets the value of CacheTypeRegister[19:16].

pub fn l1_ip(&self) -> L1ICachePolicy

The value of CacheTypeRegister[15:14].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_l1_ip to recover from invalid bit patterns.

pub fn try_l1_ip(&self) -> Result<L1ICachePolicy, InvalidBits<u8>>

Fallible variant of Self::l1_ip.

pub fn set_l1_ip(&mut self, value: L1ICachePolicy) -> &mut Self

Sets the value of CacheTypeRegister[15:14].

pub const fn imin_line(&self) -> u8

log2 of the number of words in the smallest instruction cache line. The value of CacheTypeRegister[3:0].

pub const fn set_imin_line(&mut self, value: u8) -> &mut Self

Sets the value of CacheTypeRegister[3:0].

Source

impl CacheTypeRegister

pub fn iter(&self) -> CacheTypeRegisterIter

Returns an iterator over (metadata, value) pairs for each field.

Source

impl CacheTypeRegister

pub const fn dcache_line_size(&self) -> usize

Returns the smallest data cache line size in bytes.

pub const fn icache_line_size(&self) -> usize

Returns the smallest instruction cache line size in bytes.