ExceptionSyndromeRegister

Struct ExceptionSyndromeRegister 

pub struct ExceptionSyndromeRegister(/* private fields */);
The layout of ESR_EL1, ESR_EL2, and ESR_EL3.

These are the assignments when an exception is taken from AArch64 state.

Implementations

Source

impl ExceptionSyndromeRegister

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const ISS2_MASK: u64

Unshifted bitmask of iss2.

pub const ISS2_SHIFT: usize = 32

Bit shift (i.e., the low bit) of iss2.

pub const EC_MASK: u64

Unshifted bitmask of ec.

pub const EC_SHIFT: usize = 26

Bit shift (i.e., the low bit) of ec.

pub const IL_MASK: u64

Unshifted bitmask of il.

pub const IL_SHIFT: usize = 25

Bit shift (i.e., the low bit) of il.

pub const ISS_MASK: u64

Unshifted bitmask of iss.

pub const ISS_SHIFT: usize = 0

Bit shift (i.e., the low bit) of iss.

pub const FIELDS: [FieldMetadata<u64>; 4]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn iss2(&self) -> u32

The value of ExceptionSyndromeRegister[55:32].

pub const fn set_iss2(&mut self, value: u32) -> &mut Self

Sets the value of ExceptionSyndromeRegister[55:32].

pub fn ec(&self) -> ExceptionClass

The value of ExceptionSyndromeRegister[31:26].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ec to recover from invalid bit patterns.

pub fn try_ec(&self) -> Result<ExceptionClass, InvalidBits<u8>>

Fallible variant of Self::ec.

pub fn set_ec(&mut self, value: ExceptionClass) -> &mut Self

Sets the value of ExceptionSyndromeRegister[31:26].

pub const fn il(&self) -> bool

The value of ExceptionSyndromeRegister25.

pub const fn set_il(&mut self, value: bool) -> &mut Self

Sets the value of ExceptionSyndromeRegister25.

pub const fn iss(&self) -> u32

The value of ExceptionSyndromeRegister[24:0].

pub const fn set_iss(&mut self, value: u32) -> &mut Self

Sets the value of ExceptionSyndromeRegister[24:0].

Source

impl ExceptionSyndromeRegister

pub fn iter(&self) -> ExceptionSyndromeRegisterIter

Returns an iterator over (metadata, value) pairs for each field.