InstructionSetAttributeRegister0

Struct InstructionSetAttributeRegister0 

pub struct InstructionSetAttributeRegister0(/* private fields */);
The layout of ID_AA64ISAR0_EL1.

Implementations

Source

impl InstructionSetAttributeRegister0

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const RNDR_MASK: u64

Unshifted bitmask of rndr.

pub const RNDR_SHIFT: usize = 60

Bit shift (i.e., the low bit) of rndr.

pub const TLB_MASK: u64

Unshifted bitmask of tlb.

pub const TLB_SHIFT: usize = 56

Bit shift (i.e., the low bit) of tlb.

pub const TS_MASK: u64

Unshifted bitmask of ts.

pub const TS_SHIFT: usize = 52

Bit shift (i.e., the low bit) of ts.

pub const FHM_MASK: u64

Unshifted bitmask of fhm.

pub const FHM_SHIFT: usize = 48

Bit shift (i.e., the low bit) of fhm.

pub const DP_MASK: u64

Unshifted bitmask of dp.

pub const DP_SHIFT: usize = 44

Bit shift (i.e., the low bit) of dp.

pub const SM4_MASK: u64

Unshifted bitmask of sm4.

pub const SM4_SHIFT: usize = 40

Bit shift (i.e., the low bit) of sm4.

pub const SM3_MASK: u64

Unshifted bitmask of sm3.

pub const SM3_SHIFT: usize = 36

Bit shift (i.e., the low bit) of sm3.

pub const SHA3_MASK: u64

Unshifted bitmask of sha3.

pub const SHA3_SHIFT: usize = 32

Bit shift (i.e., the low bit) of sha3.

pub const RDM_MASK: u64

Unshifted bitmask of rdm.

pub const RDM_SHIFT: usize = 28

Bit shift (i.e., the low bit) of rdm.

pub const ATOMIC_MASK: u64

Unshifted bitmask of atomic.

pub const ATOMIC_SHIFT: usize = 20

Bit shift (i.e., the low bit) of atomic.

pub const CRC32_MASK: u64

Unshifted bitmask of crc32.

pub const CRC32_SHIFT: usize = 16

Bit shift (i.e., the low bit) of crc32.

pub const SHA2_MASK: u64

Unshifted bitmask of sha2.

pub const SHA2_SHIFT: usize = 12

Bit shift (i.e., the low bit) of sha2.

pub const SHA1_MASK: u64

Unshifted bitmask of sha1.

pub const SHA1_SHIFT: usize = 8

Bit shift (i.e., the low bit) of sha1.

pub const AES_MASK: u64

Unshifted bitmask of aes.

pub const AES_SHIFT: usize = 4

Bit shift (i.e., the low bit) of aes.

pub const FIELDS: [FieldMetadata<u64>; 14]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub fn rndr(&self) -> IdAa64IsaR0Rndr

The value of InstructionSetAttributeRegister0[63:60].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_rndr to recover from invalid bit patterns.

pub fn try_rndr(&self) -> Result<IdAa64IsaR0Rndr, InvalidBits<u8>>

Fallible variant of Self::rndr.

pub fn set_rndr(&mut self, value: IdAa64IsaR0Rndr) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[63:60].

pub fn tlb(&self) -> IdAa64IsaR0Tlb

The value of InstructionSetAttributeRegister0[59:56].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tlb to recover from invalid bit patterns.

pub fn try_tlb(&self) -> Result<IdAa64IsaR0Tlb, InvalidBits<u8>>

Fallible variant of Self::tlb.

pub fn set_tlb(&mut self, value: IdAa64IsaR0Tlb) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[59:56].

pub fn ts(&self) -> IdAa64IsaR0Ts

The value of InstructionSetAttributeRegister0[55:52].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ts to recover from invalid bit patterns.

pub fn try_ts(&self) -> Result<IdAa64IsaR0Ts, InvalidBits<u8>>

Fallible variant of Self::ts.

pub fn set_ts(&mut self, value: IdAa64IsaR0Ts) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[55:52].

pub fn fhm(&self) -> IdAa64IsaR0Fhm

The value of InstructionSetAttributeRegister0[51:48].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_fhm to recover from invalid bit patterns.

pub fn try_fhm(&self) -> Result<IdAa64IsaR0Fhm, InvalidBits<u8>>

Fallible variant of Self::fhm.

pub fn set_fhm(&mut self, value: IdAa64IsaR0Fhm) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[51:48].

pub fn dp(&self) -> IdAa64IsaR0DotProd

The value of InstructionSetAttributeRegister0[47:44].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_dp to recover from invalid bit patterns.

pub fn try_dp(&self) -> Result<IdAa64IsaR0DotProd, InvalidBits<u8>>

Fallible variant of Self::dp.

pub fn set_dp(&mut self, value: IdAa64IsaR0DotProd) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[47:44].

pub fn sm4(&self) -> IdAa64IsaR0Sm4

The value of InstructionSetAttributeRegister0[43:40].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sm4 to recover from invalid bit patterns.

pub fn try_sm4(&self) -> Result<IdAa64IsaR0Sm4, InvalidBits<u8>>

Fallible variant of Self::sm4.

pub fn set_sm4(&mut self, value: IdAa64IsaR0Sm4) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[43:40].

pub fn sm3(&self) -> IdAa64IsaR0Sm3

The value of InstructionSetAttributeRegister0[39:36].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sm3 to recover from invalid bit patterns.

pub fn try_sm3(&self) -> Result<IdAa64IsaR0Sm3, InvalidBits<u8>>

Fallible variant of Self::sm3.

pub fn set_sm3(&mut self, value: IdAa64IsaR0Sm3) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[39:36].

pub fn sha3(&self) -> IdAa64IsaR0Sha3

The value of InstructionSetAttributeRegister0[35:32].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sha3 to recover from invalid bit patterns.

pub fn try_sha3(&self) -> Result<IdAa64IsaR0Sha3, InvalidBits<u8>>

Fallible variant of Self::sha3.

pub fn set_sha3(&mut self, value: IdAa64IsaR0Sha3) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[35:32].

pub fn rdm(&self) -> IdAa64IsaR0Rdm

The value of InstructionSetAttributeRegister0[31:28].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_rdm to recover from invalid bit patterns.

pub fn try_rdm(&self) -> Result<IdAa64IsaR0Rdm, InvalidBits<u8>>

Fallible variant of Self::rdm.

pub fn set_rdm(&mut self, value: IdAa64IsaR0Rdm) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[31:28].

pub fn atomic(&self) -> IdAa64IsaR0Atomic

The value of InstructionSetAttributeRegister0[23:20].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_atomic to recover from invalid bit patterns.

pub fn try_atomic(&self) -> Result<IdAa64IsaR0Atomic, InvalidBits<u8>>

Fallible variant of Self::atomic.

pub fn set_atomic(&mut self, value: IdAa64IsaR0Atomic) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[23:20].

pub fn crc32(&self) -> IdAa64IsaR0Crc32

The value of InstructionSetAttributeRegister0[19:16].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_crc32 to recover from invalid bit patterns.

pub fn try_crc32(&self) -> Result<IdAa64IsaR0Crc32, InvalidBits<u8>>

Fallible variant of Self::crc32.

pub fn set_crc32(&mut self, value: IdAa64IsaR0Crc32) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[19:16].

pub fn sha2(&self) -> IdAa64IsaR0Sha2

The value of InstructionSetAttributeRegister0[15:12].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sha2 to recover from invalid bit patterns.

pub fn try_sha2(&self) -> Result<IdAa64IsaR0Sha2, InvalidBits<u8>>

Fallible variant of Self::sha2.

pub fn set_sha2(&mut self, value: IdAa64IsaR0Sha2) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[15:12].

pub fn sha1(&self) -> IdAa64IsaR0Sha1

The value of InstructionSetAttributeRegister0[11:8].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sha1 to recover from invalid bit patterns.

pub fn try_sha1(&self) -> Result<IdAa64IsaR0Sha1, InvalidBits<u8>>

Fallible variant of Self::sha1.

pub fn set_sha1(&mut self, value: IdAa64IsaR0Sha1) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[11:8].

pub fn aes(&self) -> IdAa64IsaR0Aes

The value of InstructionSetAttributeRegister0[7:4].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_aes to recover from invalid bit patterns.

pub fn try_aes(&self) -> Result<IdAa64IsaR0Aes, InvalidBits<u8>>

Fallible variant of Self::aes.

pub fn set_aes(&mut self, value: IdAa64IsaR0Aes) -> &mut Self

Sets the value of InstructionSetAttributeRegister0[7:4].

Source

impl InstructionSetAttributeRegister0

pub fn iter(&self) -> InstructionSetAttributeRegister0Iter

Returns an iterator over (metadata, value) pairs for each field.