InstructionSetAttributeRegister1

Struct InstructionSetAttributeRegister1 

pub struct InstructionSetAttributeRegister1(/* private fields */);
The layout of ID_AA64ISAR1_EL1.

Implementations

Source

impl InstructionSetAttributeRegister1

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const LS64_MASK: u64

Unshifted bitmask of ls64.

pub const LS64_SHIFT: usize = 60

Bit shift (i.e., the low bit) of ls64.

pub const XS_MASK: u64

Unshifted bitmask of xs.

pub const XS_SHIFT: usize = 56

Bit shift (i.e., the low bit) of xs.

pub const I8MM_MASK: u64

Unshifted bitmask of i8mm.

pub const I8MM_SHIFT: usize = 52

Bit shift (i.e., the low bit) of i8mm.

pub const DGH_MASK: u64

Unshifted bitmask of dgh.

pub const DGH_SHIFT: usize = 48

Bit shift (i.e., the low bit) of dgh.

pub const BF16_MASK: u64

Unshifted bitmask of bf16.

pub const BF16_SHIFT: usize = 44

Bit shift (i.e., the low bit) of bf16.

pub const SPECRES_MASK: u64

Unshifted bitmask of specres.

pub const SPECRES_SHIFT: usize = 40

Bit shift (i.e., the low bit) of specres.

pub const SB_MASK: u64

Unshifted bitmask of sb.

pub const SB_SHIFT: usize = 36

Bit shift (i.e., the low bit) of sb.

pub const FRINTTS_MASK: u64

Unshifted bitmask of frintts.

pub const FRINTTS_SHIFT: usize = 32

Bit shift (i.e., the low bit) of frintts.

pub const GPI_MASK: u64

Unshifted bitmask of gpi.

pub const GPI_SHIFT: usize = 28

Bit shift (i.e., the low bit) of gpi.

pub const GPA_MASK: u64

Unshifted bitmask of gpa.

pub const GPA_SHIFT: usize = 24

Bit shift (i.e., the low bit) of gpa.

pub const LRCPC_MASK: u64

Unshifted bitmask of lrcpc.

pub const LRCPC_SHIFT: usize = 20

Bit shift (i.e., the low bit) of lrcpc.

pub const FCMA_MASK: u64

Unshifted bitmask of fcma.

pub const FCMA_SHIFT: usize = 16

Bit shift (i.e., the low bit) of fcma.

pub const JSCVT_MASK: u64

Unshifted bitmask of jscvt.

pub const JSCVT_SHIFT: usize = 12

Bit shift (i.e., the low bit) of jscvt.

pub const API_MASK: u64

Unshifted bitmask of api.

pub const API_SHIFT: usize = 8

Bit shift (i.e., the low bit) of api.

pub const APA_MASK: u64

Unshifted bitmask of apa.

pub const APA_SHIFT: usize = 4

Bit shift (i.e., the low bit) of apa.

pub const DPB_MASK: u64

Unshifted bitmask of dpb.

pub const DPB_SHIFT: usize = 0

Bit shift (i.e., the low bit) of dpb.

pub const FIELDS: [FieldMetadata<u64>; 16]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub fn ls64(&self) -> IdAa64IsaR1Ls64

The value of InstructionSetAttributeRegister1[63:60].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ls64 to recover from invalid bit patterns.

pub fn try_ls64(&self) -> Result<IdAa64IsaR1Ls64, InvalidBits<u8>>

Fallible variant of Self::ls64.

pub fn set_ls64(&mut self, value: IdAa64IsaR1Ls64) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[63:60].

pub fn xs(&self) -> IdAa64IsaR1Xs

The value of InstructionSetAttributeRegister1[59:56].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_xs to recover from invalid bit patterns.

pub fn try_xs(&self) -> Result<IdAa64IsaR1Xs, InvalidBits<u8>>

Fallible variant of Self::xs.

pub fn set_xs(&mut self, value: IdAa64IsaR1Xs) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[59:56].

pub fn i8mm(&self) -> IdAa64IsaR1I8mm

The value of InstructionSetAttributeRegister1[55:52].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_i8mm to recover from invalid bit patterns.

pub fn try_i8mm(&self) -> Result<IdAa64IsaR1I8mm, InvalidBits<u8>>

Fallible variant of Self::i8mm.

pub fn set_i8mm(&mut self, value: IdAa64IsaR1I8mm) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[55:52].

pub fn dgh(&self) -> IdAa64IsaR1Dgh

The value of InstructionSetAttributeRegister1[51:48].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_dgh to recover from invalid bit patterns.

pub fn try_dgh(&self) -> Result<IdAa64IsaR1Dgh, InvalidBits<u8>>

Fallible variant of Self::dgh.

pub fn set_dgh(&mut self, value: IdAa64IsaR1Dgh) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[51:48].

pub fn bf16(&self) -> IdAa64IsaR1Bf16

The value of InstructionSetAttributeRegister1[47:44].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_bf16 to recover from invalid bit patterns.

pub fn try_bf16(&self) -> Result<IdAa64IsaR1Bf16, InvalidBits<u8>>

Fallible variant of Self::bf16.

pub fn set_bf16(&mut self, value: IdAa64IsaR1Bf16) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[47:44].

pub fn specres(&self) -> IdAa64IsaR1Specres

The value of InstructionSetAttributeRegister1[43:40].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_specres to recover from invalid bit patterns.

pub fn try_specres(&self) -> Result<IdAa64IsaR1Specres, InvalidBits<u8>>

Fallible variant of Self::specres.

pub fn set_specres(&mut self, value: IdAa64IsaR1Specres) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[43:40].

pub fn sb(&self) -> IdAa64IsaR1Sb

The value of InstructionSetAttributeRegister1[39:36].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sb to recover from invalid bit patterns.

pub fn try_sb(&self) -> Result<IdAa64IsaR1Sb, InvalidBits<u8>>

Fallible variant of Self::sb.

pub fn set_sb(&mut self, value: IdAa64IsaR1Sb) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[39:36].

pub fn frintts(&self) -> IdAa64IsaR1Frintts

The value of InstructionSetAttributeRegister1[35:32].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_frintts to recover from invalid bit patterns.

pub fn try_frintts(&self) -> Result<IdAa64IsaR1Frintts, InvalidBits<u8>>

Fallible variant of Self::frintts.

pub fn set_frintts(&mut self, value: IdAa64IsaR1Frintts) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[35:32].

pub fn gpi(&self) -> IdAa64IsaR1Gpi

The value of InstructionSetAttributeRegister1[31:28].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_gpi to recover from invalid bit patterns.

pub fn try_gpi(&self) -> Result<IdAa64IsaR1Gpi, InvalidBits<u8>>

Fallible variant of Self::gpi.

pub fn set_gpi(&mut self, value: IdAa64IsaR1Gpi) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[31:28].

pub fn gpa(&self) -> IdAa64IsaR1Gpa

The value of InstructionSetAttributeRegister1[27:24].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_gpa to recover from invalid bit patterns.

pub fn try_gpa(&self) -> Result<IdAa64IsaR1Gpa, InvalidBits<u8>>

Fallible variant of Self::gpa.

pub fn set_gpa(&mut self, value: IdAa64IsaR1Gpa) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[27:24].

pub fn lrcpc(&self) -> IdAa64IsaR1Lrcpc

The value of InstructionSetAttributeRegister1[23:20].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_lrcpc to recover from invalid bit patterns.

pub fn try_lrcpc(&self) -> Result<IdAa64IsaR1Lrcpc, InvalidBits<u8>>

Fallible variant of Self::lrcpc.

pub fn set_lrcpc(&mut self, value: IdAa64IsaR1Lrcpc) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[23:20].

pub fn fcma(&self) -> IdAa64IsaR1Fcma

The value of InstructionSetAttributeRegister1[19:16].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_fcma to recover from invalid bit patterns.

pub fn try_fcma(&self) -> Result<IdAa64IsaR1Fcma, InvalidBits<u8>>

Fallible variant of Self::fcma.

pub fn set_fcma(&mut self, value: IdAa64IsaR1Fcma) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[19:16].

pub fn jscvt(&self) -> IdAa64IsaR1Jscvt

The value of InstructionSetAttributeRegister1[15:12].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_jscvt to recover from invalid bit patterns.

pub fn try_jscvt(&self) -> Result<IdAa64IsaR1Jscvt, InvalidBits<u8>>

Fallible variant of Self::jscvt.

pub fn set_jscvt(&mut self, value: IdAa64IsaR1Jscvt) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[15:12].

pub fn api(&self) -> IdAa64IsaR1Pauth

The value of InstructionSetAttributeRegister1[11:8].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_api to recover from invalid bit patterns.

pub fn try_api(&self) -> Result<IdAa64IsaR1Pauth, InvalidBits<u8>>

Fallible variant of Self::api.

pub fn set_api(&mut self, value: IdAa64IsaR1Pauth) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[11:8].

pub fn apa(&self) -> IdAa64IsaR1Pauth

The value of InstructionSetAttributeRegister1[7:4].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_apa to recover from invalid bit patterns.

pub fn try_apa(&self) -> Result<IdAa64IsaR1Pauth, InvalidBits<u8>>

Fallible variant of Self::apa.

pub fn set_apa(&mut self, value: IdAa64IsaR1Pauth) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[7:4].

pub fn dpb(&self) -> IdAa64IsaR1Dpb

The value of InstructionSetAttributeRegister1[3:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_dpb to recover from invalid bit patterns.

pub fn try_dpb(&self) -> Result<IdAa64IsaR1Dpb, InvalidBits<u8>>

Fallible variant of Self::dpb.

pub fn set_dpb(&mut self, value: IdAa64IsaR1Dpb) -> &mut Self

Sets the value of InstructionSetAttributeRegister1[3:0].

Source

impl InstructionSetAttributeRegister1

pub fn iter(&self) -> InstructionSetAttributeRegister1Iter

Returns an iterator over (metadata, value) pairs for each field.