InstructionSetAttributeRegister2

Struct InstructionSetAttributeRegister2 

pub struct InstructionSetAttributeRegister2(/* private fields */);
The layout of ID_AA64ISAR2_EL1.

Implementations

Source

impl InstructionSetAttributeRegister2

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const ATS1A_MASK: u64

Unshifted bitmask of ats1a.

pub const ATS1A_SHIFT: usize = 60

Bit shift (i.e., the low bit) of ats1a.

pub const LUT_MASK: u64

Unshifted bitmask of lut.

pub const LUT_SHIFT: usize = 56

Bit shift (i.e., the low bit) of lut.

pub const CSSC_MASK: u64

Unshifted bitmask of cssc.

pub const CSSC_SHIFT: usize = 52

Bit shift (i.e., the low bit) of cssc.

pub const RPRFM_MASK: u64

Unshifted bitmask of rprfm.

pub const RPRFM_SHIFT: usize = 48

Bit shift (i.e., the low bit) of rprfm.

pub const PRFMSLC_MASK: u64

Unshifted bitmask of prfmslc.

pub const PRFMSLC_SHIFT: usize = 40

Bit shift (i.e., the low bit) of prfmslc.

pub const SYSINSTR_128_MASK: u64

Unshifted bitmask of sysinstr_128.

pub const SYSINSTR_128_SHIFT: usize = 36

Bit shift (i.e., the low bit) of sysinstr_128.

pub const SYSREG_128_MASK: u64

Unshifted bitmask of sysreg_128.

pub const SYSREG_128_SHIFT: usize = 32

Bit shift (i.e., the low bit) of sysreg_128.

pub const CLRBHB_MASK: u64

Unshifted bitmask of clrbhb.

pub const CLRBHB_SHIFT: usize = 28

Bit shift (i.e., the low bit) of clrbhb.

pub const PAC_FRAC_MASK: u64

Unshifted bitmask of pac_frac.

pub const PAC_FRAC_SHIFT: usize = 24

Bit shift (i.e., the low bit) of pac_frac.

pub const BC_MASK: u64

Unshifted bitmask of bc.

pub const BC_SHIFT: usize = 20

Bit shift (i.e., the low bit) of bc.

pub const MOPS_MASK: u64

Unshifted bitmask of mops.

pub const MOPS_SHIFT: usize = 16

Bit shift (i.e., the low bit) of mops.

pub const APA3_MASK: u64

Unshifted bitmask of apa3.

pub const APA3_SHIFT: usize = 12

Bit shift (i.e., the low bit) of apa3.

pub const GPA3_MASK: u64

Unshifted bitmask of gpa3.

pub const GPA3_SHIFT: usize = 8

Bit shift (i.e., the low bit) of gpa3.

pub const RPRES_MASK: u64

Unshifted bitmask of rpres.

pub const RPRES_SHIFT: usize = 4

Bit shift (i.e., the low bit) of rpres.

pub const WFXT_MASK: u64

Unshifted bitmask of wfxt.

pub const WFXT_SHIFT: usize = 0

Bit shift (i.e., the low bit) of wfxt.

pub const FIELDS: [FieldMetadata<u64>; 15]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub fn ats1a(&self) -> IdAa64IsaR2Ats1a

The value of InstructionSetAttributeRegister2[63:60].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ats1a to recover from invalid bit patterns.

pub fn try_ats1a(&self) -> Result<IdAa64IsaR2Ats1a, InvalidBits<u8>>

Fallible variant of Self::ats1a.

pub fn set_ats1a(&mut self, value: IdAa64IsaR2Ats1a) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[63:60].

pub fn lut(&self) -> IdAa64IsaR2Lut

The value of InstructionSetAttributeRegister2[59:56].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_lut to recover from invalid bit patterns.

pub fn try_lut(&self) -> Result<IdAa64IsaR2Lut, InvalidBits<u8>>

Fallible variant of Self::lut.

pub fn set_lut(&mut self, value: IdAa64IsaR2Lut) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[59:56].

pub fn cssc(&self) -> IdAa64IsaR2Cssc

The value of InstructionSetAttributeRegister2[55:52].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_cssc to recover from invalid bit patterns.

pub fn try_cssc(&self) -> Result<IdAa64IsaR2Cssc, InvalidBits<u8>>

Fallible variant of Self::cssc.

pub fn set_cssc(&mut self, value: IdAa64IsaR2Cssc) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[55:52].

pub fn rprfm(&self) -> IdAa64IsaR2Rprfm

The value of InstructionSetAttributeRegister2[51:48].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_rprfm to recover from invalid bit patterns.

pub fn try_rprfm(&self) -> Result<IdAa64IsaR2Rprfm, InvalidBits<u8>>

Fallible variant of Self::rprfm.

pub fn set_rprfm(&mut self, value: IdAa64IsaR2Rprfm) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[51:48].

pub fn prfmslc(&self) -> IdAa64IsaR2Prfmslc

The value of InstructionSetAttributeRegister2[43:40].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_prfmslc to recover from invalid bit patterns.

pub fn try_prfmslc(&self) -> Result<IdAa64IsaR2Prfmslc, InvalidBits<u8>>

Fallible variant of Self::prfmslc.

pub fn set_prfmslc(&mut self, value: IdAa64IsaR2Prfmslc) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[43:40].

pub fn sysinstr_128(&self) -> IdAa64IsaR2Sysinstr128

The value of InstructionSetAttributeRegister2[39:36].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sysinstr_128 to recover from invalid bit patterns.

pub fn try_sysinstr_128( &self, ) -> Result<IdAa64IsaR2Sysinstr128, InvalidBits<u8>>

Fallible variant of Self::sysinstr_128.

pub fn set_sysinstr_128(&mut self, value: IdAa64IsaR2Sysinstr128) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[39:36].

pub fn sysreg_128(&self) -> IdAa64IsaR2Sysreg128

The value of InstructionSetAttributeRegister2[35:32].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sysreg_128 to recover from invalid bit patterns.

pub fn try_sysreg_128(&self) -> Result<IdAa64IsaR2Sysreg128, InvalidBits<u8>>

Fallible variant of Self::sysreg_128.

pub fn set_sysreg_128(&mut self, value: IdAa64IsaR2Sysreg128) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[35:32].

pub fn clrbhb(&self) -> IdAa64IsaR2Clrbhb

The value of InstructionSetAttributeRegister2[31:28].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_clrbhb to recover from invalid bit patterns.

pub fn try_clrbhb(&self) -> Result<IdAa64IsaR2Clrbhb, InvalidBits<u8>>

Fallible variant of Self::clrbhb.

pub fn set_clrbhb(&mut self, value: IdAa64IsaR2Clrbhb) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[31:28].

pub fn pac_frac(&self) -> IdAa64IsaR2PacFrac

The value of InstructionSetAttributeRegister2[27:24].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_pac_frac to recover from invalid bit patterns.

pub fn try_pac_frac(&self) -> Result<IdAa64IsaR2PacFrac, InvalidBits<u8>>

Fallible variant of Self::pac_frac.

pub fn set_pac_frac(&mut self, value: IdAa64IsaR2PacFrac) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[27:24].

pub fn bc(&self) -> IdAa64IsaR2Bc

The value of InstructionSetAttributeRegister2[23:20].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_bc to recover from invalid bit patterns.

pub fn try_bc(&self) -> Result<IdAa64IsaR2Bc, InvalidBits<u8>>

Fallible variant of Self::bc.

pub fn set_bc(&mut self, value: IdAa64IsaR2Bc) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[23:20].

pub fn mops(&self) -> IdAa64IsaR2Mops

The value of InstructionSetAttributeRegister2[19:16].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_mops to recover from invalid bit patterns.

pub fn try_mops(&self) -> Result<IdAa64IsaR2Mops, InvalidBits<u8>>

Fallible variant of Self::mops.

pub fn set_mops(&mut self, value: IdAa64IsaR2Mops) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[19:16].

pub fn apa3(&self) -> IdAa64IsaR2Apa3

The value of InstructionSetAttributeRegister2[15:12].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_apa3 to recover from invalid bit patterns.

pub fn try_apa3(&self) -> Result<IdAa64IsaR2Apa3, InvalidBits<u8>>

Fallible variant of Self::apa3.

pub fn set_apa3(&mut self, value: IdAa64IsaR2Apa3) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[15:12].

pub fn gpa3(&self) -> IdAa64IsaR2Gpa3

The value of InstructionSetAttributeRegister2[11:8].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_gpa3 to recover from invalid bit patterns.

pub fn try_gpa3(&self) -> Result<IdAa64IsaR2Gpa3, InvalidBits<u8>>

Fallible variant of Self::gpa3.

pub fn set_gpa3(&mut self, value: IdAa64IsaR2Gpa3) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[11:8].

pub fn rpres(&self) -> IdAa64IsaR2Rpres

The value of InstructionSetAttributeRegister2[7:4].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_rpres to recover from invalid bit patterns.

pub fn try_rpres(&self) -> Result<IdAa64IsaR2Rpres, InvalidBits<u8>>

Fallible variant of Self::rpres.

pub fn set_rpres(&mut self, value: IdAa64IsaR2Rpres) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[7:4].

pub fn wfxt(&self) -> IdAa64IsaR2Wfxt

The value of InstructionSetAttributeRegister2[3:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_wfxt to recover from invalid bit patterns.

pub fn try_wfxt(&self) -> Result<IdAa64IsaR2Wfxt, InvalidBits<u8>>

Fallible variant of Self::wfxt.

pub fn set_wfxt(&mut self, value: IdAa64IsaR2Wfxt) -> &mut Self

Sets the value of InstructionSetAttributeRegister2[3:0].

Source

impl InstructionSetAttributeRegister2

pub fn iter(&self) -> InstructionSetAttributeRegister2Iter

Returns an iterator over (metadata, value) pairs for each field.