MemoryModelFeatureRegister0

Struct MemoryModelFeatureRegister0 

pub struct MemoryModelFeatureRegister0(/* private fields */);
The layout of ID_AA64MMFR0_EL1.

Implementations

Source

impl MemoryModelFeatureRegister0

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const ECV_MASK: u64

Unshifted bitmask of ecv.

pub const ECV_SHIFT: usize = 60

Bit shift (i.e., the low bit) of ecv.

pub const FGT_MASK: u64

Unshifted bitmask of fgt.

pub const FGT_SHIFT: usize = 56

Bit shift (i.e., the low bit) of fgt.

pub const EXS_MASK: u64

Unshifted bitmask of exs.

pub const EXS_SHIFT: usize = 44

Bit shift (i.e., the low bit) of exs.

pub const TGRAN4_2_MASK: u64

Unshifted bitmask of tgran4_2.

pub const TGRAN4_2_SHIFT: usize = 40

Bit shift (i.e., the low bit) of tgran4_2.

pub const TGRAN64_2_MASK: u64

Unshifted bitmask of tgran64_2.

pub const TGRAN64_2_SHIFT: usize = 36

Bit shift (i.e., the low bit) of tgran64_2.

pub const TGRAN16_2_MASK: u64

Unshifted bitmask of tgran16_2.

pub const TGRAN16_2_SHIFT: usize = 32

Bit shift (i.e., the low bit) of tgran16_2.

pub const TGRAN4_MASK: u64

Unshifted bitmask of tgran4.

pub const TGRAN4_SHIFT: usize = 28

Bit shift (i.e., the low bit) of tgran4.

pub const TGRAN64_MASK: u64

Unshifted bitmask of tgran64.

pub const TGRAN64_SHIFT: usize = 24

Bit shift (i.e., the low bit) of tgran64.

pub const TGRAN16_MASK: u64

Unshifted bitmask of tgran16.

pub const TGRAN16_SHIFT: usize = 20

Bit shift (i.e., the low bit) of tgran16.

pub const BIG_END_EL0_MASK: u64

Unshifted bitmask of big_end_el0.

pub const BIG_END_EL0_SHIFT: usize = 16

Bit shift (i.e., the low bit) of big_end_el0.

pub const SNS_MEM_MASK: u64

Unshifted bitmask of sns_mem.

pub const SNS_MEM_SHIFT: usize = 12

Bit shift (i.e., the low bit) of sns_mem.

pub const BIG_END_MASK: u64

Unshifted bitmask of big_end.

pub const BIG_END_SHIFT: usize = 8

Bit shift (i.e., the low bit) of big_end.

pub const ASID_BITS_MASK: u64

Unshifted bitmask of asid_bits.

pub const ASID_BITS_SHIFT: usize = 4

Bit shift (i.e., the low bit) of asid_bits.

pub const PA_RANGE_MASK: u64

Unshifted bitmask of pa_range.

pub const PA_RANGE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of pa_range.

pub const FIELDS: [FieldMetadata<u64>; 14]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn ecv(&self) -> u8

The value of MemoryModelFeatureRegister0[63:60].

pub const fn set_ecv(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[63:60].

pub const fn fgt(&self) -> u8

The value of MemoryModelFeatureRegister0[59:56].

pub const fn set_fgt(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[59:56].

pub const fn exs(&self) -> u8

The value of MemoryModelFeatureRegister0[47:44].

pub const fn set_exs(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[47:44].

pub const fn tgran4_2(&self) -> u8

The value of MemoryModelFeatureRegister0[43:40].

pub const fn set_tgran4_2(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[43:40].

pub const fn tgran64_2(&self) -> u8

The value of MemoryModelFeatureRegister0[39:36].

pub const fn set_tgran64_2(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[39:36].

pub const fn tgran16_2(&self) -> u8

The value of MemoryModelFeatureRegister0[35:32].

pub const fn set_tgran16_2(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[35:32].

pub const fn tgran4(&self) -> u8

The value of MemoryModelFeatureRegister0[31:28].

pub const fn set_tgran4(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[31:28].

pub const fn tgran64(&self) -> u8

The value of MemoryModelFeatureRegister0[27:24].

pub const fn set_tgran64(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[27:24].

pub const fn tgran16(&self) -> u8

The value of MemoryModelFeatureRegister0[23:20].

pub const fn set_tgran16(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[23:20].

pub const fn big_end_el0(&self) -> u8

The value of MemoryModelFeatureRegister0[19:16].

pub const fn set_big_end_el0(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[19:16].

pub const fn sns_mem(&self) -> u8

The value of MemoryModelFeatureRegister0[15:12].

pub const fn set_sns_mem(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[15:12].

pub const fn big_end(&self) -> u8

The value of MemoryModelFeatureRegister0[11:8].

pub const fn set_big_end(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[11:8].

pub fn asid_bits(&self) -> AsidSize

The value of MemoryModelFeatureRegister0[7:4].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_asid_bits to recover from invalid bit patterns.

pub fn try_asid_bits(&self) -> Result<AsidSize, InvalidBits<u8>>

Fallible variant of Self::asid_bits.

pub fn set_asid_bits(&mut self, value: AsidSize) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[7:4].

pub fn pa_range(&self) -> PhysicalAddressSize

The value of MemoryModelFeatureRegister0[3:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_pa_range to recover from invalid bit patterns.

pub fn try_pa_range(&self) -> Result<PhysicalAddressSize, InvalidBits<u8>>

Fallible variant of Self::pa_range.

pub fn set_pa_range(&mut self, value: PhysicalAddressSize) -> &mut Self

Sets the value of MemoryModelFeatureRegister0[3:0].

Source

impl MemoryModelFeatureRegister0

pub fn iter(&self) -> MemoryModelFeatureRegister0Iter

Returns an iterator over (metadata, value) pairs for each field.