MemoryModelFeatureRegister1

Struct MemoryModelFeatureRegister1 

pub struct MemoryModelFeatureRegister1(/* private fields */);
The layout of ID_AA64MMFR1_EL1.

Implementations

Source

impl MemoryModelFeatureRegister1

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const CMOW_MASK: u64

Unshifted bitmask of cmow.

pub const CMOW_SHIFT: usize = 56

Bit shift (i.e., the low bit) of cmow.

pub const TIDCP1_MASK: u64

Unshifted bitmask of tidcp1.

pub const TIDCP1_SHIFT: usize = 52

Bit shift (i.e., the low bit) of tidcp1.

pub const NTLBPA_MASK: u64

Unshifted bitmask of ntlbpa.

pub const NTLBPA_SHIFT: usize = 48

Bit shift (i.e., the low bit) of ntlbpa.

pub const AFP_MASK: u64

Unshifted bitmask of afp.

pub const AFP_SHIFT: usize = 44

Bit shift (i.e., the low bit) of afp.

pub const HCX_MASK: u64

Unshifted bitmask of hcx.

pub const HCX_SHIFT: usize = 40

Bit shift (i.e., the low bit) of hcx.

pub const ETS_MASK: u64

Unshifted bitmask of ets.

pub const ETS_SHIFT: usize = 36

Bit shift (i.e., the low bit) of ets.

pub const TWED_MASK: u64

Unshifted bitmask of twed.

pub const TWED_SHIFT: usize = 32

Bit shift (i.e., the low bit) of twed.

pub const XNX_MASK: u64

Unshifted bitmask of xnx.

pub const XNX_SHIFT: usize = 28

Bit shift (i.e., the low bit) of xnx.

pub const SPEC_SEI_MASK: u64

Unshifted bitmask of spec_sei.

pub const SPEC_SEI_SHIFT: usize = 24

Bit shift (i.e., the low bit) of spec_sei.

pub const PAN_MASK: u64

Unshifted bitmask of pan.

pub const PAN_SHIFT: usize = 20

Bit shift (i.e., the low bit) of pan.

pub const LO_MASK: u64

Unshifted bitmask of lo.

pub const LO_SHIFT: usize = 16

Bit shift (i.e., the low bit) of lo.

pub const HPDS_MASK: u64

Unshifted bitmask of hpds.

pub const HPDS_SHIFT: usize = 12

Bit shift (i.e., the low bit) of hpds.

pub const VH_MASK: u64

Unshifted bitmask of vh.

pub const VH_SHIFT: usize = 8

Bit shift (i.e., the low bit) of vh.

pub const VMID_BITS_MASK: u64

Unshifted bitmask of vmid_bits.

pub const VMID_BITS_SHIFT: usize = 4

Bit shift (i.e., the low bit) of vmid_bits.

pub const HAFDBS_MASK: u64

Unshifted bitmask of hafdbs.

pub const HAFDBS_SHIFT: usize = 0

Bit shift (i.e., the low bit) of hafdbs.

pub const FIELDS: [FieldMetadata<u64>; 15]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn cmow(&self) -> u8

The value of MemoryModelFeatureRegister1[59:56].

pub const fn set_cmow(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[59:56].

pub const fn tidcp1(&self) -> u8

The value of MemoryModelFeatureRegister1[55:52].

pub const fn set_tidcp1(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[55:52].

pub const fn ntlbpa(&self) -> u8

The value of MemoryModelFeatureRegister1[51:48].

pub const fn set_ntlbpa(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[51:48].

pub const fn afp(&self) -> u8

The value of MemoryModelFeatureRegister1[47:44].

pub const fn set_afp(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[47:44].

pub const fn hcx(&self) -> u8

The value of MemoryModelFeatureRegister1[43:40].

pub const fn set_hcx(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[43:40].

pub const fn ets(&self) -> u8

The value of MemoryModelFeatureRegister1[39:36].

pub const fn set_ets(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[39:36].

pub const fn twed(&self) -> u8

The value of MemoryModelFeatureRegister1[35:32].

pub const fn set_twed(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[35:32].

pub const fn xnx(&self) -> u8

The value of MemoryModelFeatureRegister1[31:28].

pub const fn set_xnx(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[31:28].

pub const fn spec_sei(&self) -> u8

The value of MemoryModelFeatureRegister1[27:24].

pub const fn set_spec_sei(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[27:24].

pub const fn pan(&self) -> u8

The value of MemoryModelFeatureRegister1[23:20].

pub const fn set_pan(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[23:20].

pub const fn lo(&self) -> u8

The value of MemoryModelFeatureRegister1[19:16].

pub const fn set_lo(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[19:16].

pub const fn hpds(&self) -> u8

The value of MemoryModelFeatureRegister1[15:12].

pub const fn set_hpds(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[15:12].

pub const fn vh(&self) -> u8

The value of MemoryModelFeatureRegister1[11:8].

pub const fn set_vh(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[11:8].

pub fn vmid_bits(&self) -> AsidSize

The value of MemoryModelFeatureRegister1[7:4].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_vmid_bits to recover from invalid bit patterns.

pub fn try_vmid_bits(&self) -> Result<AsidSize, InvalidBits<u8>>

Fallible variant of Self::vmid_bits.

pub fn set_vmid_bits(&mut self, value: AsidSize) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[7:4].

pub const fn hafdbs(&self) -> u8

The value of MemoryModelFeatureRegister1[3:0].

pub const fn set_hafdbs(&mut self, value: u8) -> &mut Self

Sets the value of MemoryModelFeatureRegister1[3:0].

Source

impl MemoryModelFeatureRegister1

pub fn iter(&self) -> MemoryModelFeatureRegister1Iter

Returns an iterator over (metadata, value) pairs for each field.