SavedProgramStatusRegister

Struct SavedProgramStatusRegister 

pub struct SavedProgramStatusRegister(/* private fields */);
The layout of SPSR_EL1, SPSR_EL2, and SPSR_EL3.

These are the assignments when an exception is taken from AArch64 state.

Implementations

Source

impl SavedProgramStatusRegister

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const N_MASK: u64

Unshifted bitmask of n.

pub const N_SHIFT: usize = 31

Bit shift (i.e., the low bit) of n.

pub const Z_MASK: u64

Unshifted bitmask of z.

pub const Z_SHIFT: usize = 30

Bit shift (i.e., the low bit) of z.

pub const C_MASK: u64

Unshifted bitmask of c.

pub const C_SHIFT: usize = 29

Bit shift (i.e., the low bit) of c.

pub const V_MASK: u64

Unshifted bitmask of v.

pub const V_SHIFT: usize = 28

Bit shift (i.e., the low bit) of v.

pub const TCO_MASK: u64

Unshifted bitmask of tco.

pub const TCO_SHIFT: usize = 25

Bit shift (i.e., the low bit) of tco.

pub const DIT_MASK: u64

Unshifted bitmask of dit.

pub const DIT_SHIFT: usize = 24

Bit shift (i.e., the low bit) of dit.

pub const UAO_MASK: u64

Unshifted bitmask of uao.

pub const UAO_SHIFT: usize = 23

Bit shift (i.e., the low bit) of uao.

pub const PAN_MASK: u64

Unshifted bitmask of pan.

pub const PAN_SHIFT: usize = 22

Bit shift (i.e., the low bit) of pan.

pub const SS_MASK: u64

Unshifted bitmask of ss.

pub const SS_SHIFT: usize = 21

Bit shift (i.e., the low bit) of ss.

pub const IL_MASK: u64

Unshifted bitmask of il.

pub const IL_SHIFT: usize = 20

Bit shift (i.e., the low bit) of il.

pub const SSBS_MASK: u64

Unshifted bitmask of ssbs.

pub const SSBS_SHIFT: usize = 12

Bit shift (i.e., the low bit) of ssbs.

pub const BTYPE_MASK: u64

Unshifted bitmask of btype.

pub const BTYPE_SHIFT: usize = 10

Bit shift (i.e., the low bit) of btype.

pub const D_MASK: u64

Unshifted bitmask of d.

pub const D_SHIFT: usize = 9

Bit shift (i.e., the low bit) of d.

pub const A_MASK: u64

Unshifted bitmask of a.

pub const A_SHIFT: usize = 8

Bit shift (i.e., the low bit) of a.

pub const I_MASK: u64

Unshifted bitmask of i.

pub const I_SHIFT: usize = 7

Bit shift (i.e., the low bit) of i.

pub const F_MASK: u64

Unshifted bitmask of f.

pub const F_SHIFT: usize = 6

Bit shift (i.e., the low bit) of f.

pub const A32_MASK: u64

Unshifted bitmask of a32.

pub const A32_SHIFT: usize = 4

Bit shift (i.e., the low bit) of a32.

pub const M_MASK: u64

Unshifted bitmask of m.

pub const M_SHIFT: usize = 0

Bit shift (i.e., the low bit) of m.

pub const FIELDS: [FieldMetadata<u64>; 18]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn n(&self) -> bool

The value of SavedProgramStatusRegister31.

pub const fn set_n(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister31.

pub const fn z(&self) -> bool

The value of SavedProgramStatusRegister30.

pub const fn set_z(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister30.

pub const fn c(&self) -> bool

The value of SavedProgramStatusRegister29.

pub const fn set_c(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister29.

pub const fn v(&self) -> bool

The value of SavedProgramStatusRegister28.

pub const fn set_v(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister28.

pub const fn tco(&self) -> bool

The value of SavedProgramStatusRegister25.

pub const fn set_tco(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister25.

pub const fn dit(&self) -> bool

The value of SavedProgramStatusRegister24.

pub const fn set_dit(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister24.

pub const fn uao(&self) -> bool

The value of SavedProgramStatusRegister23.

pub const fn set_uao(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister23.

pub const fn pan(&self) -> bool

The value of SavedProgramStatusRegister22.

pub const fn set_pan(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister22.

pub const fn ss(&self) -> bool

The value of SavedProgramStatusRegister21.

pub const fn set_ss(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister21.

pub const fn il(&self) -> bool

The value of SavedProgramStatusRegister20.

pub const fn set_il(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister20.

pub const fn ssbs(&self) -> bool

The value of SavedProgramStatusRegister12.

pub const fn set_ssbs(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister12.

pub const fn btype(&self) -> u8

The value of SavedProgramStatusRegister[11:10].

pub const fn set_btype(&mut self, value: u8) -> &mut Self

Sets the value of SavedProgramStatusRegister[11:10].

pub const fn d(&self) -> bool

The value of SavedProgramStatusRegister9.

pub const fn set_d(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister9.

pub const fn a(&self) -> bool

The value of SavedProgramStatusRegister8.

pub const fn set_a(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister8.

pub const fn i(&self) -> bool

The value of SavedProgramStatusRegister7.

pub const fn set_i(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister7.

pub const fn f(&self) -> bool

The value of SavedProgramStatusRegister6.

pub const fn set_f(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister6.

pub const fn a32(&self) -> bool

The value of SavedProgramStatusRegister4.

pub const fn set_a32(&mut self, value: bool) -> &mut Self

Sets the value of SavedProgramStatusRegister4.

pub fn m(&self) -> SpsrExceptionLevel

The value of SavedProgramStatusRegister[3:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_m to recover from invalid bit patterns.

pub fn try_m(&self) -> Result<SpsrExceptionLevel, InvalidBits<u8>>

Fallible variant of Self::m.

pub fn set_m(&mut self, value: SpsrExceptionLevel) -> &mut Self

Sets the value of SavedProgramStatusRegister[3:0].

Source

impl SavedProgramStatusRegister

pub fn iter(&self) -> SavedProgramStatusRegisterIter

Returns an iterator over (metadata, value) pairs for each field.

Source

impl SavedProgramStatusRegister

pub fn el(self) -> CurrentEl

EL this exception was taken from.

pub fn spsel(self) -> bool

SPSel state at the exception (true if it used SP_ELx).