SystemControlRegisterEl1

Struct SystemControlRegisterEl1 

pub struct SystemControlRegisterEl1(/* private fields */);
The layout of SCTLR_EL1.

Implementations

Source

impl SystemControlRegisterEl1

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const TIDCP_MASK: u64

Unshifted bitmask of tidcp.

pub const TIDCP_SHIFT: usize = 63

Bit shift (i.e., the low bit) of tidcp.

pub const SPINTMASK_MASK: u64

Unshifted bitmask of spintmask.

pub const SPINTMASK_SHIFT: usize = 62

Bit shift (i.e., the low bit) of spintmask.

pub const NMI_MASK: u64

Unshifted bitmask of nmi.

pub const NMI_SHIFT: usize = 61

Bit shift (i.e., the low bit) of nmi.

pub const ENTP2_MASK: u64

Unshifted bitmask of entp2.

pub const ENTP2_SHIFT: usize = 60

Bit shift (i.e., the low bit) of entp2.

pub const TSCO_MASK: u64

Unshifted bitmask of tsco.

pub const TSCO_SHIFT: usize = 59

Bit shift (i.e., the low bit) of tsco.

pub const TSCO0_MASK: u64

Unshifted bitmask of tsco0.

pub const TSCO0_SHIFT: usize = 58

Bit shift (i.e., the low bit) of tsco0.

pub const EPAN_MASK: u64

Unshifted bitmask of epan.

pub const EPAN_SHIFT: usize = 57

Bit shift (i.e., the low bit) of epan.

pub const ENALS_MASK: u64

Unshifted bitmask of enals.

pub const ENALS_SHIFT: usize = 56

Bit shift (i.e., the low bit) of enals.

pub const ENAS0_MASK: u64

Unshifted bitmask of enas0.

pub const ENAS0_SHIFT: usize = 55

Bit shift (i.e., the low bit) of enas0.

pub const ENASR_MASK: u64

Unshifted bitmask of enasr.

pub const ENASR_SHIFT: usize = 54

Bit shift (i.e., the low bit) of enasr.

pub const TME_MASK: u64

Unshifted bitmask of tme.

pub const TME_SHIFT: usize = 53

Bit shift (i.e., the low bit) of tme.

pub const TME0_MASK: u64

Unshifted bitmask of tme0.

pub const TME0_SHIFT: usize = 52

Bit shift (i.e., the low bit) of tme0.

pub const TMT_MASK: u64

Unshifted bitmask of tmt.

pub const TMT_SHIFT: usize = 51

Bit shift (i.e., the low bit) of tmt.

pub const TMT0_MASK: u64

Unshifted bitmask of tmt0.

pub const TMT0_SHIFT: usize = 50

Bit shift (i.e., the low bit) of tmt0.

pub const TWEDEL_MASK: u64

Unshifted bitmask of twedel.

pub const TWEDEL_SHIFT: usize = 46

Bit shift (i.e., the low bit) of twedel.

pub const TWEDEN_MASK: u64

Unshifted bitmask of tweden.

pub const TWEDEN_SHIFT: usize = 45

Bit shift (i.e., the low bit) of tweden.

pub const DSBSS_MASK: u64

Unshifted bitmask of dsbss.

pub const DSBSS_SHIFT: usize = 44

Bit shift (i.e., the low bit) of dsbss.

pub const ATA_MASK: u64

Unshifted bitmask of ata.

pub const ATA_SHIFT: usize = 43

Bit shift (i.e., the low bit) of ata.

pub const ATA0_MASK: u64

Unshifted bitmask of ata0.

pub const ATA0_SHIFT: usize = 42

Bit shift (i.e., the low bit) of ata0.

pub const TCF_MASK: u64

Unshifted bitmask of tcf.

pub const TCF_SHIFT: usize = 40

Bit shift (i.e., the low bit) of tcf.

pub const TCF0_MASK: u64

Unshifted bitmask of tcf0.

pub const TCF0_SHIFT: usize = 38

Bit shift (i.e., the low bit) of tcf0.

pub const ITFSB_MASK: u64

Unshifted bitmask of itfsb.

pub const ITFSB_SHIFT: usize = 37

Bit shift (i.e., the low bit) of itfsb.

pub const BT_MASK: u64

Unshifted bitmask of bt.

pub const BT_SHIFT: usize = 36

Bit shift (i.e., the low bit) of bt.

pub const BT0_MASK: u64

Unshifted bitmask of bt0.

pub const BT0_SHIFT: usize = 35

Bit shift (i.e., the low bit) of bt0.

pub const MSCEN_MASK: u64

Unshifted bitmask of mscen.

pub const MSCEN_SHIFT: usize = 33

Bit shift (i.e., the low bit) of mscen.

pub const CMOW_MASK: u64

Unshifted bitmask of cmow.

pub const CMOW_SHIFT: usize = 32

Bit shift (i.e., the low bit) of cmow.

pub const ENIA_MASK: u64

Unshifted bitmask of enia.

pub const ENIA_SHIFT: usize = 31

Bit shift (i.e., the low bit) of enia.

pub const ENIB_MASK: u64

Unshifted bitmask of enib.

pub const ENIB_SHIFT: usize = 30

Bit shift (i.e., the low bit) of enib.

pub const LSMAOE_MASK: u64

Unshifted bitmask of lsmaoe.

pub const LSMAOE_SHIFT: usize = 29

Bit shift (i.e., the low bit) of lsmaoe.

pub const NTLSMD_MASK: u64

Unshifted bitmask of ntlsmd.

pub const NTLSMD_SHIFT: usize = 28

Bit shift (i.e., the low bit) of ntlsmd.

pub const ENDA_MASK: u64

Unshifted bitmask of enda.

pub const ENDA_SHIFT: usize = 27

Bit shift (i.e., the low bit) of enda.

pub const UCI_MASK: u64

Unshifted bitmask of uci.

pub const UCI_SHIFT: usize = 26

Bit shift (i.e., the low bit) of uci.

pub const EE_MASK: u64

Unshifted bitmask of ee.

pub const EE_SHIFT: usize = 25

Bit shift (i.e., the low bit) of ee.

pub const E0E_MASK: u64

Unshifted bitmask of e0e.

pub const E0E_SHIFT: usize = 24

Bit shift (i.e., the low bit) of e0e.

pub const SPAN_MASK: u64

Unshifted bitmask of span.

pub const SPAN_SHIFT: usize = 23

Bit shift (i.e., the low bit) of span.

pub const EIS_MASK: u64

Unshifted bitmask of eis.

pub const EIS_SHIFT: usize = 22

Bit shift (i.e., the low bit) of eis.

pub const IESB_MASK: u64

Unshifted bitmask of iesb.

pub const IESB_SHIFT: usize = 21

Bit shift (i.e., the low bit) of iesb.

pub const TSCXT_MASK: u64

Unshifted bitmask of tscxt.

pub const TSCXT_SHIFT: usize = 20

Bit shift (i.e., the low bit) of tscxt.

pub const WXN_MASK: u64

Unshifted bitmask of wxn.

pub const WXN_SHIFT: usize = 19

Bit shift (i.e., the low bit) of wxn.

pub const NTWE_MASK: u64

Unshifted bitmask of ntwe.

pub const NTWE_SHIFT: usize = 18

Bit shift (i.e., the low bit) of ntwe.

pub const NTWI_MASK: u64

Unshifted bitmask of ntwi.

pub const NTWI_SHIFT: usize = 16

Bit shift (i.e., the low bit) of ntwi.

pub const UCT_MASK: u64

Unshifted bitmask of uct.

pub const UCT_SHIFT: usize = 15

Bit shift (i.e., the low bit) of uct.

pub const DZE_MASK: u64

Unshifted bitmask of dze.

pub const DZE_SHIFT: usize = 14

Bit shift (i.e., the low bit) of dze.

pub const ENDB_MASK: u64

Unshifted bitmask of endb.

pub const ENDB_SHIFT: usize = 13

Bit shift (i.e., the low bit) of endb.

pub const I_MASK: u64

Unshifted bitmask of i.

pub const I_SHIFT: usize = 12

Bit shift (i.e., the low bit) of i.

pub const EOS_MASK: u64

Unshifted bitmask of eos.

pub const EOS_SHIFT: usize = 11

Bit shift (i.e., the low bit) of eos.

pub const ENRCTX_MASK: u64

Unshifted bitmask of enrctx.

pub const ENRCTX_SHIFT: usize = 10

Bit shift (i.e., the low bit) of enrctx.

pub const UMA_MASK: u64

Unshifted bitmask of uma.

pub const UMA_SHIFT: usize = 9

Bit shift (i.e., the low bit) of uma.

pub const SED_MASK: u64

Unshifted bitmask of sed.

pub const SED_SHIFT: usize = 8

Bit shift (i.e., the low bit) of sed.

pub const ITD_MASK: u64

Unshifted bitmask of itd.

pub const ITD_SHIFT: usize = 7

Bit shift (i.e., the low bit) of itd.

pub const NAA_MASK: u64

Unshifted bitmask of naa.

pub const NAA_SHIFT: usize = 6

Bit shift (i.e., the low bit) of naa.

pub const CP15BEN_MASK: u64

Unshifted bitmask of cp15ben.

pub const CP15BEN_SHIFT: usize = 5

Bit shift (i.e., the low bit) of cp15ben.

pub const SA0_MASK: u64

Unshifted bitmask of sa0.

pub const SA0_SHIFT: usize = 4

Bit shift (i.e., the low bit) of sa0.

pub const SA_MASK: u64

Unshifted bitmask of sa.

pub const SA_SHIFT: usize = 3

Bit shift (i.e., the low bit) of sa.

pub const C_MASK: u64

Unshifted bitmask of c.

pub const C_SHIFT: usize = 2

Bit shift (i.e., the low bit) of c.

pub const A_MASK: u64

Unshifted bitmask of a.

pub const A_SHIFT: usize = 1

Bit shift (i.e., the low bit) of a.

pub const M_MASK: u64

Unshifted bitmask of m.

pub const M_SHIFT: usize = 0

Bit shift (i.e., the low bit) of m.

pub const FIELDS: [FieldMetadata<u64>; 57]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn tidcp(&self) -> bool

The value of SystemControlRegisterEl163.

pub const fn set_tidcp(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl163.

pub const fn spintmask(&self) -> bool

The value of SystemControlRegisterEl162.

pub const fn set_spintmask(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl162.

pub const fn nmi(&self) -> bool

The value of SystemControlRegisterEl161.

pub const fn set_nmi(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl161.

pub const fn entp2(&self) -> bool

The value of SystemControlRegisterEl160.

pub const fn set_entp2(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl160.

pub const fn tsco(&self) -> bool

The value of SystemControlRegisterEl159.

pub const fn set_tsco(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl159.

pub const fn tsco0(&self) -> bool

The value of SystemControlRegisterEl158.

pub const fn set_tsco0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl158.

pub const fn epan(&self) -> bool

The value of SystemControlRegisterEl157.

pub const fn set_epan(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl157.

pub const fn enals(&self) -> bool

The value of SystemControlRegisterEl156.

pub const fn set_enals(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl156.

pub const fn enas0(&self) -> bool

The value of SystemControlRegisterEl155.

pub const fn set_enas0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl155.

pub const fn enasr(&self) -> bool

The value of SystemControlRegisterEl154.

pub const fn set_enasr(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl154.

pub const fn tme(&self) -> bool

The value of SystemControlRegisterEl153.

pub const fn set_tme(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl153.

pub const fn tme0(&self) -> bool

The value of SystemControlRegisterEl152.

pub const fn set_tme0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl152.

pub const fn tmt(&self) -> bool

The value of SystemControlRegisterEl151.

pub const fn set_tmt(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl151.

pub const fn tmt0(&self) -> bool

The value of SystemControlRegisterEl150.

pub const fn set_tmt0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl150.

pub const fn twedel(&self) -> u8

The value of SystemControlRegisterEl1[49:46].

pub const fn set_twedel(&mut self, value: u8) -> &mut Self

Sets the value of SystemControlRegisterEl1[49:46].

pub const fn tweden(&self) -> bool

The value of SystemControlRegisterEl145.

pub const fn set_tweden(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl145.

pub const fn dsbss(&self) -> bool

The value of SystemControlRegisterEl144.

pub const fn set_dsbss(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl144.

pub const fn ata(&self) -> bool

The value of SystemControlRegisterEl143.

pub const fn set_ata(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl143.

pub const fn ata0(&self) -> bool

The value of SystemControlRegisterEl142.

pub const fn set_ata0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl142.

pub fn tcf(&self) -> TagCheckFault

The value of SystemControlRegisterEl1[41:40].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tcf to recover from invalid bit patterns.

pub fn try_tcf(&self) -> Result<TagCheckFault, InvalidBits<u8>>

Fallible variant of Self::tcf.

pub fn set_tcf(&mut self, value: TagCheckFault) -> &mut Self

Sets the value of SystemControlRegisterEl1[41:40].

pub fn tcf0(&self) -> TagCheckFault

The value of SystemControlRegisterEl1[39:38].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tcf0 to recover from invalid bit patterns.

pub fn try_tcf0(&self) -> Result<TagCheckFault, InvalidBits<u8>>

Fallible variant of Self::tcf0.

pub fn set_tcf0(&mut self, value: TagCheckFault) -> &mut Self

Sets the value of SystemControlRegisterEl1[39:38].

pub const fn itfsb(&self) -> bool

The value of SystemControlRegisterEl137.

pub const fn set_itfsb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl137.

pub const fn bt(&self) -> bool

The value of SystemControlRegisterEl136.

pub const fn set_bt(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl136.

pub const fn bt0(&self) -> bool

The value of SystemControlRegisterEl135.

pub const fn set_bt0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl135.

pub const fn mscen(&self) -> bool

The value of SystemControlRegisterEl133.

pub const fn set_mscen(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl133.

pub const fn cmow(&self) -> bool

The value of SystemControlRegisterEl132.

pub const fn set_cmow(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl132.

pub const fn enia(&self) -> bool

The value of SystemControlRegisterEl131.

pub const fn set_enia(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl131.

pub const fn enib(&self) -> bool

The value of SystemControlRegisterEl130.

pub const fn set_enib(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl130.

pub const fn lsmaoe(&self) -> bool

The value of SystemControlRegisterEl129.

pub const fn set_lsmaoe(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl129.

pub const fn ntlsmd(&self) -> bool

The value of SystemControlRegisterEl128.

pub const fn set_ntlsmd(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl128.

pub const fn enda(&self) -> bool

The value of SystemControlRegisterEl127.

pub const fn set_enda(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl127.

pub const fn uci(&self) -> bool

The value of SystemControlRegisterEl126.

pub const fn set_uci(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl126.

pub const fn ee(&self) -> bool

The value of SystemControlRegisterEl125.

pub const fn set_ee(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl125.

pub const fn e0e(&self) -> bool

The value of SystemControlRegisterEl124.

pub const fn set_e0e(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl124.

pub const fn span(&self) -> bool

The value of SystemControlRegisterEl123.

pub const fn set_span(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl123.

pub const fn eis(&self) -> bool

The value of SystemControlRegisterEl122.

pub const fn set_eis(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl122.

pub const fn iesb(&self) -> bool

The value of SystemControlRegisterEl121.

pub const fn set_iesb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl121.

pub const fn tscxt(&self) -> bool

The value of SystemControlRegisterEl120.

pub const fn set_tscxt(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl120.

pub const fn wxn(&self) -> bool

The value of SystemControlRegisterEl119.

pub const fn set_wxn(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl119.

pub const fn ntwe(&self) -> bool

The value of SystemControlRegisterEl118.

pub const fn set_ntwe(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl118.

pub const fn ntwi(&self) -> bool

The value of SystemControlRegisterEl116.

pub const fn set_ntwi(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl116.

pub const fn uct(&self) -> bool

The value of SystemControlRegisterEl115.

pub const fn set_uct(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl115.

pub const fn dze(&self) -> bool

The value of SystemControlRegisterEl114.

pub const fn set_dze(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl114.

pub const fn endb(&self) -> bool

The value of SystemControlRegisterEl113.

pub const fn set_endb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl113.

pub const fn i(&self) -> bool

The value of SystemControlRegisterEl112.

pub const fn set_i(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl112.

pub const fn eos(&self) -> bool

The value of SystemControlRegisterEl111.

pub const fn set_eos(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl111.

pub const fn enrctx(&self) -> bool

The value of SystemControlRegisterEl110.

pub const fn set_enrctx(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl110.

pub const fn uma(&self) -> bool

The value of SystemControlRegisterEl19.

pub const fn set_uma(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl19.

pub const fn sed(&self) -> bool

The value of SystemControlRegisterEl18.

pub const fn set_sed(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl18.

pub const fn itd(&self) -> bool

The value of SystemControlRegisterEl17.

pub const fn set_itd(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl17.

pub const fn naa(&self) -> bool

The value of SystemControlRegisterEl16.

pub const fn set_naa(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl16.

pub const fn cp15ben(&self) -> bool

The value of SystemControlRegisterEl15.

pub const fn set_cp15ben(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl15.

pub const fn sa0(&self) -> bool

The value of SystemControlRegisterEl14.

pub const fn set_sa0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl14.

pub const fn sa(&self) -> bool

The value of SystemControlRegisterEl13.

pub const fn set_sa(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl13.

pub const fn c(&self) -> bool

The value of SystemControlRegisterEl12.

pub const fn set_c(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl12.

pub const fn a(&self) -> bool

The value of SystemControlRegisterEl11.

pub const fn set_a(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl11.

pub const fn m(&self) -> bool

The value of SystemControlRegisterEl10.

pub const fn set_m(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl10.

Source

impl SystemControlRegisterEl1

pub fn iter(&self) -> SystemControlRegisterEl1Iter

Returns an iterator over (metadata, value) pairs for each field.

Source

impl SystemControlRegisterEl1

pub fn twedel_cycles(&self) -> Option<u64>

Returns the minimum delay in cycles if TWEDEn is enabled.