SystemControlRegisterEl2

Struct SystemControlRegisterEl2 

pub struct SystemControlRegisterEl2(/* private fields */);
The layout of SCTLR_EL2.

Implementations

Source

impl SystemControlRegisterEl2

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const TIDCP_MASK: u64

Unshifted bitmask of tidcp.

pub const TIDCP_SHIFT: usize = 63

Bit shift (i.e., the low bit) of tidcp.

pub const SPINTMASK_MASK: u64

Unshifted bitmask of spintmask.

pub const SPINTMASK_SHIFT: usize = 62

Bit shift (i.e., the low bit) of spintmask.

pub const NMI_MASK: u64

Unshifted bitmask of nmi.

pub const NMI_SHIFT: usize = 61

Bit shift (i.e., the low bit) of nmi.

pub const ENTP2_MASK: u64

Unshifted bitmask of entp2.

pub const ENTP2_SHIFT: usize = 60

Bit shift (i.e., the low bit) of entp2.

pub const TSCO_MASK: u64

Unshifted bitmask of tsco.

pub const TSCO_SHIFT: usize = 59

Bit shift (i.e., the low bit) of tsco.

pub const TSCO0_MASK: u64

Unshifted bitmask of tsco0.

pub const TSCO0_SHIFT: usize = 58

Bit shift (i.e., the low bit) of tsco0.

pub const EPAN_MASK: u64

Unshifted bitmask of epan.

pub const EPAN_SHIFT: usize = 57

Bit shift (i.e., the low bit) of epan.

pub const ENALS_MASK: u64

Unshifted bitmask of enals.

pub const ENALS_SHIFT: usize = 56

Bit shift (i.e., the low bit) of enals.

pub const ENAS0_MASK: u64

Unshifted bitmask of enas0.

pub const ENAS0_SHIFT: usize = 55

Bit shift (i.e., the low bit) of enas0.

pub const ENASR_MASK: u64

Unshifted bitmask of enasr.

pub const ENASR_SHIFT: usize = 54

Bit shift (i.e., the low bit) of enasr.

pub const TME_MASK: u64

Unshifted bitmask of tme.

pub const TME_SHIFT: usize = 53

Bit shift (i.e., the low bit) of tme.

pub const TME0_MASK: u64

Unshifted bitmask of tme0.

pub const TME0_SHIFT: usize = 52

Bit shift (i.e., the low bit) of tme0.

pub const TMT_MASK: u64

Unshifted bitmask of tmt.

pub const TMT_SHIFT: usize = 51

Bit shift (i.e., the low bit) of tmt.

pub const TMT0_MASK: u64

Unshifted bitmask of tmt0.

pub const TMT0_SHIFT: usize = 50

Bit shift (i.e., the low bit) of tmt0.

pub const DSBSS_MASK: u64

Unshifted bitmask of dsbss.

pub const DSBSS_SHIFT: usize = 44

Bit shift (i.e., the low bit) of dsbss.

pub const ATA_MASK: u64

Unshifted bitmask of ata.

pub const ATA_SHIFT: usize = 43

Bit shift (i.e., the low bit) of ata.

pub const TCF_MASK: u64

Unshifted bitmask of tcf.

pub const TCF_SHIFT: usize = 40

Bit shift (i.e., the low bit) of tcf.

pub const ITFSB_MASK: u64

Unshifted bitmask of itfsb.

pub const ITFSB_SHIFT: usize = 37

Bit shift (i.e., the low bit) of itfsb.

pub const BT_MASK: u64

Unshifted bitmask of bt.

pub const BT_SHIFT: usize = 36

Bit shift (i.e., the low bit) of bt.

pub const MSCEN_MASK: u64

Unshifted bitmask of mscen.

pub const MSCEN_SHIFT: usize = 33

Bit shift (i.e., the low bit) of mscen.

pub const CMOW_MASK: u64

Unshifted bitmask of cmow.

pub const CMOW_SHIFT: usize = 32

Bit shift (i.e., the low bit) of cmow.

pub const ENIA_MASK: u64

Unshifted bitmask of enia.

pub const ENIA_SHIFT: usize = 31

Bit shift (i.e., the low bit) of enia.

pub const ENIB_MASK: u64

Unshifted bitmask of enib.

pub const ENIB_SHIFT: usize = 30

Bit shift (i.e., the low bit) of enib.

pub const ENDA_MASK: u64

Unshifted bitmask of enda.

pub const ENDA_SHIFT: usize = 27

Bit shift (i.e., the low bit) of enda.

pub const EE_MASK: u64

Unshifted bitmask of ee.

pub const EE_SHIFT: usize = 25

Bit shift (i.e., the low bit) of ee.

pub const EIS_MASK: u64

Unshifted bitmask of eis.

pub const EIS_SHIFT: usize = 22

Bit shift (i.e., the low bit) of eis.

pub const IESB_MASK: u64

Unshifted bitmask of iesb.

pub const IESB_SHIFT: usize = 21

Bit shift (i.e., the low bit) of iesb.

pub const WXN_MASK: u64

Unshifted bitmask of wxn.

pub const WXN_SHIFT: usize = 19

Bit shift (i.e., the low bit) of wxn.

pub const DZE_MASK: u64

Unshifted bitmask of dze.

pub const DZE_SHIFT: usize = 14

Bit shift (i.e., the low bit) of dze.

pub const ENDB_MASK: u64

Unshifted bitmask of endb.

pub const ENDB_SHIFT: usize = 13

Bit shift (i.e., the low bit) of endb.

pub const I_MASK: u64

Unshifted bitmask of i.

pub const I_SHIFT: usize = 12

Bit shift (i.e., the low bit) of i.

pub const EOS_MASK: u64

Unshifted bitmask of eos.

pub const EOS_SHIFT: usize = 11

Bit shift (i.e., the low bit) of eos.

pub const NAA_MASK: u64

Unshifted bitmask of naa.

pub const NAA_SHIFT: usize = 6

Bit shift (i.e., the low bit) of naa.

pub const SA_MASK: u64

Unshifted bitmask of sa.

pub const SA_SHIFT: usize = 3

Bit shift (i.e., the low bit) of sa.

pub const C_MASK: u64

Unshifted bitmask of c.

pub const C_SHIFT: usize = 2

Bit shift (i.e., the low bit) of c.

pub const A_MASK: u64

Unshifted bitmask of a.

pub const A_SHIFT: usize = 1

Bit shift (i.e., the low bit) of a.

pub const M_MASK: u64

Unshifted bitmask of m.

pub const M_SHIFT: usize = 0

Bit shift (i.e., the low bit) of m.

pub const FIELDS: [FieldMetadata<u64>; 37]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn tidcp(&self) -> bool

The value of SystemControlRegisterEl263.

pub const fn set_tidcp(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl263.

pub const fn spintmask(&self) -> bool

The value of SystemControlRegisterEl262.

pub const fn set_spintmask(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl262.

pub const fn nmi(&self) -> bool

The value of SystemControlRegisterEl261.

pub const fn set_nmi(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl261.

pub const fn entp2(&self) -> bool

The value of SystemControlRegisterEl260.

pub const fn set_entp2(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl260.

pub const fn tsco(&self) -> bool

The value of SystemControlRegisterEl259.

pub const fn set_tsco(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl259.

pub const fn tsco0(&self) -> bool

The value of SystemControlRegisterEl258.

pub const fn set_tsco0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl258.

pub const fn epan(&self) -> bool

The value of SystemControlRegisterEl257.

pub const fn set_epan(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl257.

pub const fn enals(&self) -> bool

The value of SystemControlRegisterEl256.

pub const fn set_enals(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl256.

pub const fn enas0(&self) -> bool

The value of SystemControlRegisterEl255.

pub const fn set_enas0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl255.

pub const fn enasr(&self) -> bool

The value of SystemControlRegisterEl254.

pub const fn set_enasr(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl254.

pub const fn tme(&self) -> bool

The value of SystemControlRegisterEl253.

pub const fn set_tme(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl253.

pub const fn tme0(&self) -> bool

The value of SystemControlRegisterEl252.

pub const fn set_tme0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl252.

pub const fn tmt(&self) -> bool

The value of SystemControlRegisterEl251.

pub const fn set_tmt(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl251.

pub const fn tmt0(&self) -> bool

The value of SystemControlRegisterEl250.

pub const fn set_tmt0(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl250.

pub const fn dsbss(&self) -> bool

The value of SystemControlRegisterEl244.

pub const fn set_dsbss(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl244.

pub const fn ata(&self) -> bool

The value of SystemControlRegisterEl243.

pub const fn set_ata(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl243.

pub fn tcf(&self) -> TagCheckFault

The value of SystemControlRegisterEl2[41:40].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tcf to recover from invalid bit patterns.

pub fn try_tcf(&self) -> Result<TagCheckFault, InvalidBits<u8>>

Fallible variant of Self::tcf.

pub fn set_tcf(&mut self, value: TagCheckFault) -> &mut Self

Sets the value of SystemControlRegisterEl2[41:40].

pub const fn itfsb(&self) -> bool

The value of SystemControlRegisterEl237.

pub const fn set_itfsb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl237.

pub const fn bt(&self) -> bool

The value of SystemControlRegisterEl236.

pub const fn set_bt(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl236.

pub const fn mscen(&self) -> bool

The value of SystemControlRegisterEl233.

pub const fn set_mscen(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl233.

pub const fn cmow(&self) -> bool

The value of SystemControlRegisterEl232.

pub const fn set_cmow(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl232.

pub const fn enia(&self) -> bool

The value of SystemControlRegisterEl231.

pub const fn set_enia(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl231.

pub const fn enib(&self) -> bool

The value of SystemControlRegisterEl230.

pub const fn set_enib(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl230.

pub const fn enda(&self) -> bool

The value of SystemControlRegisterEl227.

pub const fn set_enda(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl227.

pub const fn ee(&self) -> bool

The value of SystemControlRegisterEl225.

pub const fn set_ee(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl225.

pub const fn eis(&self) -> bool

The value of SystemControlRegisterEl222.

pub const fn set_eis(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl222.

pub const fn iesb(&self) -> bool

The value of SystemControlRegisterEl221.

pub const fn set_iesb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl221.

pub const fn wxn(&self) -> bool

The value of SystemControlRegisterEl219.

pub const fn set_wxn(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl219.

pub const fn dze(&self) -> bool

The value of SystemControlRegisterEl214.

pub const fn set_dze(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl214.

pub const fn endb(&self) -> bool

The value of SystemControlRegisterEl213.

pub const fn set_endb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl213.

pub const fn i(&self) -> bool

The value of SystemControlRegisterEl212.

pub const fn set_i(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl212.

pub const fn eos(&self) -> bool

The value of SystemControlRegisterEl211.

pub const fn set_eos(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl211.

pub const fn naa(&self) -> bool

The value of SystemControlRegisterEl26.

pub const fn set_naa(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl26.

pub const fn sa(&self) -> bool

The value of SystemControlRegisterEl23.

pub const fn set_sa(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl23.

pub const fn c(&self) -> bool

The value of SystemControlRegisterEl22.

pub const fn set_c(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl22.

pub const fn a(&self) -> bool

The value of SystemControlRegisterEl21.

pub const fn set_a(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl21.

pub const fn m(&self) -> bool

The value of SystemControlRegisterEl20.

pub const fn set_m(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl20.

Source

impl SystemControlRegisterEl2

pub fn iter(&self) -> SystemControlRegisterEl2Iter

Returns an iterator over (metadata, value) pairs for each field.