SystemControlRegisterEl3

Struct SystemControlRegisterEl3 

pub struct SystemControlRegisterEl3(/* private fields */);
The layout of SCTLR_EL3.

Implementations

Source

impl SystemControlRegisterEl3

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const SPINTMASK_MASK: u64

Unshifted bitmask of spintmask.

pub const SPINTMASK_SHIFT: usize = 62

Bit shift (i.e., the low bit) of spintmask.

pub const NMI_MASK: u64

Unshifted bitmask of nmi.

pub const NMI_SHIFT: usize = 61

Bit shift (i.e., the low bit) of nmi.

pub const TSCO_MASK: u64

Unshifted bitmask of tsco.

pub const TSCO_SHIFT: usize = 59

Bit shift (i.e., the low bit) of tsco.

pub const TME_MASK: u64

Unshifted bitmask of tme.

pub const TME_SHIFT: usize = 53

Bit shift (i.e., the low bit) of tme.

pub const TMT_MASK: u64

Unshifted bitmask of tmt.

pub const TMT_SHIFT: usize = 51

Bit shift (i.e., the low bit) of tmt.

pub const DSBSS_MASK: u64

Unshifted bitmask of dsbss.

pub const DSBSS_SHIFT: usize = 44

Bit shift (i.e., the low bit) of dsbss.

pub const ATA_MASK: u64

Unshifted bitmask of ata.

pub const ATA_SHIFT: usize = 43

Bit shift (i.e., the low bit) of ata.

pub const TCF_MASK: u64

Unshifted bitmask of tcf.

pub const TCF_SHIFT: usize = 40

Bit shift (i.e., the low bit) of tcf.

pub const ITFSB_MASK: u64

Unshifted bitmask of itfsb.

pub const ITFSB_SHIFT: usize = 37

Bit shift (i.e., the low bit) of itfsb.

pub const BT_MASK: u64

Unshifted bitmask of bt.

pub const BT_SHIFT: usize = 36

Bit shift (i.e., the low bit) of bt.

pub const ENIA_MASK: u64

Unshifted bitmask of enia.

pub const ENIA_SHIFT: usize = 31

Bit shift (i.e., the low bit) of enia.

pub const ENIB_MASK: u64

Unshifted bitmask of enib.

pub const ENIB_SHIFT: usize = 30

Bit shift (i.e., the low bit) of enib.

pub const ENDA_MASK: u64

Unshifted bitmask of enda.

pub const ENDA_SHIFT: usize = 27

Bit shift (i.e., the low bit) of enda.

pub const EE_MASK: u64

Unshifted bitmask of ee.

pub const EE_SHIFT: usize = 25

Bit shift (i.e., the low bit) of ee.

pub const EIS_MASK: u64

Unshifted bitmask of eis.

pub const EIS_SHIFT: usize = 22

Bit shift (i.e., the low bit) of eis.

pub const IESB_MASK: u64

Unshifted bitmask of iesb.

pub const IESB_SHIFT: usize = 21

Bit shift (i.e., the low bit) of iesb.

pub const WXN_MASK: u64

Unshifted bitmask of wxn.

pub const WXN_SHIFT: usize = 19

Bit shift (i.e., the low bit) of wxn.

pub const DZE_MASK: u64

Unshifted bitmask of dze.

pub const DZE_SHIFT: usize = 14

Bit shift (i.e., the low bit) of dze.

pub const ENDB_MASK: u64

Unshifted bitmask of endb.

pub const ENDB_SHIFT: usize = 13

Bit shift (i.e., the low bit) of endb.

pub const I_MASK: u64

Unshifted bitmask of i.

pub const I_SHIFT: usize = 12

Bit shift (i.e., the low bit) of i.

pub const EOS_MASK: u64

Unshifted bitmask of eos.

pub const EOS_SHIFT: usize = 11

Bit shift (i.e., the low bit) of eos.

pub const NAA_MASK: u64

Unshifted bitmask of naa.

pub const NAA_SHIFT: usize = 6

Bit shift (i.e., the low bit) of naa.

pub const SA_MASK: u64

Unshifted bitmask of sa.

pub const SA_SHIFT: usize = 3

Bit shift (i.e., the low bit) of sa.

pub const C_MASK: u64

Unshifted bitmask of c.

pub const C_SHIFT: usize = 2

Bit shift (i.e., the low bit) of c.

pub const A_MASK: u64

Unshifted bitmask of a.

pub const A_SHIFT: usize = 1

Bit shift (i.e., the low bit) of a.

pub const M_MASK: u64

Unshifted bitmask of m.

pub const M_SHIFT: usize = 0

Bit shift (i.e., the low bit) of m.

pub const FIELDS: [FieldMetadata<u64>; 26]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn spintmask(&self) -> bool

The value of SystemControlRegisterEl362.

pub const fn set_spintmask(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl362.

pub const fn nmi(&self) -> bool

The value of SystemControlRegisterEl361.

pub const fn set_nmi(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl361.

pub const fn tsco(&self) -> bool

The value of SystemControlRegisterEl359.

pub const fn set_tsco(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl359.

pub const fn tme(&self) -> bool

The value of SystemControlRegisterEl353.

pub const fn set_tme(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl353.

pub const fn tmt(&self) -> bool

The value of SystemControlRegisterEl351.

pub const fn set_tmt(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl351.

pub const fn dsbss(&self) -> bool

The value of SystemControlRegisterEl344.

pub const fn set_dsbss(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl344.

pub const fn ata(&self) -> bool

The value of SystemControlRegisterEl343.

pub const fn set_ata(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl343.

pub fn tcf(&self) -> TagCheckFault

The value of SystemControlRegisterEl3[41:40].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tcf to recover from invalid bit patterns.

pub fn try_tcf(&self) -> Result<TagCheckFault, InvalidBits<u8>>

Fallible variant of Self::tcf.

pub fn set_tcf(&mut self, value: TagCheckFault) -> &mut Self

Sets the value of SystemControlRegisterEl3[41:40].

pub const fn itfsb(&self) -> bool

The value of SystemControlRegisterEl337.

pub const fn set_itfsb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl337.

pub const fn bt(&self) -> bool

The value of SystemControlRegisterEl336.

pub const fn set_bt(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl336.

pub const fn enia(&self) -> bool

The value of SystemControlRegisterEl331.

pub const fn set_enia(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl331.

pub const fn enib(&self) -> bool

The value of SystemControlRegisterEl330.

pub const fn set_enib(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl330.

pub const fn enda(&self) -> bool

The value of SystemControlRegisterEl327.

pub const fn set_enda(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl327.

pub const fn ee(&self) -> bool

The value of SystemControlRegisterEl325.

pub const fn set_ee(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl325.

pub const fn eis(&self) -> bool

The value of SystemControlRegisterEl322.

pub const fn set_eis(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl322.

pub const fn iesb(&self) -> bool

The value of SystemControlRegisterEl321.

pub const fn set_iesb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl321.

pub const fn wxn(&self) -> bool

The value of SystemControlRegisterEl319.

pub const fn set_wxn(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl319.

pub const fn dze(&self) -> bool

The value of SystemControlRegisterEl314.

pub const fn set_dze(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl314.

pub const fn endb(&self) -> bool

The value of SystemControlRegisterEl313.

pub const fn set_endb(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl313.

pub const fn i(&self) -> bool

The value of SystemControlRegisterEl312.

pub const fn set_i(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl312.

pub const fn eos(&self) -> bool

The value of SystemControlRegisterEl311.

pub const fn set_eos(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl311.

pub const fn naa(&self) -> bool

The value of SystemControlRegisterEl36.

pub const fn set_naa(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl36.

pub const fn sa(&self) -> bool

The value of SystemControlRegisterEl33.

pub const fn set_sa(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl33.

pub const fn c(&self) -> bool

The value of SystemControlRegisterEl32.

pub const fn set_c(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl32.

pub const fn a(&self) -> bool

The value of SystemControlRegisterEl31.

pub const fn set_a(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl31.

pub const fn m(&self) -> bool

The value of SystemControlRegisterEl30.

pub const fn set_m(&mut self, value: bool) -> &mut Self

Sets the value of SystemControlRegisterEl30.

Source

impl SystemControlRegisterEl3

pub fn iter(&self) -> SystemControlRegisterEl3Iter

Returns an iterator over (metadata, value) pairs for each field.