TranslationControlRegisterEl1

Struct TranslationControlRegisterEl1 

pub struct TranslationControlRegisterEl1(/* private fields */);
The layout of TCR_EL1.

Implementations

Source

impl TranslationControlRegisterEl1

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const MTX1_MASK: u64

Unshifted bitmask of mtx1.

pub const MTX1_SHIFT: usize = 61

Bit shift (i.e., the low bit) of mtx1.

pub const MTX0_MASK: u64

Unshifted bitmask of mtx0.

pub const MTX0_SHIFT: usize = 60

Bit shift (i.e., the low bit) of mtx0.

pub const DS_MASK: u64

Unshifted bitmask of ds.

pub const DS_SHIFT: usize = 59

Bit shift (i.e., the low bit) of ds.

pub const TCMA1_MASK: u64

Unshifted bitmask of tcma1.

pub const TCMA1_SHIFT: usize = 58

Bit shift (i.e., the low bit) of tcma1.

pub const TCMA0_MASK: u64

Unshifted bitmask of tcma0.

pub const TCMA0_SHIFT: usize = 57

Bit shift (i.e., the low bit) of tcma0.

pub const E0PD1_MASK: u64

Unshifted bitmask of e0pd1.

pub const E0PD1_SHIFT: usize = 56

Bit shift (i.e., the low bit) of e0pd1.

pub const E0PD0_MASK: u64

Unshifted bitmask of e0pd0.

pub const E0PD0_SHIFT: usize = 55

Bit shift (i.e., the low bit) of e0pd0.

pub const NFD1_MASK: u64

Unshifted bitmask of nfd1.

pub const NFD1_SHIFT: usize = 54

Bit shift (i.e., the low bit) of nfd1.

pub const NFD0_MASK: u64

Unshifted bitmask of nfd0.

pub const NFD0_SHIFT: usize = 53

Bit shift (i.e., the low bit) of nfd0.

pub const TBID1_MASK: u64

Unshifted bitmask of tbid1.

pub const TBID1_SHIFT: usize = 52

Bit shift (i.e., the low bit) of tbid1.

pub const TBID0_MASK: u64

Unshifted bitmask of tbid0.

pub const TBID0_SHIFT: usize = 51

Bit shift (i.e., the low bit) of tbid0.

pub const HWU162_MASK: u64

Unshifted bitmask of hwu162.

pub const HWU162_SHIFT: usize = 50

Bit shift (i.e., the low bit) of hwu162.

pub const HWU161_MASK: u64

Unshifted bitmask of hwu161.

pub const HWU161_SHIFT: usize = 49

Bit shift (i.e., the low bit) of hwu161.

pub const HWU160_MASK: u64

Unshifted bitmask of hwu160.

pub const HWU160_SHIFT: usize = 48

Bit shift (i.e., the low bit) of hwu160.

pub const HWU159_MASK: u64

Unshifted bitmask of hwu159.

pub const HWU159_SHIFT: usize = 47

Bit shift (i.e., the low bit) of hwu159.

pub const HWU062_MASK: u64

Unshifted bitmask of hwu062.

pub const HWU062_SHIFT: usize = 46

Bit shift (i.e., the low bit) of hwu062.

pub const HWU061_MASK: u64

Unshifted bitmask of hwu061.

pub const HWU061_SHIFT: usize = 45

Bit shift (i.e., the low bit) of hwu061.

pub const HWU060_MASK: u64

Unshifted bitmask of hwu060.

pub const HWU060_SHIFT: usize = 44

Bit shift (i.e., the low bit) of hwu060.

pub const HWU059_MASK: u64

Unshifted bitmask of hwu059.

pub const HWU059_SHIFT: usize = 43

Bit shift (i.e., the low bit) of hwu059.

pub const HPD1_MASK: u64

Unshifted bitmask of hpd1.

pub const HPD1_SHIFT: usize = 42

Bit shift (i.e., the low bit) of hpd1.

pub const HPD0_MASK: u64

Unshifted bitmask of hpd0.

pub const HPD0_SHIFT: usize = 41

Bit shift (i.e., the low bit) of hpd0.

pub const HD_MASK: u64

Unshifted bitmask of hd.

pub const HD_SHIFT: usize = 40

Bit shift (i.e., the low bit) of hd.

pub const HA_MASK: u64

Unshifted bitmask of ha.

pub const HA_SHIFT: usize = 39

Bit shift (i.e., the low bit) of ha.

pub const TBI1_MASK: u64

Unshifted bitmask of tbi1.

pub const TBI1_SHIFT: usize = 38

Bit shift (i.e., the low bit) of tbi1.

pub const TBI0_MASK: u64

Unshifted bitmask of tbi0.

pub const TBI0_SHIFT: usize = 37

Bit shift (i.e., the low bit) of tbi0.

pub const ASID_SIZE_MASK: u64

Unshifted bitmask of asid_size.

pub const ASID_SIZE_SHIFT: usize = 36

Bit shift (i.e., the low bit) of asid_size.

pub const IPS_MASK: u64

Unshifted bitmask of ips.

pub const IPS_SHIFT: usize = 32

Bit shift (i.e., the low bit) of ips.

pub const TG1_MASK: u64

Unshifted bitmask of tg1.

pub const TG1_SHIFT: usize = 30

Bit shift (i.e., the low bit) of tg1.

pub const SH1_MASK: u64

Unshifted bitmask of sh1.

pub const SH1_SHIFT: usize = 28

Bit shift (i.e., the low bit) of sh1.

pub const ORGN1_MASK: u64

Unshifted bitmask of orgn1.

pub const ORGN1_SHIFT: usize = 26

Bit shift (i.e., the low bit) of orgn1.

pub const IRGN1_MASK: u64

Unshifted bitmask of irgn1.

pub const IRGN1_SHIFT: usize = 24

Bit shift (i.e., the low bit) of irgn1.

pub const EPD1_MASK: u64

Unshifted bitmask of epd1.

pub const EPD1_SHIFT: usize = 23

Bit shift (i.e., the low bit) of epd1.

pub const A1_MASK: u64

Unshifted bitmask of a1.

pub const A1_SHIFT: usize = 22

Bit shift (i.e., the low bit) of a1.

pub const T1SZ_MASK: u64

Unshifted bitmask of t1sz.

pub const T1SZ_SHIFT: usize = 16

Bit shift (i.e., the low bit) of t1sz.

pub const TG0_MASK: u64

Unshifted bitmask of tg0.

pub const TG0_SHIFT: usize = 14

Bit shift (i.e., the low bit) of tg0.

pub const SH0_MASK: u64

Unshifted bitmask of sh0.

pub const SH0_SHIFT: usize = 12

Bit shift (i.e., the low bit) of sh0.

pub const ORGN0_MASK: u64

Unshifted bitmask of orgn0.

pub const ORGN0_SHIFT: usize = 10

Bit shift (i.e., the low bit) of orgn0.

pub const IRGN0_MASK: u64

Unshifted bitmask of irgn0.

pub const IRGN0_SHIFT: usize = 8

Bit shift (i.e., the low bit) of irgn0.

pub const EPD0_MASK: u64

Unshifted bitmask of epd0.

pub const EPD0_SHIFT: usize = 7

Bit shift (i.e., the low bit) of epd0.

pub const T0SZ_MASK: u64

Unshifted bitmask of t0sz.

pub const T0SZ_SHIFT: usize = 0

Bit shift (i.e., the low bit) of t0sz.

pub const FIELDS: [FieldMetadata<u64>; 40]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn mtx1(&self) -> bool

The value of TranslationControlRegisterEl161.

pub const fn set_mtx1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl161.

pub const fn mtx0(&self) -> bool

The value of TranslationControlRegisterEl160.

pub const fn set_mtx0(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl160.

pub const fn ds(&self) -> bool

The value of TranslationControlRegisterEl159.

pub const fn set_ds(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl159.

pub const fn tcma1(&self) -> bool

The value of TranslationControlRegisterEl158.

pub const fn set_tcma1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl158.

pub const fn tcma0(&self) -> bool

The value of TranslationControlRegisterEl157.

pub const fn set_tcma0(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl157.

pub const fn e0pd1(&self) -> bool

The value of TranslationControlRegisterEl156.

pub const fn set_e0pd1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl156.

pub const fn e0pd0(&self) -> bool

The value of TranslationControlRegisterEl155.

pub const fn set_e0pd0(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl155.

pub const fn nfd1(&self) -> bool

The value of TranslationControlRegisterEl154.

pub const fn set_nfd1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl154.

pub const fn nfd0(&self) -> bool

The value of TranslationControlRegisterEl153.

pub const fn set_nfd0(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl153.

pub const fn tbid1(&self) -> bool

The value of TranslationControlRegisterEl152.

pub const fn set_tbid1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl152.

pub const fn tbid0(&self) -> bool

The value of TranslationControlRegisterEl151.

pub const fn set_tbid0(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl151.

pub const fn hwu162(&self) -> bool

The value of TranslationControlRegisterEl150.

pub const fn set_hwu162(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl150.

pub const fn hwu161(&self) -> bool

The value of TranslationControlRegisterEl149.

pub const fn set_hwu161(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl149.

pub const fn hwu160(&self) -> bool

The value of TranslationControlRegisterEl148.

pub const fn set_hwu160(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl148.

pub const fn hwu159(&self) -> bool

The value of TranslationControlRegisterEl147.

pub const fn set_hwu159(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl147.

pub const fn hwu062(&self) -> bool

The value of TranslationControlRegisterEl146.

pub const fn set_hwu062(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl146.

pub const fn hwu061(&self) -> bool

The value of TranslationControlRegisterEl145.

pub const fn set_hwu061(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl145.

pub const fn hwu060(&self) -> bool

The value of TranslationControlRegisterEl144.

pub const fn set_hwu060(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl144.

pub const fn hwu059(&self) -> bool

The value of TranslationControlRegisterEl143.

pub const fn set_hwu059(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl143.

pub const fn hpd1(&self) -> bool

The value of TranslationControlRegisterEl142.

pub const fn set_hpd1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl142.

pub const fn hpd0(&self) -> bool

The value of TranslationControlRegisterEl141.

pub const fn set_hpd0(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl141.

pub const fn hd(&self) -> bool

The value of TranslationControlRegisterEl140.

pub const fn set_hd(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl140.

pub const fn ha(&self) -> bool

The value of TranslationControlRegisterEl139.

pub const fn set_ha(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl139.

pub const fn tbi1(&self) -> bool

The value of TranslationControlRegisterEl138.

pub const fn set_tbi1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl138.

pub const fn tbi0(&self) -> bool

The value of TranslationControlRegisterEl137.

pub const fn set_tbi0(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl137.

pub const fn asid_size(&self) -> bool

The value of TranslationControlRegisterEl136.

pub const fn set_asid_size(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl136.

pub fn ips(&self) -> PhysicalAddressSize

The value of TranslationControlRegisterEl1[34:32].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ips to recover from invalid bit patterns.

pub fn try_ips(&self) -> Result<PhysicalAddressSize, InvalidBits<u8>>

Fallible variant of Self::ips.

pub fn set_ips(&mut self, value: PhysicalAddressSize) -> &mut Self

Sets the value of TranslationControlRegisterEl1[34:32].

pub fn tg1(&self) -> TcrTg1Value

The value of TranslationControlRegisterEl1[31:30].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tg1 to recover from invalid bit patterns.

pub fn try_tg1(&self) -> Result<TcrTg1Value, InvalidBits<u8>>

Fallible variant of Self::tg1.

pub fn set_tg1(&mut self, value: TcrTg1Value) -> &mut Self

Sets the value of TranslationControlRegisterEl1[31:30].

pub fn sh1(&self) -> ShareabilityAttribute

The value of TranslationControlRegisterEl1[29:28].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sh1 to recover from invalid bit patterns.

pub fn try_sh1(&self) -> Result<ShareabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::sh1.

pub fn set_sh1(&mut self, value: ShareabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl1[29:28].

pub fn orgn1(&self) -> CacheabilityAttribute

The value of TranslationControlRegisterEl1[27:26].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_orgn1 to recover from invalid bit patterns.

pub fn try_orgn1(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::orgn1.

pub fn set_orgn1(&mut self, value: CacheabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl1[27:26].

pub fn irgn1(&self) -> CacheabilityAttribute

The value of TranslationControlRegisterEl1[25:24].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_irgn1 to recover from invalid bit patterns.

pub fn try_irgn1(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::irgn1.

pub fn set_irgn1(&mut self, value: CacheabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl1[25:24].

pub const fn epd1(&self) -> bool

The value of TranslationControlRegisterEl123.

pub const fn set_epd1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl123.

pub const fn a1(&self) -> bool

The value of TranslationControlRegisterEl122.

pub const fn set_a1(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl122.

pub const fn t1sz(&self) -> u8

The value of TranslationControlRegisterEl1[21:16].

pub const fn set_t1sz(&mut self, value: u8) -> &mut Self

Sets the value of TranslationControlRegisterEl1[21:16].

pub fn tg0(&self) -> TcrTg0Value

The value of TranslationControlRegisterEl1[15:14].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tg0 to recover from invalid bit patterns.

pub fn try_tg0(&self) -> Result<TcrTg0Value, InvalidBits<u8>>

Fallible variant of Self::tg0.

pub fn set_tg0(&mut self, value: TcrTg0Value) -> &mut Self

Sets the value of TranslationControlRegisterEl1[15:14].

pub fn sh0(&self) -> ShareabilityAttribute

The value of TranslationControlRegisterEl1[13:12].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sh0 to recover from invalid bit patterns.

pub fn try_sh0(&self) -> Result<ShareabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::sh0.

pub fn set_sh0(&mut self, value: ShareabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl1[13:12].

pub fn orgn0(&self) -> CacheabilityAttribute

The value of TranslationControlRegisterEl1[11:10].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_orgn0 to recover from invalid bit patterns.

pub fn try_orgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::orgn0.

pub fn set_orgn0(&mut self, value: CacheabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl1[11:10].

pub fn irgn0(&self) -> CacheabilityAttribute

The value of TranslationControlRegisterEl1[9:8].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_irgn0 to recover from invalid bit patterns.

pub fn try_irgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::irgn0.

pub fn set_irgn0(&mut self, value: CacheabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl1[9:8].

pub const fn epd0(&self) -> bool

The value of TranslationControlRegisterEl17.

pub const fn set_epd0(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl17.

pub const fn t0sz(&self) -> u8

The value of TranslationControlRegisterEl1[5:0].

pub const fn set_t0sz(&mut self, value: u8) -> &mut Self

Sets the value of TranslationControlRegisterEl1[5:0].

Source

impl TranslationControlRegisterEl1

pub fn iter(&self) -> TranslationControlRegisterEl1Iter

Returns an iterator over (metadata, value) pairs for each field.