TranslationControlRegisterEl2

Struct TranslationControlRegisterEl2 

pub struct TranslationControlRegisterEl2(/* private fields */);
The layout of TCR_EL2.

Implementations

Source

impl TranslationControlRegisterEl2

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const MTX_MASK: u64

Unshifted bitmask of mtx.

pub const MTX_SHIFT: usize = 33

Bit shift (i.e., the low bit) of mtx.

pub const DS_MASK: u64

Unshifted bitmask of ds.

pub const DS_SHIFT: usize = 32

Bit shift (i.e., the low bit) of ds.

pub const TCMA_MASK: u64

Unshifted bitmask of tcma.

pub const TCMA_SHIFT: usize = 30

Bit shift (i.e., the low bit) of tcma.

pub const TBID_MASK: u64

Unshifted bitmask of tbid.

pub const TBID_SHIFT: usize = 29

Bit shift (i.e., the low bit) of tbid.

pub const HWU62_MASK: u64

Unshifted bitmask of hwu62.

pub const HWU62_SHIFT: usize = 28

Bit shift (i.e., the low bit) of hwu62.

pub const HWU61_MASK: u64

Unshifted bitmask of hwu61.

pub const HWU61_SHIFT: usize = 27

Bit shift (i.e., the low bit) of hwu61.

pub const HWU60_MASK: u64

Unshifted bitmask of hwu60.

pub const HWU60_SHIFT: usize = 26

Bit shift (i.e., the low bit) of hwu60.

pub const HWU59_MASK: u64

Unshifted bitmask of hwu59.

pub const HWU59_SHIFT: usize = 25

Bit shift (i.e., the low bit) of hwu59.

pub const HPD_MASK: u64

Unshifted bitmask of hpd.

pub const HPD_SHIFT: usize = 24

Bit shift (i.e., the low bit) of hpd.

pub const HD_MASK: u64

Unshifted bitmask of hd.

pub const HD_SHIFT: usize = 22

Bit shift (i.e., the low bit) of hd.

pub const HA_MASK: u64

Unshifted bitmask of ha.

pub const HA_SHIFT: usize = 21

Bit shift (i.e., the low bit) of ha.

pub const TBI_MASK: u64

Unshifted bitmask of tbi.

pub const TBI_SHIFT: usize = 20

Bit shift (i.e., the low bit) of tbi.

pub const PS_MASK: u64

Unshifted bitmask of ps.

pub const PS_SHIFT: usize = 16

Bit shift (i.e., the low bit) of ps.

pub const TG0_MASK: u64

Unshifted bitmask of tg0.

pub const TG0_SHIFT: usize = 14

Bit shift (i.e., the low bit) of tg0.

pub const SH0_MASK: u64

Unshifted bitmask of sh0.

pub const SH0_SHIFT: usize = 12

Bit shift (i.e., the low bit) of sh0.

pub const ORGN0_MASK: u64

Unshifted bitmask of orgn0.

pub const ORGN0_SHIFT: usize = 10

Bit shift (i.e., the low bit) of orgn0.

pub const IRGN0_MASK: u64

Unshifted bitmask of irgn0.

pub const IRGN0_SHIFT: usize = 8

Bit shift (i.e., the low bit) of irgn0.

pub const T0SZ_MASK: u64

Unshifted bitmask of t0sz.

pub const T0SZ_SHIFT: usize = 0

Bit shift (i.e., the low bit) of t0sz.

pub const FIELDS: [FieldMetadata<u64>; 18]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn mtx(&self) -> bool

The value of TranslationControlRegisterEl233.

pub const fn set_mtx(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl233.

pub const fn ds(&self) -> bool

The value of TranslationControlRegisterEl232.

pub const fn set_ds(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl232.

pub const fn tcma(&self) -> bool

The value of TranslationControlRegisterEl230.

pub const fn set_tcma(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl230.

pub const fn tbid(&self) -> bool

The value of TranslationControlRegisterEl229.

pub const fn set_tbid(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl229.

pub const fn hwu62(&self) -> bool

The value of TranslationControlRegisterEl228.

pub const fn set_hwu62(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl228.

pub const fn hwu61(&self) -> bool

The value of TranslationControlRegisterEl227.

pub const fn set_hwu61(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl227.

pub const fn hwu60(&self) -> bool

The value of TranslationControlRegisterEl226.

pub const fn set_hwu60(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl226.

pub const fn hwu59(&self) -> bool

The value of TranslationControlRegisterEl225.

pub const fn set_hwu59(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl225.

pub const fn hpd(&self) -> bool

The value of TranslationControlRegisterEl224.

pub const fn set_hpd(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl224.

pub const fn hd(&self) -> bool

The value of TranslationControlRegisterEl222.

pub const fn set_hd(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl222.

pub const fn ha(&self) -> bool

The value of TranslationControlRegisterEl221.

pub const fn set_ha(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl221.

pub const fn tbi(&self) -> bool

The value of TranslationControlRegisterEl220.

pub const fn set_tbi(&mut self, value: bool) -> &mut Self

Sets the value of TranslationControlRegisterEl220.

pub fn ps(&self) -> PhysicalAddressSize

The value of TranslationControlRegisterEl2[18:16].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ps to recover from invalid bit patterns.

pub fn try_ps(&self) -> Result<PhysicalAddressSize, InvalidBits<u8>>

Fallible variant of Self::ps.

pub fn set_ps(&mut self, value: PhysicalAddressSize) -> &mut Self

Sets the value of TranslationControlRegisterEl2[18:16].

pub fn tg0(&self) -> TcrTg0Value

The value of TranslationControlRegisterEl2[15:14].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tg0 to recover from invalid bit patterns.

pub fn try_tg0(&self) -> Result<TcrTg0Value, InvalidBits<u8>>

Fallible variant of Self::tg0.

pub fn set_tg0(&mut self, value: TcrTg0Value) -> &mut Self

Sets the value of TranslationControlRegisterEl2[15:14].

pub fn sh0(&self) -> ShareabilityAttribute

The value of TranslationControlRegisterEl2[13:12].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sh0 to recover from invalid bit patterns.

pub fn try_sh0(&self) -> Result<ShareabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::sh0.

pub fn set_sh0(&mut self, value: ShareabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl2[13:12].

pub fn orgn0(&self) -> CacheabilityAttribute

The value of TranslationControlRegisterEl2[11:10].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_orgn0 to recover from invalid bit patterns.

pub fn try_orgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::orgn0.

pub fn set_orgn0(&mut self, value: CacheabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl2[11:10].

pub fn irgn0(&self) -> CacheabilityAttribute

The value of TranslationControlRegisterEl2[9:8].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_irgn0 to recover from invalid bit patterns.

pub fn try_irgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::irgn0.

pub fn set_irgn0(&mut self, value: CacheabilityAttribute) -> &mut Self

Sets the value of TranslationControlRegisterEl2[9:8].

pub const fn t0sz(&self) -> u8

The value of TranslationControlRegisterEl2[5:0].

pub const fn set_t0sz(&mut self, value: u8) -> &mut Self

Sets the value of TranslationControlRegisterEl2[5:0].

Source

impl TranslationControlRegisterEl2

pub fn iter(&self) -> TranslationControlRegisterEl2Iter

Returns an iterator over (metadata, value) pairs for each field.