VirtualizationTranslationControlRegister

Struct VirtualizationTranslationControlRegister 

pub struct VirtualizationTranslationControlRegister(/* private fields */);
The layout of VTCR_EL2.

Implementations

Source

impl VirtualizationTranslationControlRegister

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const HDBSS_MASK: u64

Unshifted bitmask of hdbss.

pub const HDBSS_SHIFT: usize = 45

Bit shift (i.e., the low bit) of hdbss.

pub const HAFT_MASK: u64

Unshifted bitmask of haft.

pub const HAFT_SHIFT: usize = 44

Bit shift (i.e., the low bit) of haft.

pub const TL0_MASK: u64

Unshifted bitmask of tl0.

pub const TL0_SHIFT: usize = 41

Bit shift (i.e., the low bit) of tl0.

pub const GCSH_MASK: u64

Unshifted bitmask of gcsh.

pub const GCSH_SHIFT: usize = 40

Bit shift (i.e., the low bit) of gcsh.

pub const D128_MASK: u64

Unshifted bitmask of d128.

pub const D128_SHIFT: usize = 38

Bit shift (i.e., the low bit) of d128.

pub const S2POE_MASK: u64

Unshifted bitmask of s2poe.

pub const S2POE_SHIFT: usize = 37

Bit shift (i.e., the low bit) of s2poe.

pub const S2PIE_MASK: u64

Unshifted bitmask of s2pie.

pub const S2PIE_SHIFT: usize = 36

Bit shift (i.e., the low bit) of s2pie.

pub const TL1_MASK: u64

Unshifted bitmask of tl1.

pub const TL1_SHIFT: usize = 35

Bit shift (i.e., the low bit) of tl1.

pub const ASSURED_ONLY_MASK: u64

Unshifted bitmask of assured_only.

pub const ASSURED_ONLY_SHIFT: usize = 34

Bit shift (i.e., the low bit) of assured_only.

pub const SL2_MASK: u64

Unshifted bitmask of sl2.

pub const SL2_SHIFT: usize = 33

Bit shift (i.e., the low bit) of sl2.

pub const DS_MASK: u64

Unshifted bitmask of ds.

pub const DS_SHIFT: usize = 32

Bit shift (i.e., the low bit) of ds.

pub const NSA_MASK: u64

Unshifted bitmask of nsa.

pub const NSA_SHIFT: usize = 30

Bit shift (i.e., the low bit) of nsa.

pub const NSW_MASK: u64

Unshifted bitmask of nsw.

pub const NSW_SHIFT: usize = 29

Bit shift (i.e., the low bit) of nsw.

pub const HWU62_MASK: u64

Unshifted bitmask of hwu62.

pub const HWU62_SHIFT: usize = 28

Bit shift (i.e., the low bit) of hwu62.

pub const HWU61_MASK: u64

Unshifted bitmask of hwu61.

pub const HWU61_SHIFT: usize = 27

Bit shift (i.e., the low bit) of hwu61.

pub const HWU60_MASK: u64

Unshifted bitmask of hwu60.

pub const HWU60_SHIFT: usize = 26

Bit shift (i.e., the low bit) of hwu60.

pub const HWU59_MASK: u64

Unshifted bitmask of hwu59.

pub const HWU59_SHIFT: usize = 25

Bit shift (i.e., the low bit) of hwu59.

pub const HD_MASK: u64

Unshifted bitmask of hd.

pub const HD_SHIFT: usize = 22

Bit shift (i.e., the low bit) of hd.

pub const HA_MASK: u64

Unshifted bitmask of ha.

pub const HA_SHIFT: usize = 21

Bit shift (i.e., the low bit) of ha.

pub const VS_MASK: u64

Unshifted bitmask of vs.

pub const VS_SHIFT: usize = 19

Bit shift (i.e., the low bit) of vs.

pub const PS_MASK: u64

Unshifted bitmask of ps.

pub const PS_SHIFT: usize = 16

Bit shift (i.e., the low bit) of ps.

pub const TG0_MASK: u64

Unshifted bitmask of tg0.

pub const TG0_SHIFT: usize = 14

Bit shift (i.e., the low bit) of tg0.

pub const SH0_MASK: u64

Unshifted bitmask of sh0.

pub const SH0_SHIFT: usize = 12

Bit shift (i.e., the low bit) of sh0.

pub const ORGN0_MASK: u64

Unshifted bitmask of orgn0.

pub const ORGN0_SHIFT: usize = 10

Bit shift (i.e., the low bit) of orgn0.

pub const IRGN0_MASK: u64

Unshifted bitmask of irgn0.

pub const IRGN0_SHIFT: usize = 8

Bit shift (i.e., the low bit) of irgn0.

pub const SL0_MASK: u64

Unshifted bitmask of sl0.

pub const SL0_SHIFT: usize = 6

Bit shift (i.e., the low bit) of sl0.

pub const T0SZ_MASK: u64

Unshifted bitmask of t0sz.

pub const T0SZ_SHIFT: usize = 0

Bit shift (i.e., the low bit) of t0sz.

pub const FIELDS: [FieldMetadata<u64>; 27]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn hdbss(&self) -> bool

The value of VirtualizationTranslationControlRegister45.

pub const fn set_hdbss(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister45.

pub const fn haft(&self) -> bool

The value of VirtualizationTranslationControlRegister44.

pub const fn set_haft(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister44.

pub const fn tl0(&self) -> bool

The value of VirtualizationTranslationControlRegister41.

pub const fn set_tl0(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister41.

pub const fn gcsh(&self) -> bool

The value of VirtualizationTranslationControlRegister40.

pub const fn set_gcsh(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister40.

pub const fn d128(&self) -> bool

The value of VirtualizationTranslationControlRegister38.

pub const fn set_d128(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister38.

pub const fn s2poe(&self) -> bool

The value of VirtualizationTranslationControlRegister37.

pub const fn set_s2poe(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister37.

pub const fn s2pie(&self) -> bool

The value of VirtualizationTranslationControlRegister36.

pub const fn set_s2pie(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister36.

pub const fn tl1(&self) -> bool

The value of VirtualizationTranslationControlRegister35.

pub const fn set_tl1(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister35.

pub const fn assured_only(&self) -> bool

The value of VirtualizationTranslationControlRegister34.

pub const fn set_assured_only(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister34.

pub const fn sl2(&self) -> bool

The value of VirtualizationTranslationControlRegister33.

pub const fn set_sl2(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister33.

pub const fn ds(&self) -> bool

The value of VirtualizationTranslationControlRegister32.

pub const fn set_ds(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister32.

pub const fn nsa(&self) -> bool

The value of VirtualizationTranslationControlRegister30.

pub const fn set_nsa(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister30.

pub const fn nsw(&self) -> bool

The value of VirtualizationTranslationControlRegister29.

pub const fn set_nsw(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister29.

pub const fn hwu62(&self) -> bool

The value of VirtualizationTranslationControlRegister28.

pub const fn set_hwu62(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister28.

pub const fn hwu61(&self) -> bool

The value of VirtualizationTranslationControlRegister27.

pub const fn set_hwu61(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister27.

pub const fn hwu60(&self) -> bool

The value of VirtualizationTranslationControlRegister26.

pub const fn set_hwu60(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister26.

pub const fn hwu59(&self) -> bool

The value of VirtualizationTranslationControlRegister25.

pub const fn set_hwu59(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister25.

pub const fn hd(&self) -> bool

The value of VirtualizationTranslationControlRegister22.

pub const fn set_hd(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister22.

pub const fn ha(&self) -> bool

The value of VirtualizationTranslationControlRegister21.

pub const fn set_ha(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister21.

pub const fn vs(&self) -> bool

The value of VirtualizationTranslationControlRegister19.

pub const fn set_vs(&mut self, value: bool) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister19.

pub fn ps(&self) -> PhysicalAddressSize

The value of VirtualizationTranslationControlRegister[18:16].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ps to recover from invalid bit patterns.

pub fn try_ps(&self) -> Result<PhysicalAddressSize, InvalidBits<u8>>

Fallible variant of Self::ps.

pub fn set_ps(&mut self, value: PhysicalAddressSize) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister[18:16].

pub fn tg0(&self) -> TcrTg0Value

The value of VirtualizationTranslationControlRegister[15:14].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tg0 to recover from invalid bit patterns.

pub fn try_tg0(&self) -> Result<TcrTg0Value, InvalidBits<u8>>

Fallible variant of Self::tg0.

pub fn set_tg0(&mut self, value: TcrTg0Value) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister[15:14].

pub fn sh0(&self) -> ShareabilityAttribute

The value of VirtualizationTranslationControlRegister[13:12].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sh0 to recover from invalid bit patterns.

pub fn try_sh0(&self) -> Result<ShareabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::sh0.

pub fn set_sh0(&mut self, value: ShareabilityAttribute) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister[13:12].

pub fn orgn0(&self) -> CacheabilityAttribute

The value of VirtualizationTranslationControlRegister[11:10].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_orgn0 to recover from invalid bit patterns.

pub fn try_orgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::orgn0.

pub fn set_orgn0(&mut self, value: CacheabilityAttribute) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister[11:10].

pub fn irgn0(&self) -> CacheabilityAttribute

The value of VirtualizationTranslationControlRegister[9:8].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_irgn0 to recover from invalid bit patterns.

pub fn try_irgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>

Fallible variant of Self::irgn0.

pub fn set_irgn0(&mut self, value: CacheabilityAttribute) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister[9:8].

pub const fn sl0(&self) -> u8

The value of VirtualizationTranslationControlRegister[7:6].

pub const fn set_sl0(&mut self, value: u8) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister[7:6].

pub const fn t0sz(&self) -> u8

The value of VirtualizationTranslationControlRegister[5:0].

pub const fn set_t0sz(&mut self, value: u8) -> &mut Self

Sets the value of VirtualizationTranslationControlRegister[5:0].

Source

impl VirtualizationTranslationControlRegister

pub fn iter(&self) -> VirtualizationTranslationControlRegisterIter

Returns an iterator over (metadata, value) pairs for each field.