RiscvFeature

Enum RiscvFeature 

#[repr(u32)]
pub enum RiscvFeature { Sstc = 0, Svpbmt = 1, Vector = 2, Zicbom = 3, Zicboz = 4, Zicntr = 5, }
An enumeration of RISC-V features.

This is not intended to be exhaustive, but rather to include the features that the kernel currently depends on.

The discriminants must match arch::RiscvFeature in <lib/arch/riscv64/feature.h>, which is where they are checked.

Variants



Sstc = 0

Extension for supervisor based timer.



Svpbmt = 1

SuperVisor extension for Page-Based Memory Types.



Vector = 2

The standard V extension for vector support.



Zicbom = 3

Cache-Block Management Operations.



Zicboz = 4

Cache-Block Zero Operations.



Zicntr = 5

Counter CSRs are accessible.

Implementations

Source

impl RiscvFeature

pub const ALL: [RiscvFeature; 6]

Every feature, in discriminant order.