pub struct RiscvFeatures { /* private fields */ }Expand description
A simple container abstraction around the set of RISC-V features.
Implementations
Sourceimpl RiscvFeatures
impl RiscvFeatures
Sourcepub const fn from_bits(bits: u64) -> Self
pub const fn from_bits(bits: u64) -> Self
Constructs a feature set from a raw bitmask, in which bit n records
support for the feature whose discriminant is n.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
The raw bitmask, in which bit n records support for the feature whose
discriminant is n.
Sourcepub const fn supports(&self, feature: RiscvFeature) -> bool
pub const fn supports(&self, feature: RiscvFeature) -> bool
Whether a given feature is supported.
Sourcepub fn set(&mut self, feature: RiscvFeature, supported: bool) -> &mut Self
pub fn set(&mut self, feature: RiscvFeature, supported: bool) -> &mut Self
Sets support for a given feature.
Sourcepub const fn cbom_size(&self) -> u16
pub const fn cbom_size(&self) -> u16
The cache block size for Cache-Block Management Operations, in bytes.
Sourcepub const fn cboz_size(&self) -> u16
pub const fn cboz_size(&self) -> u16
The cache block size for Cache-Block Zero Operations, in bytes.
Sourcepub fn set_cbom_size(&mut self, size: u16) -> &mut Self
pub fn set_cbom_size(&mut self, size: u16) -> &mut Self
Sets the Cache-Block Management Operations block size.
Sourcepub fn set_cboz_size(&mut self, size: u16) -> &mut Self
pub fn set_cboz_size(&mut self, size: u16) -> &mut Self
Sets the Cache-Block Zero Operations block size.