SupervisorAddressTranslationAndProtection

Struct SupervisorAddressTranslationAndProtection 

pub struct SupervisorAddressTranslationAndProtection(/* private fields */);
The layout of SATP.

Implementations

Source

impl SupervisorAddressTranslationAndProtection

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const MODE_MASK: u64

Unshifted bitmask of mode.

pub const MODE_SHIFT: usize = 60

Bit shift (i.e., the low bit) of mode.

pub const ASID_MASK: u64

Unshifted bitmask of asid.

pub const ASID_SHIFT: usize = 44

Bit shift (i.e., the low bit) of asid.

pub const PPN_MASK: u64

Unshifted bitmask of ppn.

pub const PPN_SHIFT: usize = 0

Bit shift (i.e., the low bit) of ppn.

pub const FIELDS: [FieldMetadata<u64>; 3]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub fn mode(&self) -> TranslationMode

The value of SupervisorAddressTranslationAndProtection[63:60].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_mode to recover from invalid bit patterns.

pub fn try_mode(&self) -> Result<TranslationMode, InvalidBits<u8>>

Fallible variant of Self::mode.

pub fn set_mode(&mut self, value: TranslationMode) -> &mut Self

Sets the value of SupervisorAddressTranslationAndProtection[63:60].

pub const fn asid(&self) -> u16

The value of SupervisorAddressTranslationAndProtection[59:44].

pub const fn set_asid(&mut self, value: u16) -> &mut Self

Sets the value of SupervisorAddressTranslationAndProtection[59:44].

pub const fn ppn(&self) -> u64

The value of SupervisorAddressTranslationAndProtection[43:0].

pub const fn set_ppn(&mut self, value: u64) -> &mut Self

Sets the value of SupervisorAddressTranslationAndProtection[43:0].

Source

impl SupervisorAddressTranslationAndProtection

pub fn iter(&self) -> SupervisorAddressTranslationAndProtectionIter

Returns an iterator over (metadata, value) pairs for each field.

Source

impl SupervisorAddressTranslationAndProtection

pub fn root_address(&self) -> u64

Returns the root page table physical address (PPN << 12).

pub fn set_root_address(&mut self, addr: u64) -> &mut Self

Sets the root page table physical address (must be 4KiB-aligned).