SupervisorStatus

Struct SupervisorStatus 

pub struct SupervisorStatus(/* private fields */);
The layout of SSTATUS.

Implementations

Source

impl SupervisorStatus

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const SD_MASK: u64

Unshifted bitmask of sd.

pub const SD_SHIFT: usize = 63

Bit shift (i.e., the low bit) of sd.

pub const UXL_MASK: u64

Unshifted bitmask of uxl.

pub const UXL_SHIFT: usize = 32

Bit shift (i.e., the low bit) of uxl.

pub const MXR_MASK: u64

Unshifted bitmask of mxr.

pub const MXR_SHIFT: usize = 19

Bit shift (i.e., the low bit) of mxr.

pub const SUM_MASK: u64

Unshifted bitmask of sum.

pub const SUM_SHIFT: usize = 18

Bit shift (i.e., the low bit) of sum.

pub const XS_MASK: u64

Unshifted bitmask of xs.

pub const XS_SHIFT: usize = 15

Bit shift (i.e., the low bit) of xs.

pub const FS_MASK: u64

Unshifted bitmask of fs.

pub const FS_SHIFT: usize = 13

Bit shift (i.e., the low bit) of fs.

pub const VS_MASK: u64

Unshifted bitmask of vs.

pub const VS_SHIFT: usize = 9

Bit shift (i.e., the low bit) of vs.

pub const SPP_MASK: u64

Unshifted bitmask of spp.

pub const SPP_SHIFT: usize = 8

Bit shift (i.e., the low bit) of spp.

pub const UBE_MASK: u64

Unshifted bitmask of ube.

pub const UBE_SHIFT: usize = 6

Bit shift (i.e., the low bit) of ube.

pub const SPIE_MASK: u64

Unshifted bitmask of spie.

pub const SPIE_SHIFT: usize = 5

Bit shift (i.e., the low bit) of spie.

pub const SIE_MASK: u64

Unshifted bitmask of sie.

pub const SIE_SHIFT: usize = 1

Bit shift (i.e., the low bit) of sie.

pub const FIELDS: [FieldMetadata<u64>; 11]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn sd(&self) -> bool

The value of SupervisorStatus63.

pub const fn set_sd(&mut self, value: bool) -> &mut Self

Sets the value of SupervisorStatus63.

pub fn uxl(&self) -> Xlen

The value of SupervisorStatus[33:32].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_uxl to recover from invalid bit patterns.

pub fn try_uxl(&self) -> Result<Xlen, InvalidBits<u8>>

Fallible variant of Self::uxl.

pub fn set_uxl(&mut self, value: Xlen) -> &mut Self

Sets the value of SupervisorStatus[33:32].

pub const fn mxr(&self) -> bool

The value of SupervisorStatus19.

pub const fn set_mxr(&mut self, value: bool) -> &mut Self

Sets the value of SupervisorStatus19.

pub const fn sum(&self) -> bool

The value of SupervisorStatus18.

pub const fn set_sum(&mut self, value: bool) -> &mut Self

Sets the value of SupervisorStatus18.

pub fn xs(&self) -> ExtensionStatus

The value of SupervisorStatus[16:15].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_xs to recover from invalid bit patterns.

pub fn try_xs(&self) -> Result<ExtensionStatus, InvalidBits<u8>>

Fallible variant of Self::xs.

pub fn set_xs(&mut self, value: ExtensionStatus) -> &mut Self

Sets the value of SupervisorStatus[16:15].

pub fn fs(&self) -> ExtensionStatus

The value of SupervisorStatus[14:13].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_fs to recover from invalid bit patterns.

pub fn try_fs(&self) -> Result<ExtensionStatus, InvalidBits<u8>>

Fallible variant of Self::fs.

pub fn set_fs(&mut self, value: ExtensionStatus) -> &mut Self

Sets the value of SupervisorStatus[14:13].

pub fn vs(&self) -> ExtensionStatus

The value of SupervisorStatus[10:9].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_vs to recover from invalid bit patterns.

pub fn try_vs(&self) -> Result<ExtensionStatus, InvalidBits<u8>>

Fallible variant of Self::vs.

pub fn set_vs(&mut self, value: ExtensionStatus) -> &mut Self

Sets the value of SupervisorStatus[10:9].

pub const fn spp(&self) -> bool

The value of SupervisorStatus8.

pub const fn set_spp(&mut self, value: bool) -> &mut Self

Sets the value of SupervisorStatus8.

pub const fn ube(&self) -> bool

The value of SupervisorStatus6.

pub const fn set_ube(&mut self, value: bool) -> &mut Self

Sets the value of SupervisorStatus6.

pub const fn spie(&self) -> bool

The value of SupervisorStatus5.

pub const fn set_spie(&mut self, value: bool) -> &mut Self

Sets the value of SupervisorStatus5.

pub const fn sie(&self) -> bool

The value of SupervisorStatus1.

pub const fn set_sie(&mut self, value: bool) -> &mut Self

Sets the value of SupervisorStatus1.

Source

impl SupervisorStatus

pub fn iter(&self) -> SupervisorStatusIter

Returns an iterator over (metadata, value) pairs for each field.