SupervisorTrapVector

Struct SupervisorTrapVector 

pub struct SupervisorTrapVector(/* private fields */);
The layout of STVEC.

Implementations

Source

impl SupervisorTrapVector

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const BASE_MASK: u64

Unshifted bitmask of base.

pub const BASE_SHIFT: usize = 2

Bit shift (i.e., the low bit) of base.

pub const MODE_MASK: u64

Unshifted bitmask of mode.

pub const MODE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of mode.

pub const FIELDS: [FieldMetadata<u64>; 2]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn base(&self) -> u64

The unshifted value of SupervisorTrapVector[63:2].

pub const fn set_base(&mut self, value: u64) -> &mut Self

Sets the unshifted value of SupervisorTrapVector[63:2].

pub fn mode(&self) -> TrapVectorMode

The value of SupervisorTrapVector[1:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_mode to recover from invalid bit patterns.

pub fn try_mode(&self) -> Result<TrapVectorMode, InvalidBits<u8>>

Fallible variant of Self::mode.

pub fn set_mode(&mut self, value: TrapVectorMode) -> &mut Self

Sets the value of SupervisorTrapVector[1:0].

Source

impl SupervisorTrapVector

pub fn iter(&self) -> SupervisorTrapVectorIter

Returns an iterator over (metadata, value) pairs for each field.