CacheTopologyA

Struct CacheTopologyA 

pub struct CacheTopologyA(/* private fields */);
The layout of EAX in Intel and AMD Cache Topology leaves.

Implementations

Source

impl CacheTopologyA

pub const RSVD1_MASK: u32

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u32

Mask of all reserved-as-0 bits.

pub const DEFAULT: u32

The default value of the layout, combining all field defaults and reserved-as values.

pub const MAX_CORES_MASK: u32

Unshifted bitmask of max_cores.

pub const MAX_CORES_SHIFT: usize = 26

Bit shift (i.e., the low bit) of max_cores.

pub const MAX_SHARING_LOGICAL_PROCESSORS_MASK: u32

Unshifted bitmask of max_sharing_logical_processors.

pub const MAX_SHARING_LOGICAL_PROCESSORS_SHIFT: usize = 14

Bit shift (i.e., the low bit) of max_sharing_logical_processors.

pub const FULLY_ASSOCIATIVE_MASK: u32

Unshifted bitmask of fully_associative.

pub const FULLY_ASSOCIATIVE_SHIFT: usize = 9

Bit shift (i.e., the low bit) of fully_associative.

pub const SELF_INITIALIZING_MASK: u32

Unshifted bitmask of self_initializing.

pub const SELF_INITIALIZING_SHIFT: usize = 8

Bit shift (i.e., the low bit) of self_initializing.

pub const CACHE_LEVEL_MASK: u32

Unshifted bitmask of cache_level.

pub const CACHE_LEVEL_SHIFT: usize = 5

Bit shift (i.e., the low bit) of cache_level.

pub const CACHE_TYPE_MASK: u32

Unshifted bitmask of cache_type.

pub const CACHE_TYPE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of cache_type.

pub const FIELDS: [FieldMetadata<u32>; 6]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u32

pub const fn max_cores(&self) -> u8

The value of CacheTopologyA[31:26].

pub const fn set_max_cores(&mut self, value: u8) -> &mut Self

Sets the value of CacheTopologyA[31:26].

pub const fn max_sharing_logical_processors(&self) -> u16

The value of CacheTopologyA[25:14].

pub const fn set_max_sharing_logical_processors( &mut self, value: u16, ) -> &mut Self

Sets the value of CacheTopologyA[25:14].

pub const fn fully_associative(&self) -> bool

The value of CacheTopologyA9.

pub const fn set_fully_associative(&mut self, value: bool) -> &mut Self

Sets the value of CacheTopologyA9.

pub const fn self_initializing(&self) -> bool

The value of CacheTopologyA8.

pub const fn set_self_initializing(&mut self, value: bool) -> &mut Self

Sets the value of CacheTopologyA8.

pub const fn cache_level(&self) -> u8

The value of CacheTopologyA[7:5].

pub const fn set_cache_level(&mut self, value: u8) -> &mut Self

Sets the value of CacheTopologyA[7:5].

pub fn cache_type(&self) -> CacheType

The value of CacheTopologyA[4:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_cache_type to recover from invalid bit patterns.

pub fn try_cache_type(&self) -> Result<CacheType, InvalidBits<u8>>

Fallible variant of Self::cache_type.

pub fn set_cache_type(&mut self, value: CacheType) -> &mut Self

Sets the value of CacheTopologyA[4:0].

Source

impl CacheTopologyA

pub fn iter(&self) -> CacheTopologyAIter

Returns an iterator over (metadata, value) pairs for each field.