ExtendedSizeInfo

Struct ExtendedSizeInfo 

pub struct ExtendedSizeInfo(/* private fields */);
The layout of ECX in EXTENDED_SIZE_INFO.

Implementations

Source

impl ExtendedSizeInfo

pub const RSVD1_MASK: u32

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u32

Mask of all reserved-as-0 bits.

pub const DEFAULT: u32

The default value of the layout, combining all field defaults and reserved-as values.

pub const PERF_TSC_SIZE_MASK: u32

Unshifted bitmask of perf_tsc_size.

pub const PERF_TSC_SIZE_SHIFT: usize = 16

Bit shift (i.e., the low bit) of perf_tsc_size.

pub const APIC_ID_SIZE_MASK: u32

Unshifted bitmask of apic_id_size.

pub const APIC_ID_SIZE_SHIFT: usize = 12

Bit shift (i.e., the low bit) of apic_id_size.

pub const NC_MASK: u32

Unshifted bitmask of nc.

pub const NC_SHIFT: usize = 0

Bit shift (i.e., the low bit) of nc.

pub const FIELDS: [FieldMetadata<u32>; 3]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u32

pub fn perf_tsc_size(&self) -> PerfTimestampCounterSize

The value of ExtendedSizeInfo[17:16].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_perf_tsc_size to recover from invalid bit patterns.

pub fn try_perf_tsc_size( &self, ) -> Result<PerfTimestampCounterSize, InvalidBits<u8>>

Fallible variant of Self::perf_tsc_size.

pub fn set_perf_tsc_size( &mut self, value: PerfTimestampCounterSize, ) -> &mut Self

Sets the value of ExtendedSizeInfo[17:16].

pub const fn apic_id_size(&self) -> u8

The value of ExtendedSizeInfo[15:12].

pub const fn set_apic_id_size(&mut self, value: u8) -> &mut Self

Sets the value of ExtendedSizeInfo[15:12].

pub const fn nc(&self) -> u8

The value of ExtendedSizeInfo[7:0].

pub const fn set_nc(&mut self, value: u8) -> &mut Self

Sets the value of ExtendedSizeInfo[7:0].

Source

impl ExtendedSizeInfo

pub fn iter(&self) -> ExtendedSizeInfoIter

Returns an iterator over (metadata, value) pairs for each field.