TopologyEnumerationC

Struct TopologyEnumerationC 

pub struct TopologyEnumerationC(/* private fields */);
The layout of ECX in topology enumeration leaves.

Implementations

Source

impl TopologyEnumerationC

pub const RSVD1_MASK: u32

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u32

Mask of all reserved-as-0 bits.

pub const DEFAULT: u32

The default value of the layout, combining all field defaults and reserved-as values.

pub const LEVEL_TYPE_MASK: u32

Unshifted bitmask of level_type.

pub const LEVEL_TYPE_SHIFT: usize = 8

Bit shift (i.e., the low bit) of level_type.

pub const LEVEL_NUMBER_MASK: u32

Unshifted bitmask of level_number.

pub const LEVEL_NUMBER_SHIFT: usize = 0

Bit shift (i.e., the low bit) of level_number.

pub const FIELDS: [FieldMetadata<u32>; 2]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u32

pub fn level_type(&self) -> TopologyLevelType

The value of TopologyEnumerationC[15:8].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_level_type to recover from invalid bit patterns.

pub fn try_level_type(&self) -> Result<TopologyLevelType, InvalidBits<u8>>

Fallible variant of Self::level_type.

pub fn set_level_type(&mut self, value: TopologyLevelType) -> &mut Self

Sets the value of TopologyEnumerationC[15:8].

pub const fn level_number(&self) -> u8

The value of TopologyEnumerationC[7:0].

pub const fn set_level_number(&mut self, value: u8) -> &mut Self

Sets the value of TopologyEnumerationC[7:0].

Source

impl TopologyEnumerationC

pub fn iter(&self) -> TopologyEnumerationCIter

Returns an iterator over (metadata, value) pairs for each field.