VersionInfo

Struct VersionInfo 

pub struct VersionInfo(/* private fields */);
The layout of EAX in VERSION_INFO.

Implementations

Source

impl VersionInfo

pub const RSVD1_MASK: u32

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u32

Mask of all reserved-as-0 bits.

pub const DEFAULT: u32

The default value of the layout, combining all field defaults and reserved-as values.

pub const EXTENDED_FAMILY_MASK: u32

Unshifted bitmask of extended_family.

pub const EXTENDED_FAMILY_SHIFT: usize = 20

Bit shift (i.e., the low bit) of extended_family.

pub const EXTENDED_MODEL_MASK: u32

Unshifted bitmask of extended_model.

pub const EXTENDED_MODEL_SHIFT: usize = 16

Bit shift (i.e., the low bit) of extended_model.

pub const INTEL_PROCESSOR_MASK: u32

Unshifted bitmask of intel_processor.

pub const INTEL_PROCESSOR_SHIFT: usize = 12

Bit shift (i.e., the low bit) of intel_processor.

pub const BASE_FAMILY_MASK: u32

Unshifted bitmask of base_family.

pub const BASE_FAMILY_SHIFT: usize = 8

Bit shift (i.e., the low bit) of base_family.

pub const BASE_MODEL_MASK: u32

Unshifted bitmask of base_model.

pub const BASE_MODEL_SHIFT: usize = 4

Bit shift (i.e., the low bit) of base_model.

pub const STEPPING_MASK: u32

Unshifted bitmask of stepping.

pub const STEPPING_SHIFT: usize = 0

Bit shift (i.e., the low bit) of stepping.

pub const FIELDS: [FieldMetadata<u32>; 6]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u32

pub const fn extended_family(&self) -> u8

The value of VersionInfo[27:20].

pub const fn set_extended_family(&mut self, value: u8) -> &mut Self

Sets the value of VersionInfo[27:20].

pub const fn extended_model(&self) -> u8

The value of VersionInfo[19:16].

pub const fn set_extended_model(&mut self, value: u8) -> &mut Self

Sets the value of VersionInfo[19:16].

pub fn intel_processor(&self) -> IntelProcessorType

The value of VersionInfo[13:12].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_intel_processor to recover from invalid bit patterns.

pub fn try_intel_processor(&self) -> Result<IntelProcessorType, InvalidBits<u8>>

Fallible variant of Self::intel_processor.

pub fn set_intel_processor(&mut self, value: IntelProcessorType) -> &mut Self

Sets the value of VersionInfo[13:12].

pub const fn base_family(&self) -> u8

The value of VersionInfo[11:8].

pub const fn set_base_family(&mut self, value: u8) -> &mut Self

Sets the value of VersionInfo[11:8].

pub const fn base_model(&self) -> u8

The value of VersionInfo[7:4].

pub const fn set_base_model(&mut self, value: u8) -> &mut Self

Sets the value of VersionInfo[7:4].

pub const fn stepping(&self) -> u8

The value of VersionInfo[3:0].

pub const fn set_stepping(&mut self, value: u8) -> &mut Self

Sets the value of VersionInfo[3:0].

Source

impl VersionInfo

pub fn iter(&self) -> VersionInfoIter

Returns an iterator over (metadata, value) pairs for each field.

Source

impl VersionInfo

pub fn family(self) -> u8

pub fn model(self) -> u8

pub fn microarchitecture(self, vendor: Vendor) -> Microarchitecture

Attempts to derives the microarchitecture with the assumption that the system relates to a particular vendor.