pub enum SpectreV2Mitigation {
Ibrs,
IbpbRetpoline,
IbpbRetpolineStibp,
}Expand description
An architecturally prescribed mitigation for Spectre v2.
Variants
Ibrs
Enhanced/always-on IBRS (i.e., IBRS that can be enabled once without automatic disabling) is preferred alone.
IbpbRetpoline
IBPB and/or retpoline are recommended.
IbpbRetpolineStibp
IBPB and/or retpoline are recommended - and STIPB, though not preferred as a performant mitigation, is also present and may be used.