pub fn has_x86_mds_taa_bugs(
cpuid: &impl Cpuid,
msr: &impl ReadReg<ArchCapabilitiesMsr>,
) -> boolExpand description
Whether the CPU is susceptible to any of the MDS or TAA bugs, which are closely related and similarly mitigated.
pub fn has_x86_mds_taa_bugs(
cpuid: &impl Cpuid,
msr: &impl ReadReg<ArchCapabilitiesMsr>,
) -> boolWhether the CPU is susceptible to any of the MDS or TAA bugs, which are closely related and similarly mitigated.