store_memory_barrier

Function store_memory_barrier 

pub fn store_memory_barrier()
Ensure all stores that appear before this barrier (in program order) complete before any stores that appear after this barrier.