pub struct ExceptionSyndromeRegister(/* private fields */);Expand description
Implementations
Sourceimpl ExceptionSyndromeRegister
impl ExceptionSyndromeRegister
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const ISS2_SHIFT: usize = 32
pub const ISS2_SHIFT: usize = 32
Bit shift (i.e., the low bit) of iss2.
Sourcepub const FIELDS: [FieldMetadata<u64>; 4]
pub const FIELDS: [FieldMetadata<u64>; 4]
Metadata of all named fields in the layout.
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub const fn set_iss2(&mut self, value: u32) -> &mut Self
pub const fn set_iss2(&mut self, value: u32) -> &mut Self
Sets the value of ExceptionSyndromeRegister[55:32].
Sourcepub fn ec(&self) -> ExceptionClasswhere
ExceptionClass: TryFromBytes,
pub fn ec(&self) -> ExceptionClasswhere
ExceptionClass: TryFromBytes,
The value of ExceptionSyndromeRegister[31:26].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ec to recover from invalid bit patterns.
Sourcepub fn try_ec(&self) -> Result<ExceptionClass, InvalidBits<u8>>where
ExceptionClass: TryFromBytes,
pub fn try_ec(&self) -> Result<ExceptionClass, InvalidBits<u8>>where
ExceptionClass: TryFromBytes,
Fallible variant of Self::ec.
Sourcepub fn set_ec(&mut self, value: ExceptionClass) -> &mut Self
pub fn set_ec(&mut self, value: ExceptionClass) -> &mut Self
Sets the value of ExceptionSyndromeRegister[31:26].