pub struct InstructionSetAttributeRegister0(/* private fields */);Expand description
The layout of ID_AA64ISAR0_EL1.
Implementations
Sourceimpl InstructionSetAttributeRegister0
impl InstructionSetAttributeRegister0
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const RNDR_SHIFT: usize = 60
pub const RNDR_SHIFT: usize = 60
Bit shift (i.e., the low bit) of rndr.
Sourcepub const SHA3_SHIFT: usize = 32
pub const SHA3_SHIFT: usize = 32
Bit shift (i.e., the low bit) of sha3.
Sourcepub const ATOMIC_MASK: u64
pub const ATOMIC_MASK: u64
Unshifted bitmask of atomic.
Sourcepub const ATOMIC_SHIFT: usize = 20
pub const ATOMIC_SHIFT: usize = 20
Bit shift (i.e., the low bit) of atomic.
Sourcepub const CRC32_MASK: u64
pub const CRC32_MASK: u64
Unshifted bitmask of crc32.
Sourcepub const CRC32_SHIFT: usize = 16
pub const CRC32_SHIFT: usize = 16
Bit shift (i.e., the low bit) of crc32.
Sourcepub const SHA2_SHIFT: usize = 12
pub const SHA2_SHIFT: usize = 12
Bit shift (i.e., the low bit) of sha2.
Sourcepub const SHA1_SHIFT: usize = 8
pub const SHA1_SHIFT: usize = 8
Bit shift (i.e., the low bit) of sha1.
Sourcepub const FIELDS: [FieldMetadata<u64>; 14]
pub const FIELDS: [FieldMetadata<u64>; 14]
Metadata of all named fields in the layout.
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub fn rndr(&self) -> IdAa64IsaR0Rndrwhere
IdAa64IsaR0Rndr: TryFromBytes,
pub fn rndr(&self) -> IdAa64IsaR0Rndrwhere
IdAa64IsaR0Rndr: TryFromBytes,
The value of InstructionSetAttributeRegister0[63:60].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_rndr to recover from invalid bit patterns.
Sourcepub fn try_rndr(&self) -> Result<IdAa64IsaR0Rndr, InvalidBits<u8>>where
IdAa64IsaR0Rndr: TryFromBytes,
pub fn try_rndr(&self) -> Result<IdAa64IsaR0Rndr, InvalidBits<u8>>where
IdAa64IsaR0Rndr: TryFromBytes,
Fallible variant of Self::rndr.
Sourcepub fn set_rndr(&mut self, value: IdAa64IsaR0Rndr) -> &mut Self
pub fn set_rndr(&mut self, value: IdAa64IsaR0Rndr) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[63:60].
Sourcepub fn tlb(&self) -> IdAa64IsaR0Tlbwhere
IdAa64IsaR0Tlb: TryFromBytes,
pub fn tlb(&self) -> IdAa64IsaR0Tlbwhere
IdAa64IsaR0Tlb: TryFromBytes,
The value of InstructionSetAttributeRegister0[59:56].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tlb to recover from invalid bit patterns.
Sourcepub fn try_tlb(&self) -> Result<IdAa64IsaR0Tlb, InvalidBits<u8>>where
IdAa64IsaR0Tlb: TryFromBytes,
pub fn try_tlb(&self) -> Result<IdAa64IsaR0Tlb, InvalidBits<u8>>where
IdAa64IsaR0Tlb: TryFromBytes,
Fallible variant of Self::tlb.
Sourcepub fn set_tlb(&mut self, value: IdAa64IsaR0Tlb) -> &mut Self
pub fn set_tlb(&mut self, value: IdAa64IsaR0Tlb) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[59:56].
Sourcepub fn ts(&self) -> IdAa64IsaR0Tswhere
IdAa64IsaR0Ts: TryFromBytes,
pub fn ts(&self) -> IdAa64IsaR0Tswhere
IdAa64IsaR0Ts: TryFromBytes,
The value of InstructionSetAttributeRegister0[55:52].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ts to recover from invalid bit patterns.
Sourcepub fn try_ts(&self) -> Result<IdAa64IsaR0Ts, InvalidBits<u8>>where
IdAa64IsaR0Ts: TryFromBytes,
pub fn try_ts(&self) -> Result<IdAa64IsaR0Ts, InvalidBits<u8>>where
IdAa64IsaR0Ts: TryFromBytes,
Fallible variant of Self::ts.
Sourcepub fn set_ts(&mut self, value: IdAa64IsaR0Ts) -> &mut Self
pub fn set_ts(&mut self, value: IdAa64IsaR0Ts) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[55:52].
Sourcepub fn fhm(&self) -> IdAa64IsaR0Fhmwhere
IdAa64IsaR0Fhm: TryFromBytes,
pub fn fhm(&self) -> IdAa64IsaR0Fhmwhere
IdAa64IsaR0Fhm: TryFromBytes,
The value of InstructionSetAttributeRegister0[51:48].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_fhm to recover from invalid bit patterns.
Sourcepub fn try_fhm(&self) -> Result<IdAa64IsaR0Fhm, InvalidBits<u8>>where
IdAa64IsaR0Fhm: TryFromBytes,
pub fn try_fhm(&self) -> Result<IdAa64IsaR0Fhm, InvalidBits<u8>>where
IdAa64IsaR0Fhm: TryFromBytes,
Fallible variant of Self::fhm.
Sourcepub fn set_fhm(&mut self, value: IdAa64IsaR0Fhm) -> &mut Self
pub fn set_fhm(&mut self, value: IdAa64IsaR0Fhm) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[51:48].
Sourcepub fn dp(&self) -> IdAa64IsaR0DotProdwhere
IdAa64IsaR0DotProd: TryFromBytes,
pub fn dp(&self) -> IdAa64IsaR0DotProdwhere
IdAa64IsaR0DotProd: TryFromBytes,
The value of InstructionSetAttributeRegister0[47:44].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_dp to recover from invalid bit patterns.
Sourcepub fn try_dp(&self) -> Result<IdAa64IsaR0DotProd, InvalidBits<u8>>where
IdAa64IsaR0DotProd: TryFromBytes,
pub fn try_dp(&self) -> Result<IdAa64IsaR0DotProd, InvalidBits<u8>>where
IdAa64IsaR0DotProd: TryFromBytes,
Fallible variant of Self::dp.
Sourcepub fn set_dp(&mut self, value: IdAa64IsaR0DotProd) -> &mut Self
pub fn set_dp(&mut self, value: IdAa64IsaR0DotProd) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[47:44].
Sourcepub fn sm4(&self) -> IdAa64IsaR0Sm4where
IdAa64IsaR0Sm4: TryFromBytes,
pub fn sm4(&self) -> IdAa64IsaR0Sm4where
IdAa64IsaR0Sm4: TryFromBytes,
The value of InstructionSetAttributeRegister0[43:40].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sm4 to recover from invalid bit patterns.
Sourcepub fn try_sm4(&self) -> Result<IdAa64IsaR0Sm4, InvalidBits<u8>>where
IdAa64IsaR0Sm4: TryFromBytes,
pub fn try_sm4(&self) -> Result<IdAa64IsaR0Sm4, InvalidBits<u8>>where
IdAa64IsaR0Sm4: TryFromBytes,
Fallible variant of Self::sm4.
Sourcepub fn set_sm4(&mut self, value: IdAa64IsaR0Sm4) -> &mut Self
pub fn set_sm4(&mut self, value: IdAa64IsaR0Sm4) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[43:40].
Sourcepub fn sm3(&self) -> IdAa64IsaR0Sm3where
IdAa64IsaR0Sm3: TryFromBytes,
pub fn sm3(&self) -> IdAa64IsaR0Sm3where
IdAa64IsaR0Sm3: TryFromBytes,
The value of InstructionSetAttributeRegister0[39:36].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sm3 to recover from invalid bit patterns.
Sourcepub fn try_sm3(&self) -> Result<IdAa64IsaR0Sm3, InvalidBits<u8>>where
IdAa64IsaR0Sm3: TryFromBytes,
pub fn try_sm3(&self) -> Result<IdAa64IsaR0Sm3, InvalidBits<u8>>where
IdAa64IsaR0Sm3: TryFromBytes,
Fallible variant of Self::sm3.
Sourcepub fn set_sm3(&mut self, value: IdAa64IsaR0Sm3) -> &mut Self
pub fn set_sm3(&mut self, value: IdAa64IsaR0Sm3) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[39:36].
Sourcepub fn sha3(&self) -> IdAa64IsaR0Sha3where
IdAa64IsaR0Sha3: TryFromBytes,
pub fn sha3(&self) -> IdAa64IsaR0Sha3where
IdAa64IsaR0Sha3: TryFromBytes,
The value of InstructionSetAttributeRegister0[35:32].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sha3 to recover from invalid bit patterns.
Sourcepub fn try_sha3(&self) -> Result<IdAa64IsaR0Sha3, InvalidBits<u8>>where
IdAa64IsaR0Sha3: TryFromBytes,
pub fn try_sha3(&self) -> Result<IdAa64IsaR0Sha3, InvalidBits<u8>>where
IdAa64IsaR0Sha3: TryFromBytes,
Fallible variant of Self::sha3.
Sourcepub fn set_sha3(&mut self, value: IdAa64IsaR0Sha3) -> &mut Self
pub fn set_sha3(&mut self, value: IdAa64IsaR0Sha3) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[35:32].
Sourcepub fn rdm(&self) -> IdAa64IsaR0Rdmwhere
IdAa64IsaR0Rdm: TryFromBytes,
pub fn rdm(&self) -> IdAa64IsaR0Rdmwhere
IdAa64IsaR0Rdm: TryFromBytes,
The value of InstructionSetAttributeRegister0[31:28].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_rdm to recover from invalid bit patterns.
Sourcepub fn try_rdm(&self) -> Result<IdAa64IsaR0Rdm, InvalidBits<u8>>where
IdAa64IsaR0Rdm: TryFromBytes,
pub fn try_rdm(&self) -> Result<IdAa64IsaR0Rdm, InvalidBits<u8>>where
IdAa64IsaR0Rdm: TryFromBytes,
Fallible variant of Self::rdm.
Sourcepub fn set_rdm(&mut self, value: IdAa64IsaR0Rdm) -> &mut Self
pub fn set_rdm(&mut self, value: IdAa64IsaR0Rdm) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[31:28].
Sourcepub fn atomic(&self) -> IdAa64IsaR0Atomicwhere
IdAa64IsaR0Atomic: TryFromBytes,
pub fn atomic(&self) -> IdAa64IsaR0Atomicwhere
IdAa64IsaR0Atomic: TryFromBytes,
The value of InstructionSetAttributeRegister0[23:20].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_atomic to recover from invalid bit patterns.
Sourcepub fn try_atomic(&self) -> Result<IdAa64IsaR0Atomic, InvalidBits<u8>>where
IdAa64IsaR0Atomic: TryFromBytes,
pub fn try_atomic(&self) -> Result<IdAa64IsaR0Atomic, InvalidBits<u8>>where
IdAa64IsaR0Atomic: TryFromBytes,
Fallible variant of Self::atomic.
Sourcepub fn set_atomic(&mut self, value: IdAa64IsaR0Atomic) -> &mut Self
pub fn set_atomic(&mut self, value: IdAa64IsaR0Atomic) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[23:20].
Sourcepub fn crc32(&self) -> IdAa64IsaR0Crc32where
IdAa64IsaR0Crc32: TryFromBytes,
pub fn crc32(&self) -> IdAa64IsaR0Crc32where
IdAa64IsaR0Crc32: TryFromBytes,
The value of InstructionSetAttributeRegister0[19:16].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_crc32 to recover from invalid bit patterns.
Sourcepub fn try_crc32(&self) -> Result<IdAa64IsaR0Crc32, InvalidBits<u8>>where
IdAa64IsaR0Crc32: TryFromBytes,
pub fn try_crc32(&self) -> Result<IdAa64IsaR0Crc32, InvalidBits<u8>>where
IdAa64IsaR0Crc32: TryFromBytes,
Fallible variant of Self::crc32.
Sourcepub fn set_crc32(&mut self, value: IdAa64IsaR0Crc32) -> &mut Self
pub fn set_crc32(&mut self, value: IdAa64IsaR0Crc32) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[19:16].
Sourcepub fn sha2(&self) -> IdAa64IsaR0Sha2where
IdAa64IsaR0Sha2: TryFromBytes,
pub fn sha2(&self) -> IdAa64IsaR0Sha2where
IdAa64IsaR0Sha2: TryFromBytes,
The value of InstructionSetAttributeRegister0[15:12].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sha2 to recover from invalid bit patterns.
Sourcepub fn try_sha2(&self) -> Result<IdAa64IsaR0Sha2, InvalidBits<u8>>where
IdAa64IsaR0Sha2: TryFromBytes,
pub fn try_sha2(&self) -> Result<IdAa64IsaR0Sha2, InvalidBits<u8>>where
IdAa64IsaR0Sha2: TryFromBytes,
Fallible variant of Self::sha2.
Sourcepub fn set_sha2(&mut self, value: IdAa64IsaR0Sha2) -> &mut Self
pub fn set_sha2(&mut self, value: IdAa64IsaR0Sha2) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[15:12].
Sourcepub fn sha1(&self) -> IdAa64IsaR0Sha1where
IdAa64IsaR0Sha1: TryFromBytes,
pub fn sha1(&self) -> IdAa64IsaR0Sha1where
IdAa64IsaR0Sha1: TryFromBytes,
The value of InstructionSetAttributeRegister0[11:8].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sha1 to recover from invalid bit patterns.
Sourcepub fn try_sha1(&self) -> Result<IdAa64IsaR0Sha1, InvalidBits<u8>>where
IdAa64IsaR0Sha1: TryFromBytes,
pub fn try_sha1(&self) -> Result<IdAa64IsaR0Sha1, InvalidBits<u8>>where
IdAa64IsaR0Sha1: TryFromBytes,
Fallible variant of Self::sha1.
Sourcepub fn set_sha1(&mut self, value: IdAa64IsaR0Sha1) -> &mut Self
pub fn set_sha1(&mut self, value: IdAa64IsaR0Sha1) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[11:8].
Sourcepub fn aes(&self) -> IdAa64IsaR0Aeswhere
IdAa64IsaR0Aes: TryFromBytes,
pub fn aes(&self) -> IdAa64IsaR0Aeswhere
IdAa64IsaR0Aes: TryFromBytes,
The value of InstructionSetAttributeRegister0[7:4].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_aes to recover from invalid bit patterns.
Sourcepub fn try_aes(&self) -> Result<IdAa64IsaR0Aes, InvalidBits<u8>>where
IdAa64IsaR0Aes: TryFromBytes,
pub fn try_aes(&self) -> Result<IdAa64IsaR0Aes, InvalidBits<u8>>where
IdAa64IsaR0Aes: TryFromBytes,
Fallible variant of Self::aes.
Sourcepub fn set_aes(&mut self, value: IdAa64IsaR0Aes) -> &mut Self
pub fn set_aes(&mut self, value: IdAa64IsaR0Aes) -> &mut Self
Sets the value of InstructionSetAttributeRegister0[7:4].