pub struct InstructionSetAttributeRegister1(/* private fields */);Expand description
The layout of ID_AA64ISAR1_EL1.
Implementations
Sourceimpl InstructionSetAttributeRegister1
impl InstructionSetAttributeRegister1
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const LS64_SHIFT: usize = 60
pub const LS64_SHIFT: usize = 60
Bit shift (i.e., the low bit) of ls64.
Sourcepub const I8MM_SHIFT: usize = 52
pub const I8MM_SHIFT: usize = 52
Bit shift (i.e., the low bit) of i8mm.
Sourcepub const BF16_SHIFT: usize = 44
pub const BF16_SHIFT: usize = 44
Bit shift (i.e., the low bit) of bf16.
Sourcepub const SPECRES_MASK: u64
pub const SPECRES_MASK: u64
Unshifted bitmask of specres.
Sourcepub const SPECRES_SHIFT: usize = 40
pub const SPECRES_SHIFT: usize = 40
Bit shift (i.e., the low bit) of specres.
Sourcepub const FRINTTS_MASK: u64
pub const FRINTTS_MASK: u64
Unshifted bitmask of frintts.
Sourcepub const FRINTTS_SHIFT: usize = 32
pub const FRINTTS_SHIFT: usize = 32
Bit shift (i.e., the low bit) of frintts.
Sourcepub const LRCPC_MASK: u64
pub const LRCPC_MASK: u64
Unshifted bitmask of lrcpc.
Sourcepub const LRCPC_SHIFT: usize = 20
pub const LRCPC_SHIFT: usize = 20
Bit shift (i.e., the low bit) of lrcpc.
Sourcepub const FCMA_SHIFT: usize = 16
pub const FCMA_SHIFT: usize = 16
Bit shift (i.e., the low bit) of fcma.
Sourcepub const JSCVT_MASK: u64
pub const JSCVT_MASK: u64
Unshifted bitmask of jscvt.
Sourcepub const JSCVT_SHIFT: usize = 12
pub const JSCVT_SHIFT: usize = 12
Bit shift (i.e., the low bit) of jscvt.
Sourcepub const FIELDS: [FieldMetadata<u64>; 16]
pub const FIELDS: [FieldMetadata<u64>; 16]
Metadata of all named fields in the layout.
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub fn ls64(&self) -> IdAa64IsaR1Ls64where
IdAa64IsaR1Ls64: TryFromBytes,
pub fn ls64(&self) -> IdAa64IsaR1Ls64where
IdAa64IsaR1Ls64: TryFromBytes,
The value of InstructionSetAttributeRegister1[63:60].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ls64 to recover from invalid bit patterns.
Sourcepub fn try_ls64(&self) -> Result<IdAa64IsaR1Ls64, InvalidBits<u8>>where
IdAa64IsaR1Ls64: TryFromBytes,
pub fn try_ls64(&self) -> Result<IdAa64IsaR1Ls64, InvalidBits<u8>>where
IdAa64IsaR1Ls64: TryFromBytes,
Fallible variant of Self::ls64.
Sourcepub fn set_ls64(&mut self, value: IdAa64IsaR1Ls64) -> &mut Self
pub fn set_ls64(&mut self, value: IdAa64IsaR1Ls64) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[63:60].
Sourcepub fn xs(&self) -> IdAa64IsaR1Xswhere
IdAa64IsaR1Xs: TryFromBytes,
pub fn xs(&self) -> IdAa64IsaR1Xswhere
IdAa64IsaR1Xs: TryFromBytes,
The value of InstructionSetAttributeRegister1[59:56].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_xs to recover from invalid bit patterns.
Sourcepub fn try_xs(&self) -> Result<IdAa64IsaR1Xs, InvalidBits<u8>>where
IdAa64IsaR1Xs: TryFromBytes,
pub fn try_xs(&self) -> Result<IdAa64IsaR1Xs, InvalidBits<u8>>where
IdAa64IsaR1Xs: TryFromBytes,
Fallible variant of Self::xs.
Sourcepub fn set_xs(&mut self, value: IdAa64IsaR1Xs) -> &mut Self
pub fn set_xs(&mut self, value: IdAa64IsaR1Xs) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[59:56].
Sourcepub fn i8mm(&self) -> IdAa64IsaR1I8mmwhere
IdAa64IsaR1I8mm: TryFromBytes,
pub fn i8mm(&self) -> IdAa64IsaR1I8mmwhere
IdAa64IsaR1I8mm: TryFromBytes,
The value of InstructionSetAttributeRegister1[55:52].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_i8mm to recover from invalid bit patterns.
Sourcepub fn try_i8mm(&self) -> Result<IdAa64IsaR1I8mm, InvalidBits<u8>>where
IdAa64IsaR1I8mm: TryFromBytes,
pub fn try_i8mm(&self) -> Result<IdAa64IsaR1I8mm, InvalidBits<u8>>where
IdAa64IsaR1I8mm: TryFromBytes,
Fallible variant of Self::i8mm.
Sourcepub fn set_i8mm(&mut self, value: IdAa64IsaR1I8mm) -> &mut Self
pub fn set_i8mm(&mut self, value: IdAa64IsaR1I8mm) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[55:52].
Sourcepub fn dgh(&self) -> IdAa64IsaR1Dghwhere
IdAa64IsaR1Dgh: TryFromBytes,
pub fn dgh(&self) -> IdAa64IsaR1Dghwhere
IdAa64IsaR1Dgh: TryFromBytes,
The value of InstructionSetAttributeRegister1[51:48].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_dgh to recover from invalid bit patterns.
Sourcepub fn try_dgh(&self) -> Result<IdAa64IsaR1Dgh, InvalidBits<u8>>where
IdAa64IsaR1Dgh: TryFromBytes,
pub fn try_dgh(&self) -> Result<IdAa64IsaR1Dgh, InvalidBits<u8>>where
IdAa64IsaR1Dgh: TryFromBytes,
Fallible variant of Self::dgh.
Sourcepub fn set_dgh(&mut self, value: IdAa64IsaR1Dgh) -> &mut Self
pub fn set_dgh(&mut self, value: IdAa64IsaR1Dgh) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[51:48].
Sourcepub fn bf16(&self) -> IdAa64IsaR1Bf16where
IdAa64IsaR1Bf16: TryFromBytes,
pub fn bf16(&self) -> IdAa64IsaR1Bf16where
IdAa64IsaR1Bf16: TryFromBytes,
The value of InstructionSetAttributeRegister1[47:44].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_bf16 to recover from invalid bit patterns.
Sourcepub fn try_bf16(&self) -> Result<IdAa64IsaR1Bf16, InvalidBits<u8>>where
IdAa64IsaR1Bf16: TryFromBytes,
pub fn try_bf16(&self) -> Result<IdAa64IsaR1Bf16, InvalidBits<u8>>where
IdAa64IsaR1Bf16: TryFromBytes,
Fallible variant of Self::bf16.
Sourcepub fn set_bf16(&mut self, value: IdAa64IsaR1Bf16) -> &mut Self
pub fn set_bf16(&mut self, value: IdAa64IsaR1Bf16) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[47:44].
Sourcepub fn specres(&self) -> IdAa64IsaR1Specreswhere
IdAa64IsaR1Specres: TryFromBytes,
pub fn specres(&self) -> IdAa64IsaR1Specreswhere
IdAa64IsaR1Specres: TryFromBytes,
The value of InstructionSetAttributeRegister1[43:40].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_specres to recover from invalid bit patterns.
Sourcepub fn try_specres(&self) -> Result<IdAa64IsaR1Specres, InvalidBits<u8>>where
IdAa64IsaR1Specres: TryFromBytes,
pub fn try_specres(&self) -> Result<IdAa64IsaR1Specres, InvalidBits<u8>>where
IdAa64IsaR1Specres: TryFromBytes,
Fallible variant of Self::specres.
Sourcepub fn set_specres(&mut self, value: IdAa64IsaR1Specres) -> &mut Self
pub fn set_specres(&mut self, value: IdAa64IsaR1Specres) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[43:40].
Sourcepub fn sb(&self) -> IdAa64IsaR1Sbwhere
IdAa64IsaR1Sb: TryFromBytes,
pub fn sb(&self) -> IdAa64IsaR1Sbwhere
IdAa64IsaR1Sb: TryFromBytes,
The value of InstructionSetAttributeRegister1[39:36].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sb to recover from invalid bit patterns.
Sourcepub fn try_sb(&self) -> Result<IdAa64IsaR1Sb, InvalidBits<u8>>where
IdAa64IsaR1Sb: TryFromBytes,
pub fn try_sb(&self) -> Result<IdAa64IsaR1Sb, InvalidBits<u8>>where
IdAa64IsaR1Sb: TryFromBytes,
Fallible variant of Self::sb.
Sourcepub fn set_sb(&mut self, value: IdAa64IsaR1Sb) -> &mut Self
pub fn set_sb(&mut self, value: IdAa64IsaR1Sb) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[39:36].
Sourcepub fn frintts(&self) -> IdAa64IsaR1Frinttswhere
IdAa64IsaR1Frintts: TryFromBytes,
pub fn frintts(&self) -> IdAa64IsaR1Frinttswhere
IdAa64IsaR1Frintts: TryFromBytes,
The value of InstructionSetAttributeRegister1[35:32].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_frintts to recover from invalid bit patterns.
Sourcepub fn try_frintts(&self) -> Result<IdAa64IsaR1Frintts, InvalidBits<u8>>where
IdAa64IsaR1Frintts: TryFromBytes,
pub fn try_frintts(&self) -> Result<IdAa64IsaR1Frintts, InvalidBits<u8>>where
IdAa64IsaR1Frintts: TryFromBytes,
Fallible variant of Self::frintts.
Sourcepub fn set_frintts(&mut self, value: IdAa64IsaR1Frintts) -> &mut Self
pub fn set_frintts(&mut self, value: IdAa64IsaR1Frintts) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[35:32].
Sourcepub fn gpi(&self) -> IdAa64IsaR1Gpiwhere
IdAa64IsaR1Gpi: TryFromBytes,
pub fn gpi(&self) -> IdAa64IsaR1Gpiwhere
IdAa64IsaR1Gpi: TryFromBytes,
The value of InstructionSetAttributeRegister1[31:28].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_gpi to recover from invalid bit patterns.
Sourcepub fn try_gpi(&self) -> Result<IdAa64IsaR1Gpi, InvalidBits<u8>>where
IdAa64IsaR1Gpi: TryFromBytes,
pub fn try_gpi(&self) -> Result<IdAa64IsaR1Gpi, InvalidBits<u8>>where
IdAa64IsaR1Gpi: TryFromBytes,
Fallible variant of Self::gpi.
Sourcepub fn set_gpi(&mut self, value: IdAa64IsaR1Gpi) -> &mut Self
pub fn set_gpi(&mut self, value: IdAa64IsaR1Gpi) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[31:28].
Sourcepub fn gpa(&self) -> IdAa64IsaR1Gpawhere
IdAa64IsaR1Gpa: TryFromBytes,
pub fn gpa(&self) -> IdAa64IsaR1Gpawhere
IdAa64IsaR1Gpa: TryFromBytes,
The value of InstructionSetAttributeRegister1[27:24].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_gpa to recover from invalid bit patterns.
Sourcepub fn try_gpa(&self) -> Result<IdAa64IsaR1Gpa, InvalidBits<u8>>where
IdAa64IsaR1Gpa: TryFromBytes,
pub fn try_gpa(&self) -> Result<IdAa64IsaR1Gpa, InvalidBits<u8>>where
IdAa64IsaR1Gpa: TryFromBytes,
Fallible variant of Self::gpa.
Sourcepub fn set_gpa(&mut self, value: IdAa64IsaR1Gpa) -> &mut Self
pub fn set_gpa(&mut self, value: IdAa64IsaR1Gpa) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[27:24].
Sourcepub fn lrcpc(&self) -> IdAa64IsaR1Lrcpcwhere
IdAa64IsaR1Lrcpc: TryFromBytes,
pub fn lrcpc(&self) -> IdAa64IsaR1Lrcpcwhere
IdAa64IsaR1Lrcpc: TryFromBytes,
The value of InstructionSetAttributeRegister1[23:20].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_lrcpc to recover from invalid bit patterns.
Sourcepub fn try_lrcpc(&self) -> Result<IdAa64IsaR1Lrcpc, InvalidBits<u8>>where
IdAa64IsaR1Lrcpc: TryFromBytes,
pub fn try_lrcpc(&self) -> Result<IdAa64IsaR1Lrcpc, InvalidBits<u8>>where
IdAa64IsaR1Lrcpc: TryFromBytes,
Fallible variant of Self::lrcpc.
Sourcepub fn set_lrcpc(&mut self, value: IdAa64IsaR1Lrcpc) -> &mut Self
pub fn set_lrcpc(&mut self, value: IdAa64IsaR1Lrcpc) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[23:20].
Sourcepub fn fcma(&self) -> IdAa64IsaR1Fcmawhere
IdAa64IsaR1Fcma: TryFromBytes,
pub fn fcma(&self) -> IdAa64IsaR1Fcmawhere
IdAa64IsaR1Fcma: TryFromBytes,
The value of InstructionSetAttributeRegister1[19:16].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_fcma to recover from invalid bit patterns.
Sourcepub fn try_fcma(&self) -> Result<IdAa64IsaR1Fcma, InvalidBits<u8>>where
IdAa64IsaR1Fcma: TryFromBytes,
pub fn try_fcma(&self) -> Result<IdAa64IsaR1Fcma, InvalidBits<u8>>where
IdAa64IsaR1Fcma: TryFromBytes,
Fallible variant of Self::fcma.
Sourcepub fn set_fcma(&mut self, value: IdAa64IsaR1Fcma) -> &mut Self
pub fn set_fcma(&mut self, value: IdAa64IsaR1Fcma) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[19:16].
Sourcepub fn jscvt(&self) -> IdAa64IsaR1Jscvtwhere
IdAa64IsaR1Jscvt: TryFromBytes,
pub fn jscvt(&self) -> IdAa64IsaR1Jscvtwhere
IdAa64IsaR1Jscvt: TryFromBytes,
The value of InstructionSetAttributeRegister1[15:12].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_jscvt to recover from invalid bit patterns.
Sourcepub fn try_jscvt(&self) -> Result<IdAa64IsaR1Jscvt, InvalidBits<u8>>where
IdAa64IsaR1Jscvt: TryFromBytes,
pub fn try_jscvt(&self) -> Result<IdAa64IsaR1Jscvt, InvalidBits<u8>>where
IdAa64IsaR1Jscvt: TryFromBytes,
Fallible variant of Self::jscvt.
Sourcepub fn set_jscvt(&mut self, value: IdAa64IsaR1Jscvt) -> &mut Self
pub fn set_jscvt(&mut self, value: IdAa64IsaR1Jscvt) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[15:12].
Sourcepub fn api(&self) -> IdAa64IsaR1Pauthwhere
IdAa64IsaR1Pauth: TryFromBytes,
pub fn api(&self) -> IdAa64IsaR1Pauthwhere
IdAa64IsaR1Pauth: TryFromBytes,
The value of InstructionSetAttributeRegister1[11:8].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_api to recover from invalid bit patterns.
Sourcepub fn try_api(&self) -> Result<IdAa64IsaR1Pauth, InvalidBits<u8>>where
IdAa64IsaR1Pauth: TryFromBytes,
pub fn try_api(&self) -> Result<IdAa64IsaR1Pauth, InvalidBits<u8>>where
IdAa64IsaR1Pauth: TryFromBytes,
Fallible variant of Self::api.
Sourcepub fn set_api(&mut self, value: IdAa64IsaR1Pauth) -> &mut Self
pub fn set_api(&mut self, value: IdAa64IsaR1Pauth) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[11:8].
Sourcepub fn apa(&self) -> IdAa64IsaR1Pauthwhere
IdAa64IsaR1Pauth: TryFromBytes,
pub fn apa(&self) -> IdAa64IsaR1Pauthwhere
IdAa64IsaR1Pauth: TryFromBytes,
The value of InstructionSetAttributeRegister1[7:4].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_apa to recover from invalid bit patterns.
Sourcepub fn try_apa(&self) -> Result<IdAa64IsaR1Pauth, InvalidBits<u8>>where
IdAa64IsaR1Pauth: TryFromBytes,
pub fn try_apa(&self) -> Result<IdAa64IsaR1Pauth, InvalidBits<u8>>where
IdAa64IsaR1Pauth: TryFromBytes,
Fallible variant of Self::apa.
Sourcepub fn set_apa(&mut self, value: IdAa64IsaR1Pauth) -> &mut Self
pub fn set_apa(&mut self, value: IdAa64IsaR1Pauth) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[7:4].
Sourcepub fn dpb(&self) -> IdAa64IsaR1Dpbwhere
IdAa64IsaR1Dpb: TryFromBytes,
pub fn dpb(&self) -> IdAa64IsaR1Dpbwhere
IdAa64IsaR1Dpb: TryFromBytes,
The value of InstructionSetAttributeRegister1[3:0].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_dpb to recover from invalid bit patterns.
Sourcepub fn try_dpb(&self) -> Result<IdAa64IsaR1Dpb, InvalidBits<u8>>where
IdAa64IsaR1Dpb: TryFromBytes,
pub fn try_dpb(&self) -> Result<IdAa64IsaR1Dpb, InvalidBits<u8>>where
IdAa64IsaR1Dpb: TryFromBytes,
Fallible variant of Self::dpb.
Sourcepub fn set_dpb(&mut self, value: IdAa64IsaR1Dpb) -> &mut Self
pub fn set_dpb(&mut self, value: IdAa64IsaR1Dpb) -> &mut Self
Sets the value of InstructionSetAttributeRegister1[3:0].