pub struct InstructionSetAttributeRegister2(/* private fields */);Expand description
The layout of ID_AA64ISAR2_EL1.
Implementations
Sourceimpl InstructionSetAttributeRegister2
impl InstructionSetAttributeRegister2
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const ATS1A_MASK: u64
pub const ATS1A_MASK: u64
Unshifted bitmask of ats1a.
Sourcepub const ATS1A_SHIFT: usize = 60
pub const ATS1A_SHIFT: usize = 60
Bit shift (i.e., the low bit) of ats1a.
Sourcepub const CSSC_SHIFT: usize = 52
pub const CSSC_SHIFT: usize = 52
Bit shift (i.e., the low bit) of cssc.
Sourcepub const RPRFM_MASK: u64
pub const RPRFM_MASK: u64
Unshifted bitmask of rprfm.
Sourcepub const RPRFM_SHIFT: usize = 48
pub const RPRFM_SHIFT: usize = 48
Bit shift (i.e., the low bit) of rprfm.
Sourcepub const PRFMSLC_MASK: u64
pub const PRFMSLC_MASK: u64
Unshifted bitmask of prfmslc.
Sourcepub const PRFMSLC_SHIFT: usize = 40
pub const PRFMSLC_SHIFT: usize = 40
Bit shift (i.e., the low bit) of prfmslc.
Sourcepub const SYSINSTR_128_MASK: u64
pub const SYSINSTR_128_MASK: u64
Unshifted bitmask of sysinstr_128.
Sourcepub const SYSINSTR_128_SHIFT: usize = 36
pub const SYSINSTR_128_SHIFT: usize = 36
Bit shift (i.e., the low bit) of sysinstr_128.
Sourcepub const SYSREG_128_MASK: u64
pub const SYSREG_128_MASK: u64
Unshifted bitmask of sysreg_128.
Sourcepub const SYSREG_128_SHIFT: usize = 32
pub const SYSREG_128_SHIFT: usize = 32
Bit shift (i.e., the low bit) of sysreg_128.
Sourcepub const CLRBHB_MASK: u64
pub const CLRBHB_MASK: u64
Unshifted bitmask of clrbhb.
Sourcepub const CLRBHB_SHIFT: usize = 28
pub const CLRBHB_SHIFT: usize = 28
Bit shift (i.e., the low bit) of clrbhb.
Sourcepub const PAC_FRAC_MASK: u64
pub const PAC_FRAC_MASK: u64
Unshifted bitmask of pac_frac.
Sourcepub const PAC_FRAC_SHIFT: usize = 24
pub const PAC_FRAC_SHIFT: usize = 24
Bit shift (i.e., the low bit) of pac_frac.
Sourcepub const MOPS_SHIFT: usize = 16
pub const MOPS_SHIFT: usize = 16
Bit shift (i.e., the low bit) of mops.
Sourcepub const APA3_SHIFT: usize = 12
pub const APA3_SHIFT: usize = 12
Bit shift (i.e., the low bit) of apa3.
Sourcepub const GPA3_SHIFT: usize = 8
pub const GPA3_SHIFT: usize = 8
Bit shift (i.e., the low bit) of gpa3.
Sourcepub const RPRES_MASK: u64
pub const RPRES_MASK: u64
Unshifted bitmask of rpres.
Sourcepub const RPRES_SHIFT: usize = 4
pub const RPRES_SHIFT: usize = 4
Bit shift (i.e., the low bit) of rpres.
Sourcepub const WFXT_SHIFT: usize = 0
pub const WFXT_SHIFT: usize = 0
Bit shift (i.e., the low bit) of wfxt.
Sourcepub const FIELDS: [FieldMetadata<u64>; 15]
pub const FIELDS: [FieldMetadata<u64>; 15]
Metadata of all named fields in the layout.
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub fn ats1a(&self) -> IdAa64IsaR2Ats1awhere
IdAa64IsaR2Ats1a: TryFromBytes,
pub fn ats1a(&self) -> IdAa64IsaR2Ats1awhere
IdAa64IsaR2Ats1a: TryFromBytes,
The value of InstructionSetAttributeRegister2[63:60].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ats1a to recover from invalid bit patterns.
Sourcepub fn try_ats1a(&self) -> Result<IdAa64IsaR2Ats1a, InvalidBits<u8>>where
IdAa64IsaR2Ats1a: TryFromBytes,
pub fn try_ats1a(&self) -> Result<IdAa64IsaR2Ats1a, InvalidBits<u8>>where
IdAa64IsaR2Ats1a: TryFromBytes,
Fallible variant of Self::ats1a.
Sourcepub fn set_ats1a(&mut self, value: IdAa64IsaR2Ats1a) -> &mut Self
pub fn set_ats1a(&mut self, value: IdAa64IsaR2Ats1a) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[63:60].
Sourcepub fn lut(&self) -> IdAa64IsaR2Lutwhere
IdAa64IsaR2Lut: TryFromBytes,
pub fn lut(&self) -> IdAa64IsaR2Lutwhere
IdAa64IsaR2Lut: TryFromBytes,
The value of InstructionSetAttributeRegister2[59:56].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_lut to recover from invalid bit patterns.
Sourcepub fn try_lut(&self) -> Result<IdAa64IsaR2Lut, InvalidBits<u8>>where
IdAa64IsaR2Lut: TryFromBytes,
pub fn try_lut(&self) -> Result<IdAa64IsaR2Lut, InvalidBits<u8>>where
IdAa64IsaR2Lut: TryFromBytes,
Fallible variant of Self::lut.
Sourcepub fn set_lut(&mut self, value: IdAa64IsaR2Lut) -> &mut Self
pub fn set_lut(&mut self, value: IdAa64IsaR2Lut) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[59:56].
Sourcepub fn cssc(&self) -> IdAa64IsaR2Csscwhere
IdAa64IsaR2Cssc: TryFromBytes,
pub fn cssc(&self) -> IdAa64IsaR2Csscwhere
IdAa64IsaR2Cssc: TryFromBytes,
The value of InstructionSetAttributeRegister2[55:52].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_cssc to recover from invalid bit patterns.
Sourcepub fn try_cssc(&self) -> Result<IdAa64IsaR2Cssc, InvalidBits<u8>>where
IdAa64IsaR2Cssc: TryFromBytes,
pub fn try_cssc(&self) -> Result<IdAa64IsaR2Cssc, InvalidBits<u8>>where
IdAa64IsaR2Cssc: TryFromBytes,
Fallible variant of Self::cssc.
Sourcepub fn set_cssc(&mut self, value: IdAa64IsaR2Cssc) -> &mut Self
pub fn set_cssc(&mut self, value: IdAa64IsaR2Cssc) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[55:52].
Sourcepub fn rprfm(&self) -> IdAa64IsaR2Rprfmwhere
IdAa64IsaR2Rprfm: TryFromBytes,
pub fn rprfm(&self) -> IdAa64IsaR2Rprfmwhere
IdAa64IsaR2Rprfm: TryFromBytes,
The value of InstructionSetAttributeRegister2[51:48].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_rprfm to recover from invalid bit patterns.
Sourcepub fn try_rprfm(&self) -> Result<IdAa64IsaR2Rprfm, InvalidBits<u8>>where
IdAa64IsaR2Rprfm: TryFromBytes,
pub fn try_rprfm(&self) -> Result<IdAa64IsaR2Rprfm, InvalidBits<u8>>where
IdAa64IsaR2Rprfm: TryFromBytes,
Fallible variant of Self::rprfm.
Sourcepub fn set_rprfm(&mut self, value: IdAa64IsaR2Rprfm) -> &mut Self
pub fn set_rprfm(&mut self, value: IdAa64IsaR2Rprfm) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[51:48].
Sourcepub fn prfmslc(&self) -> IdAa64IsaR2Prfmslcwhere
IdAa64IsaR2Prfmslc: TryFromBytes,
pub fn prfmslc(&self) -> IdAa64IsaR2Prfmslcwhere
IdAa64IsaR2Prfmslc: TryFromBytes,
The value of InstructionSetAttributeRegister2[43:40].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_prfmslc to recover from invalid bit patterns.
Sourcepub fn try_prfmslc(&self) -> Result<IdAa64IsaR2Prfmslc, InvalidBits<u8>>where
IdAa64IsaR2Prfmslc: TryFromBytes,
pub fn try_prfmslc(&self) -> Result<IdAa64IsaR2Prfmslc, InvalidBits<u8>>where
IdAa64IsaR2Prfmslc: TryFromBytes,
Fallible variant of Self::prfmslc.
Sourcepub fn set_prfmslc(&mut self, value: IdAa64IsaR2Prfmslc) -> &mut Self
pub fn set_prfmslc(&mut self, value: IdAa64IsaR2Prfmslc) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[43:40].
Sourcepub fn sysinstr_128(&self) -> IdAa64IsaR2Sysinstr128where
IdAa64IsaR2Sysinstr128: TryFromBytes,
pub fn sysinstr_128(&self) -> IdAa64IsaR2Sysinstr128where
IdAa64IsaR2Sysinstr128: TryFromBytes,
The value of InstructionSetAttributeRegister2[39:36].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sysinstr_128 to recover from invalid bit patterns.
Sourcepub fn try_sysinstr_128(
&self,
) -> Result<IdAa64IsaR2Sysinstr128, InvalidBits<u8>>where
IdAa64IsaR2Sysinstr128: TryFromBytes,
pub fn try_sysinstr_128(
&self,
) -> Result<IdAa64IsaR2Sysinstr128, InvalidBits<u8>>where
IdAa64IsaR2Sysinstr128: TryFromBytes,
Fallible variant of Self::sysinstr_128.
Sourcepub fn set_sysinstr_128(&mut self, value: IdAa64IsaR2Sysinstr128) -> &mut Self
pub fn set_sysinstr_128(&mut self, value: IdAa64IsaR2Sysinstr128) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[39:36].
Sourcepub fn sysreg_128(&self) -> IdAa64IsaR2Sysreg128where
IdAa64IsaR2Sysreg128: TryFromBytes,
pub fn sysreg_128(&self) -> IdAa64IsaR2Sysreg128where
IdAa64IsaR2Sysreg128: TryFromBytes,
The value of InstructionSetAttributeRegister2[35:32].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sysreg_128 to recover from invalid bit patterns.
Sourcepub fn try_sysreg_128(&self) -> Result<IdAa64IsaR2Sysreg128, InvalidBits<u8>>where
IdAa64IsaR2Sysreg128: TryFromBytes,
pub fn try_sysreg_128(&self) -> Result<IdAa64IsaR2Sysreg128, InvalidBits<u8>>where
IdAa64IsaR2Sysreg128: TryFromBytes,
Fallible variant of Self::sysreg_128.
Sourcepub fn set_sysreg_128(&mut self, value: IdAa64IsaR2Sysreg128) -> &mut Self
pub fn set_sysreg_128(&mut self, value: IdAa64IsaR2Sysreg128) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[35:32].
Sourcepub fn clrbhb(&self) -> IdAa64IsaR2Clrbhbwhere
IdAa64IsaR2Clrbhb: TryFromBytes,
pub fn clrbhb(&self) -> IdAa64IsaR2Clrbhbwhere
IdAa64IsaR2Clrbhb: TryFromBytes,
The value of InstructionSetAttributeRegister2[31:28].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_clrbhb to recover from invalid bit patterns.
Sourcepub fn try_clrbhb(&self) -> Result<IdAa64IsaR2Clrbhb, InvalidBits<u8>>where
IdAa64IsaR2Clrbhb: TryFromBytes,
pub fn try_clrbhb(&self) -> Result<IdAa64IsaR2Clrbhb, InvalidBits<u8>>where
IdAa64IsaR2Clrbhb: TryFromBytes,
Fallible variant of Self::clrbhb.
Sourcepub fn set_clrbhb(&mut self, value: IdAa64IsaR2Clrbhb) -> &mut Self
pub fn set_clrbhb(&mut self, value: IdAa64IsaR2Clrbhb) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[31:28].
Sourcepub fn pac_frac(&self) -> IdAa64IsaR2PacFracwhere
IdAa64IsaR2PacFrac: TryFromBytes,
pub fn pac_frac(&self) -> IdAa64IsaR2PacFracwhere
IdAa64IsaR2PacFrac: TryFromBytes,
The value of InstructionSetAttributeRegister2[27:24].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_pac_frac to recover from invalid bit patterns.
Sourcepub fn try_pac_frac(&self) -> Result<IdAa64IsaR2PacFrac, InvalidBits<u8>>where
IdAa64IsaR2PacFrac: TryFromBytes,
pub fn try_pac_frac(&self) -> Result<IdAa64IsaR2PacFrac, InvalidBits<u8>>where
IdAa64IsaR2PacFrac: TryFromBytes,
Fallible variant of Self::pac_frac.
Sourcepub fn set_pac_frac(&mut self, value: IdAa64IsaR2PacFrac) -> &mut Self
pub fn set_pac_frac(&mut self, value: IdAa64IsaR2PacFrac) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[27:24].
Sourcepub fn bc(&self) -> IdAa64IsaR2Bcwhere
IdAa64IsaR2Bc: TryFromBytes,
pub fn bc(&self) -> IdAa64IsaR2Bcwhere
IdAa64IsaR2Bc: TryFromBytes,
The value of InstructionSetAttributeRegister2[23:20].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_bc to recover from invalid bit patterns.
Sourcepub fn try_bc(&self) -> Result<IdAa64IsaR2Bc, InvalidBits<u8>>where
IdAa64IsaR2Bc: TryFromBytes,
pub fn try_bc(&self) -> Result<IdAa64IsaR2Bc, InvalidBits<u8>>where
IdAa64IsaR2Bc: TryFromBytes,
Fallible variant of Self::bc.
Sourcepub fn set_bc(&mut self, value: IdAa64IsaR2Bc) -> &mut Self
pub fn set_bc(&mut self, value: IdAa64IsaR2Bc) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[23:20].
Sourcepub fn mops(&self) -> IdAa64IsaR2Mopswhere
IdAa64IsaR2Mops: TryFromBytes,
pub fn mops(&self) -> IdAa64IsaR2Mopswhere
IdAa64IsaR2Mops: TryFromBytes,
The value of InstructionSetAttributeRegister2[19:16].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_mops to recover from invalid bit patterns.
Sourcepub fn try_mops(&self) -> Result<IdAa64IsaR2Mops, InvalidBits<u8>>where
IdAa64IsaR2Mops: TryFromBytes,
pub fn try_mops(&self) -> Result<IdAa64IsaR2Mops, InvalidBits<u8>>where
IdAa64IsaR2Mops: TryFromBytes,
Fallible variant of Self::mops.
Sourcepub fn set_mops(&mut self, value: IdAa64IsaR2Mops) -> &mut Self
pub fn set_mops(&mut self, value: IdAa64IsaR2Mops) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[19:16].
Sourcepub fn apa3(&self) -> IdAa64IsaR2Apa3where
IdAa64IsaR2Apa3: TryFromBytes,
pub fn apa3(&self) -> IdAa64IsaR2Apa3where
IdAa64IsaR2Apa3: TryFromBytes,
The value of InstructionSetAttributeRegister2[15:12].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_apa3 to recover from invalid bit patterns.
Sourcepub fn try_apa3(&self) -> Result<IdAa64IsaR2Apa3, InvalidBits<u8>>where
IdAa64IsaR2Apa3: TryFromBytes,
pub fn try_apa3(&self) -> Result<IdAa64IsaR2Apa3, InvalidBits<u8>>where
IdAa64IsaR2Apa3: TryFromBytes,
Fallible variant of Self::apa3.
Sourcepub fn set_apa3(&mut self, value: IdAa64IsaR2Apa3) -> &mut Self
pub fn set_apa3(&mut self, value: IdAa64IsaR2Apa3) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[15:12].
Sourcepub fn gpa3(&self) -> IdAa64IsaR2Gpa3where
IdAa64IsaR2Gpa3: TryFromBytes,
pub fn gpa3(&self) -> IdAa64IsaR2Gpa3where
IdAa64IsaR2Gpa3: TryFromBytes,
The value of InstructionSetAttributeRegister2[11:8].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_gpa3 to recover from invalid bit patterns.
Sourcepub fn try_gpa3(&self) -> Result<IdAa64IsaR2Gpa3, InvalidBits<u8>>where
IdAa64IsaR2Gpa3: TryFromBytes,
pub fn try_gpa3(&self) -> Result<IdAa64IsaR2Gpa3, InvalidBits<u8>>where
IdAa64IsaR2Gpa3: TryFromBytes,
Fallible variant of Self::gpa3.
Sourcepub fn set_gpa3(&mut self, value: IdAa64IsaR2Gpa3) -> &mut Self
pub fn set_gpa3(&mut self, value: IdAa64IsaR2Gpa3) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[11:8].
Sourcepub fn rpres(&self) -> IdAa64IsaR2Rpreswhere
IdAa64IsaR2Rpres: TryFromBytes,
pub fn rpres(&self) -> IdAa64IsaR2Rpreswhere
IdAa64IsaR2Rpres: TryFromBytes,
The value of InstructionSetAttributeRegister2[7:4].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_rpres to recover from invalid bit patterns.
Sourcepub fn try_rpres(&self) -> Result<IdAa64IsaR2Rpres, InvalidBits<u8>>where
IdAa64IsaR2Rpres: TryFromBytes,
pub fn try_rpres(&self) -> Result<IdAa64IsaR2Rpres, InvalidBits<u8>>where
IdAa64IsaR2Rpres: TryFromBytes,
Fallible variant of Self::rpres.
Sourcepub fn set_rpres(&mut self, value: IdAa64IsaR2Rpres) -> &mut Self
pub fn set_rpres(&mut self, value: IdAa64IsaR2Rpres) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[7:4].
Sourcepub fn wfxt(&self) -> IdAa64IsaR2Wfxtwhere
IdAa64IsaR2Wfxt: TryFromBytes,
pub fn wfxt(&self) -> IdAa64IsaR2Wfxtwhere
IdAa64IsaR2Wfxt: TryFromBytes,
The value of InstructionSetAttributeRegister2[3:0].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_wfxt to recover from invalid bit patterns.
Sourcepub fn try_wfxt(&self) -> Result<IdAa64IsaR2Wfxt, InvalidBits<u8>>where
IdAa64IsaR2Wfxt: TryFromBytes,
pub fn try_wfxt(&self) -> Result<IdAa64IsaR2Wfxt, InvalidBits<u8>>where
IdAa64IsaR2Wfxt: TryFromBytes,
Fallible variant of Self::wfxt.
Sourcepub fn set_wfxt(&mut self, value: IdAa64IsaR2Wfxt) -> &mut Self
pub fn set_wfxt(&mut self, value: IdAa64IsaR2Wfxt) -> &mut Self
Sets the value of InstructionSetAttributeRegister2[3:0].