pub struct SystemControlRegisterEl1(/* private fields */);Expand description
The layout of SCTLR_EL1.
Implementations
Sourceimpl SystemControlRegisterEl1
impl SystemControlRegisterEl1
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const TIDCP_MASK: u64
pub const TIDCP_MASK: u64
Unshifted bitmask of tidcp.
Sourcepub const TIDCP_SHIFT: usize = 63
pub const TIDCP_SHIFT: usize = 63
Bit shift (i.e., the low bit) of tidcp.
Sourcepub const SPINTMASK_MASK: u64
pub const SPINTMASK_MASK: u64
Unshifted bitmask of spintmask.
Sourcepub const SPINTMASK_SHIFT: usize = 62
pub const SPINTMASK_SHIFT: usize = 62
Bit shift (i.e., the low bit) of spintmask.
Sourcepub const ENTP2_MASK: u64
pub const ENTP2_MASK: u64
Unshifted bitmask of entp2.
Sourcepub const ENTP2_SHIFT: usize = 60
pub const ENTP2_SHIFT: usize = 60
Bit shift (i.e., the low bit) of entp2.
Sourcepub const TSCO_SHIFT: usize = 59
pub const TSCO_SHIFT: usize = 59
Bit shift (i.e., the low bit) of tsco.
Sourcepub const TSCO0_MASK: u64
pub const TSCO0_MASK: u64
Unshifted bitmask of tsco0.
Sourcepub const TSCO0_SHIFT: usize = 58
pub const TSCO0_SHIFT: usize = 58
Bit shift (i.e., the low bit) of tsco0.
Sourcepub const EPAN_SHIFT: usize = 57
pub const EPAN_SHIFT: usize = 57
Bit shift (i.e., the low bit) of epan.
Sourcepub const ENALS_MASK: u64
pub const ENALS_MASK: u64
Unshifted bitmask of enals.
Sourcepub const ENALS_SHIFT: usize = 56
pub const ENALS_SHIFT: usize = 56
Bit shift (i.e., the low bit) of enals.
Sourcepub const ENAS0_MASK: u64
pub const ENAS0_MASK: u64
Unshifted bitmask of enas0.
Sourcepub const ENAS0_SHIFT: usize = 55
pub const ENAS0_SHIFT: usize = 55
Bit shift (i.e., the low bit) of enas0.
Sourcepub const ENASR_MASK: u64
pub const ENASR_MASK: u64
Unshifted bitmask of enasr.
Sourcepub const ENASR_SHIFT: usize = 54
pub const ENASR_SHIFT: usize = 54
Bit shift (i.e., the low bit) of enasr.
Sourcepub const TME0_SHIFT: usize = 52
pub const TME0_SHIFT: usize = 52
Bit shift (i.e., the low bit) of tme0.
Sourcepub const TMT0_SHIFT: usize = 50
pub const TMT0_SHIFT: usize = 50
Bit shift (i.e., the low bit) of tmt0.
Sourcepub const TWEDEL_MASK: u64
pub const TWEDEL_MASK: u64
Unshifted bitmask of twedel.
Sourcepub const TWEDEL_SHIFT: usize = 46
pub const TWEDEL_SHIFT: usize = 46
Bit shift (i.e., the low bit) of twedel.
Sourcepub const TWEDEN_MASK: u64
pub const TWEDEN_MASK: u64
Unshifted bitmask of tweden.
Sourcepub const TWEDEN_SHIFT: usize = 45
pub const TWEDEN_SHIFT: usize = 45
Bit shift (i.e., the low bit) of tweden.
Sourcepub const DSBSS_MASK: u64
pub const DSBSS_MASK: u64
Unshifted bitmask of dsbss.
Sourcepub const DSBSS_SHIFT: usize = 44
pub const DSBSS_SHIFT: usize = 44
Bit shift (i.e., the low bit) of dsbss.
Sourcepub const ATA0_SHIFT: usize = 42
pub const ATA0_SHIFT: usize = 42
Bit shift (i.e., the low bit) of ata0.
Sourcepub const TCF0_SHIFT: usize = 38
pub const TCF0_SHIFT: usize = 38
Bit shift (i.e., the low bit) of tcf0.
Sourcepub const ITFSB_MASK: u64
pub const ITFSB_MASK: u64
Unshifted bitmask of itfsb.
Sourcepub const ITFSB_SHIFT: usize = 37
pub const ITFSB_SHIFT: usize = 37
Bit shift (i.e., the low bit) of itfsb.
Sourcepub const MSCEN_MASK: u64
pub const MSCEN_MASK: u64
Unshifted bitmask of mscen.
Sourcepub const MSCEN_SHIFT: usize = 33
pub const MSCEN_SHIFT: usize = 33
Bit shift (i.e., the low bit) of mscen.
Sourcepub const CMOW_SHIFT: usize = 32
pub const CMOW_SHIFT: usize = 32
Bit shift (i.e., the low bit) of cmow.
Sourcepub const ENIA_SHIFT: usize = 31
pub const ENIA_SHIFT: usize = 31
Bit shift (i.e., the low bit) of enia.
Sourcepub const ENIB_SHIFT: usize = 30
pub const ENIB_SHIFT: usize = 30
Bit shift (i.e., the low bit) of enib.
Sourcepub const LSMAOE_MASK: u64
pub const LSMAOE_MASK: u64
Unshifted bitmask of lsmaoe.
Sourcepub const LSMAOE_SHIFT: usize = 29
pub const LSMAOE_SHIFT: usize = 29
Bit shift (i.e., the low bit) of lsmaoe.
Sourcepub const NTLSMD_MASK: u64
pub const NTLSMD_MASK: u64
Unshifted bitmask of ntlsmd.
Sourcepub const NTLSMD_SHIFT: usize = 28
pub const NTLSMD_SHIFT: usize = 28
Bit shift (i.e., the low bit) of ntlsmd.
Sourcepub const ENDA_SHIFT: usize = 27
pub const ENDA_SHIFT: usize = 27
Bit shift (i.e., the low bit) of enda.
Sourcepub const SPAN_SHIFT: usize = 23
pub const SPAN_SHIFT: usize = 23
Bit shift (i.e., the low bit) of span.
Sourcepub const IESB_SHIFT: usize = 21
pub const IESB_SHIFT: usize = 21
Bit shift (i.e., the low bit) of iesb.
Sourcepub const TSCXT_MASK: u64
pub const TSCXT_MASK: u64
Unshifted bitmask of tscxt.
Sourcepub const TSCXT_SHIFT: usize = 20
pub const TSCXT_SHIFT: usize = 20
Bit shift (i.e., the low bit) of tscxt.
Sourcepub const NTWE_SHIFT: usize = 18
pub const NTWE_SHIFT: usize = 18
Bit shift (i.e., the low bit) of ntwe.
Sourcepub const NTWI_SHIFT: usize = 16
pub const NTWI_SHIFT: usize = 16
Bit shift (i.e., the low bit) of ntwi.
Sourcepub const ENDB_SHIFT: usize = 13
pub const ENDB_SHIFT: usize = 13
Bit shift (i.e., the low bit) of endb.
Sourcepub const ENRCTX_MASK: u64
pub const ENRCTX_MASK: u64
Unshifted bitmask of enrctx.
Sourcepub const ENRCTX_SHIFT: usize = 10
pub const ENRCTX_SHIFT: usize = 10
Bit shift (i.e., the low bit) of enrctx.
Sourcepub const CP15BEN_MASK: u64
pub const CP15BEN_MASK: u64
Unshifted bitmask of cp15ben.
Sourcepub const CP15BEN_SHIFT: usize = 5
pub const CP15BEN_SHIFT: usize = 5
Bit shift (i.e., the low bit) of cp15ben.
Sourcepub const FIELDS: [FieldMetadata<u64>; 57]
pub const FIELDS: [FieldMetadata<u64>; 57]
Metadata of all named fields in the layout.
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub const fn set_tidcp(&mut self, value: bool) -> &mut Self
pub const fn set_tidcp(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl163.
Sourcepub const fn set_spintmask(&mut self, value: bool) -> &mut Self
pub const fn set_spintmask(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl162.
Sourcepub const fn set_nmi(&mut self, value: bool) -> &mut Self
pub const fn set_nmi(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl161.
Sourcepub const fn set_entp2(&mut self, value: bool) -> &mut Self
pub const fn set_entp2(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl160.
Sourcepub const fn set_tsco(&mut self, value: bool) -> &mut Self
pub const fn set_tsco(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl159.
Sourcepub const fn set_tsco0(&mut self, value: bool) -> &mut Self
pub const fn set_tsco0(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl158.
Sourcepub const fn set_epan(&mut self, value: bool) -> &mut Self
pub const fn set_epan(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl157.
Sourcepub const fn set_enals(&mut self, value: bool) -> &mut Self
pub const fn set_enals(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl156.
Sourcepub const fn set_enas0(&mut self, value: bool) -> &mut Self
pub const fn set_enas0(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl155.
Sourcepub const fn set_enasr(&mut self, value: bool) -> &mut Self
pub const fn set_enasr(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl154.
Sourcepub const fn set_tme(&mut self, value: bool) -> &mut Self
pub const fn set_tme(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl153.
Sourcepub const fn set_tme0(&mut self, value: bool) -> &mut Self
pub const fn set_tme0(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl152.
Sourcepub const fn set_tmt(&mut self, value: bool) -> &mut Self
pub const fn set_tmt(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl151.
Sourcepub const fn set_tmt0(&mut self, value: bool) -> &mut Self
pub const fn set_tmt0(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl150.
Sourcepub const fn set_twedel(&mut self, value: u8) -> &mut Self
pub const fn set_twedel(&mut self, value: u8) -> &mut Self
Sets the value of SystemControlRegisterEl1[49:46].
Sourcepub const fn set_tweden(&mut self, value: bool) -> &mut Self
pub const fn set_tweden(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl145.
Sourcepub const fn set_dsbss(&mut self, value: bool) -> &mut Self
pub const fn set_dsbss(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl144.
Sourcepub const fn set_ata(&mut self, value: bool) -> &mut Self
pub const fn set_ata(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl143.
Sourcepub const fn set_ata0(&mut self, value: bool) -> &mut Self
pub const fn set_ata0(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl142.
Sourcepub fn tcf(&self) -> TagCheckFaultwhere
TagCheckFault: TryFromBytes,
pub fn tcf(&self) -> TagCheckFaultwhere
TagCheckFault: TryFromBytes,
The value of SystemControlRegisterEl1[41:40].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tcf to recover from invalid bit patterns.
Sourcepub fn try_tcf(&self) -> Result<TagCheckFault, InvalidBits<u8>>where
TagCheckFault: TryFromBytes,
pub fn try_tcf(&self) -> Result<TagCheckFault, InvalidBits<u8>>where
TagCheckFault: TryFromBytes,
Fallible variant of Self::tcf.
Sourcepub fn set_tcf(&mut self, value: TagCheckFault) -> &mut Self
pub fn set_tcf(&mut self, value: TagCheckFault) -> &mut Self
Sets the value of SystemControlRegisterEl1[41:40].
Sourcepub fn tcf0(&self) -> TagCheckFaultwhere
TagCheckFault: TryFromBytes,
pub fn tcf0(&self) -> TagCheckFaultwhere
TagCheckFault: TryFromBytes,
The value of SystemControlRegisterEl1[39:38].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tcf0 to recover from invalid bit patterns.
Sourcepub fn try_tcf0(&self) -> Result<TagCheckFault, InvalidBits<u8>>where
TagCheckFault: TryFromBytes,
pub fn try_tcf0(&self) -> Result<TagCheckFault, InvalidBits<u8>>where
TagCheckFault: TryFromBytes,
Fallible variant of Self::tcf0.
Sourcepub fn set_tcf0(&mut self, value: TagCheckFault) -> &mut Self
pub fn set_tcf0(&mut self, value: TagCheckFault) -> &mut Self
Sets the value of SystemControlRegisterEl1[39:38].
Sourcepub const fn set_itfsb(&mut self, value: bool) -> &mut Self
pub const fn set_itfsb(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl137.
Sourcepub const fn set_bt(&mut self, value: bool) -> &mut Self
pub const fn set_bt(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl136.
Sourcepub const fn set_bt0(&mut self, value: bool) -> &mut Self
pub const fn set_bt0(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl135.
Sourcepub const fn set_mscen(&mut self, value: bool) -> &mut Self
pub const fn set_mscen(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl133.
Sourcepub const fn set_cmow(&mut self, value: bool) -> &mut Self
pub const fn set_cmow(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl132.
Sourcepub const fn set_enia(&mut self, value: bool) -> &mut Self
pub const fn set_enia(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl131.
Sourcepub const fn set_enib(&mut self, value: bool) -> &mut Self
pub const fn set_enib(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl130.
Sourcepub const fn set_lsmaoe(&mut self, value: bool) -> &mut Self
pub const fn set_lsmaoe(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl129.
Sourcepub const fn set_ntlsmd(&mut self, value: bool) -> &mut Self
pub const fn set_ntlsmd(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl128.
Sourcepub const fn set_enda(&mut self, value: bool) -> &mut Self
pub const fn set_enda(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl127.
Sourcepub const fn set_uci(&mut self, value: bool) -> &mut Self
pub const fn set_uci(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl126.
Sourcepub const fn set_ee(&mut self, value: bool) -> &mut Self
pub const fn set_ee(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl125.
Sourcepub const fn set_e0e(&mut self, value: bool) -> &mut Self
pub const fn set_e0e(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl124.
Sourcepub const fn set_span(&mut self, value: bool) -> &mut Self
pub const fn set_span(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl123.
Sourcepub const fn set_eis(&mut self, value: bool) -> &mut Self
pub const fn set_eis(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl122.
Sourcepub const fn set_iesb(&mut self, value: bool) -> &mut Self
pub const fn set_iesb(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl121.
Sourcepub const fn set_tscxt(&mut self, value: bool) -> &mut Self
pub const fn set_tscxt(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl120.
Sourcepub const fn set_wxn(&mut self, value: bool) -> &mut Self
pub const fn set_wxn(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl119.
Sourcepub const fn set_ntwe(&mut self, value: bool) -> &mut Self
pub const fn set_ntwe(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl118.
Sourcepub const fn set_ntwi(&mut self, value: bool) -> &mut Self
pub const fn set_ntwi(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl116.
Sourcepub const fn set_uct(&mut self, value: bool) -> &mut Self
pub const fn set_uct(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl115.
Sourcepub const fn set_dze(&mut self, value: bool) -> &mut Self
pub const fn set_dze(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl114.
Sourcepub const fn set_endb(&mut self, value: bool) -> &mut Self
pub const fn set_endb(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl113.
Sourcepub const fn set_i(&mut self, value: bool) -> &mut Self
pub const fn set_i(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl112.
Sourcepub const fn set_eos(&mut self, value: bool) -> &mut Self
pub const fn set_eos(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl111.
Sourcepub const fn set_enrctx(&mut self, value: bool) -> &mut Self
pub const fn set_enrctx(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl110.
Sourcepub const fn set_uma(&mut self, value: bool) -> &mut Self
pub const fn set_uma(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl19.
Sourcepub const fn set_sed(&mut self, value: bool) -> &mut Self
pub const fn set_sed(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl18.
Sourcepub const fn set_itd(&mut self, value: bool) -> &mut Self
pub const fn set_itd(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl17.
Sourcepub const fn set_naa(&mut self, value: bool) -> &mut Self
pub const fn set_naa(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl16.
Sourcepub const fn set_cp15ben(&mut self, value: bool) -> &mut Self
pub const fn set_cp15ben(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl15.
Sourcepub const fn set_sa0(&mut self, value: bool) -> &mut Self
pub const fn set_sa0(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl14.
Sourcepub const fn set_sa(&mut self, value: bool) -> &mut Self
pub const fn set_sa(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl13.
Sourcepub const fn set_c(&mut self, value: bool) -> &mut Self
pub const fn set_c(&mut self, value: bool) -> &mut Self
Sets the value of SystemControlRegisterEl12.
Sourceimpl SystemControlRegisterEl1
impl SystemControlRegisterEl1
Sourcepub fn twedel_cycles(&self) -> Option<u64>
pub fn twedel_cycles(&self) -> Option<u64>
Returns the minimum delay in cycles if TWEDEn is enabled.