pub struct TranslationControlRegisterEl1(/* private fields */);Expand description
The layout of TCR_EL1.
Implementations
Sourceimpl TranslationControlRegisterEl1
impl TranslationControlRegisterEl1
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const MTX1_SHIFT: usize = 61
pub const MTX1_SHIFT: usize = 61
Bit shift (i.e., the low bit) of mtx1.
Sourcepub const MTX0_SHIFT: usize = 60
pub const MTX0_SHIFT: usize = 60
Bit shift (i.e., the low bit) of mtx0.
Sourcepub const TCMA1_MASK: u64
pub const TCMA1_MASK: u64
Unshifted bitmask of tcma1.
Sourcepub const TCMA1_SHIFT: usize = 58
pub const TCMA1_SHIFT: usize = 58
Bit shift (i.e., the low bit) of tcma1.
Sourcepub const TCMA0_MASK: u64
pub const TCMA0_MASK: u64
Unshifted bitmask of tcma0.
Sourcepub const TCMA0_SHIFT: usize = 57
pub const TCMA0_SHIFT: usize = 57
Bit shift (i.e., the low bit) of tcma0.
Sourcepub const E0PD1_MASK: u64
pub const E0PD1_MASK: u64
Unshifted bitmask of e0pd1.
Sourcepub const E0PD1_SHIFT: usize = 56
pub const E0PD1_SHIFT: usize = 56
Bit shift (i.e., the low bit) of e0pd1.
Sourcepub const E0PD0_MASK: u64
pub const E0PD0_MASK: u64
Unshifted bitmask of e0pd0.
Sourcepub const E0PD0_SHIFT: usize = 55
pub const E0PD0_SHIFT: usize = 55
Bit shift (i.e., the low bit) of e0pd0.
Sourcepub const NFD1_SHIFT: usize = 54
pub const NFD1_SHIFT: usize = 54
Bit shift (i.e., the low bit) of nfd1.
Sourcepub const NFD0_SHIFT: usize = 53
pub const NFD0_SHIFT: usize = 53
Bit shift (i.e., the low bit) of nfd0.
Sourcepub const TBID1_MASK: u64
pub const TBID1_MASK: u64
Unshifted bitmask of tbid1.
Sourcepub const TBID1_SHIFT: usize = 52
pub const TBID1_SHIFT: usize = 52
Bit shift (i.e., the low bit) of tbid1.
Sourcepub const TBID0_MASK: u64
pub const TBID0_MASK: u64
Unshifted bitmask of tbid0.
Sourcepub const TBID0_SHIFT: usize = 51
pub const TBID0_SHIFT: usize = 51
Bit shift (i.e., the low bit) of tbid0.
Sourcepub const HWU162_MASK: u64
pub const HWU162_MASK: u64
Unshifted bitmask of hwu162.
Sourcepub const HWU162_SHIFT: usize = 50
pub const HWU162_SHIFT: usize = 50
Bit shift (i.e., the low bit) of hwu162.
Sourcepub const HWU161_MASK: u64
pub const HWU161_MASK: u64
Unshifted bitmask of hwu161.
Sourcepub const HWU161_SHIFT: usize = 49
pub const HWU161_SHIFT: usize = 49
Bit shift (i.e., the low bit) of hwu161.
Sourcepub const HWU160_MASK: u64
pub const HWU160_MASK: u64
Unshifted bitmask of hwu160.
Sourcepub const HWU160_SHIFT: usize = 48
pub const HWU160_SHIFT: usize = 48
Bit shift (i.e., the low bit) of hwu160.
Sourcepub const HWU159_MASK: u64
pub const HWU159_MASK: u64
Unshifted bitmask of hwu159.
Sourcepub const HWU159_SHIFT: usize = 47
pub const HWU159_SHIFT: usize = 47
Bit shift (i.e., the low bit) of hwu159.
Sourcepub const HWU062_MASK: u64
pub const HWU062_MASK: u64
Unshifted bitmask of hwu062.
Sourcepub const HWU062_SHIFT: usize = 46
pub const HWU062_SHIFT: usize = 46
Bit shift (i.e., the low bit) of hwu062.
Sourcepub const HWU061_MASK: u64
pub const HWU061_MASK: u64
Unshifted bitmask of hwu061.
Sourcepub const HWU061_SHIFT: usize = 45
pub const HWU061_SHIFT: usize = 45
Bit shift (i.e., the low bit) of hwu061.
Sourcepub const HWU060_MASK: u64
pub const HWU060_MASK: u64
Unshifted bitmask of hwu060.
Sourcepub const HWU060_SHIFT: usize = 44
pub const HWU060_SHIFT: usize = 44
Bit shift (i.e., the low bit) of hwu060.
Sourcepub const HWU059_MASK: u64
pub const HWU059_MASK: u64
Unshifted bitmask of hwu059.
Sourcepub const HWU059_SHIFT: usize = 43
pub const HWU059_SHIFT: usize = 43
Bit shift (i.e., the low bit) of hwu059.
Sourcepub const HPD1_SHIFT: usize = 42
pub const HPD1_SHIFT: usize = 42
Bit shift (i.e., the low bit) of hpd1.
Sourcepub const HPD0_SHIFT: usize = 41
pub const HPD0_SHIFT: usize = 41
Bit shift (i.e., the low bit) of hpd0.
Sourcepub const TBI1_SHIFT: usize = 38
pub const TBI1_SHIFT: usize = 38
Bit shift (i.e., the low bit) of tbi1.
Sourcepub const TBI0_SHIFT: usize = 37
pub const TBI0_SHIFT: usize = 37
Bit shift (i.e., the low bit) of tbi0.
Sourcepub const ASID_SIZE_MASK: u64
pub const ASID_SIZE_MASK: u64
Unshifted bitmask of asid_size.
Sourcepub const ASID_SIZE_SHIFT: usize = 36
pub const ASID_SIZE_SHIFT: usize = 36
Bit shift (i.e., the low bit) of asid_size.
Sourcepub const ORGN1_MASK: u64
pub const ORGN1_MASK: u64
Unshifted bitmask of orgn1.
Sourcepub const ORGN1_SHIFT: usize = 26
pub const ORGN1_SHIFT: usize = 26
Bit shift (i.e., the low bit) of orgn1.
Sourcepub const IRGN1_MASK: u64
pub const IRGN1_MASK: u64
Unshifted bitmask of irgn1.
Sourcepub const IRGN1_SHIFT: usize = 24
pub const IRGN1_SHIFT: usize = 24
Bit shift (i.e., the low bit) of irgn1.
Sourcepub const EPD1_SHIFT: usize = 23
pub const EPD1_SHIFT: usize = 23
Bit shift (i.e., the low bit) of epd1.
Sourcepub const T1SZ_SHIFT: usize = 16
pub const T1SZ_SHIFT: usize = 16
Bit shift (i.e., the low bit) of t1sz.
Sourcepub const ORGN0_MASK: u64
pub const ORGN0_MASK: u64
Unshifted bitmask of orgn0.
Sourcepub const ORGN0_SHIFT: usize = 10
pub const ORGN0_SHIFT: usize = 10
Bit shift (i.e., the low bit) of orgn0.
Sourcepub const IRGN0_MASK: u64
pub const IRGN0_MASK: u64
Unshifted bitmask of irgn0.
Sourcepub const IRGN0_SHIFT: usize = 8
pub const IRGN0_SHIFT: usize = 8
Bit shift (i.e., the low bit) of irgn0.
Sourcepub const EPD0_SHIFT: usize = 7
pub const EPD0_SHIFT: usize = 7
Bit shift (i.e., the low bit) of epd0.
Sourcepub const T0SZ_SHIFT: usize = 0
pub const T0SZ_SHIFT: usize = 0
Bit shift (i.e., the low bit) of t0sz.
Sourcepub const FIELDS: [FieldMetadata<u64>; 40]
pub const FIELDS: [FieldMetadata<u64>; 40]
Metadata of all named fields in the layout.
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub const fn set_mtx1(&mut self, value: bool) -> &mut Self
pub const fn set_mtx1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl161.
Sourcepub const fn set_mtx0(&mut self, value: bool) -> &mut Self
pub const fn set_mtx0(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl160.
Sourcepub const fn set_ds(&mut self, value: bool) -> &mut Self
pub const fn set_ds(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl159.
Sourcepub const fn set_tcma1(&mut self, value: bool) -> &mut Self
pub const fn set_tcma1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl158.
Sourcepub const fn set_tcma0(&mut self, value: bool) -> &mut Self
pub const fn set_tcma0(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl157.
Sourcepub const fn set_e0pd1(&mut self, value: bool) -> &mut Self
pub const fn set_e0pd1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl156.
Sourcepub const fn set_e0pd0(&mut self, value: bool) -> &mut Self
pub const fn set_e0pd0(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl155.
Sourcepub const fn set_nfd1(&mut self, value: bool) -> &mut Self
pub const fn set_nfd1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl154.
Sourcepub const fn set_nfd0(&mut self, value: bool) -> &mut Self
pub const fn set_nfd0(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl153.
Sourcepub const fn set_tbid1(&mut self, value: bool) -> &mut Self
pub const fn set_tbid1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl152.
Sourcepub const fn set_tbid0(&mut self, value: bool) -> &mut Self
pub const fn set_tbid0(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl151.
Sourcepub const fn set_hwu162(&mut self, value: bool) -> &mut Self
pub const fn set_hwu162(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl150.
Sourcepub const fn set_hwu161(&mut self, value: bool) -> &mut Self
pub const fn set_hwu161(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl149.
Sourcepub const fn set_hwu160(&mut self, value: bool) -> &mut Self
pub const fn set_hwu160(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl148.
Sourcepub const fn set_hwu159(&mut self, value: bool) -> &mut Self
pub const fn set_hwu159(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl147.
Sourcepub const fn set_hwu062(&mut self, value: bool) -> &mut Self
pub const fn set_hwu062(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl146.
Sourcepub const fn set_hwu061(&mut self, value: bool) -> &mut Self
pub const fn set_hwu061(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl145.
Sourcepub const fn set_hwu060(&mut self, value: bool) -> &mut Self
pub const fn set_hwu060(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl144.
Sourcepub const fn set_hwu059(&mut self, value: bool) -> &mut Self
pub const fn set_hwu059(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl143.
Sourcepub const fn set_hpd1(&mut self, value: bool) -> &mut Self
pub const fn set_hpd1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl142.
Sourcepub const fn set_hpd0(&mut self, value: bool) -> &mut Self
pub const fn set_hpd0(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl141.
Sourcepub const fn set_hd(&mut self, value: bool) -> &mut Self
pub const fn set_hd(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl140.
Sourcepub const fn set_ha(&mut self, value: bool) -> &mut Self
pub const fn set_ha(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl139.
Sourcepub const fn set_tbi1(&mut self, value: bool) -> &mut Self
pub const fn set_tbi1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl138.
Sourcepub const fn set_tbi0(&mut self, value: bool) -> &mut Self
pub const fn set_tbi0(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl137.
Sourcepub const fn set_asid_size(&mut self, value: bool) -> &mut Self
pub const fn set_asid_size(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl136.
Sourcepub fn ips(&self) -> PhysicalAddressSizewhere
PhysicalAddressSize: TryFromBytes,
pub fn ips(&self) -> PhysicalAddressSizewhere
PhysicalAddressSize: TryFromBytes,
The value of TranslationControlRegisterEl1[34:32].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_ips to recover from invalid bit patterns.
Sourcepub fn try_ips(&self) -> Result<PhysicalAddressSize, InvalidBits<u8>>where
PhysicalAddressSize: TryFromBytes,
pub fn try_ips(&self) -> Result<PhysicalAddressSize, InvalidBits<u8>>where
PhysicalAddressSize: TryFromBytes,
Fallible variant of Self::ips.
Sourcepub fn set_ips(&mut self, value: PhysicalAddressSize) -> &mut Self
pub fn set_ips(&mut self, value: PhysicalAddressSize) -> &mut Self
Sets the value of TranslationControlRegisterEl1[34:32].
Sourcepub fn tg1(&self) -> TcrTg1Valuewhere
TcrTg1Value: TryFromBytes,
pub fn tg1(&self) -> TcrTg1Valuewhere
TcrTg1Value: TryFromBytes,
The value of TranslationControlRegisterEl1[31:30].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tg1 to recover from invalid bit patterns.
Sourcepub fn try_tg1(&self) -> Result<TcrTg1Value, InvalidBits<u8>>where
TcrTg1Value: TryFromBytes,
pub fn try_tg1(&self) -> Result<TcrTg1Value, InvalidBits<u8>>where
TcrTg1Value: TryFromBytes,
Fallible variant of Self::tg1.
Sourcepub fn set_tg1(&mut self, value: TcrTg1Value) -> &mut Self
pub fn set_tg1(&mut self, value: TcrTg1Value) -> &mut Self
Sets the value of TranslationControlRegisterEl1[31:30].
Sourcepub fn sh1(&self) -> ShareabilityAttributewhere
ShareabilityAttribute: TryFromBytes,
pub fn sh1(&self) -> ShareabilityAttributewhere
ShareabilityAttribute: TryFromBytes,
The value of TranslationControlRegisterEl1[29:28].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sh1 to recover from invalid bit patterns.
Sourcepub fn try_sh1(&self) -> Result<ShareabilityAttribute, InvalidBits<u8>>where
ShareabilityAttribute: TryFromBytes,
pub fn try_sh1(&self) -> Result<ShareabilityAttribute, InvalidBits<u8>>where
ShareabilityAttribute: TryFromBytes,
Fallible variant of Self::sh1.
Sourcepub fn set_sh1(&mut self, value: ShareabilityAttribute) -> &mut Self
pub fn set_sh1(&mut self, value: ShareabilityAttribute) -> &mut Self
Sets the value of TranslationControlRegisterEl1[29:28].
Sourcepub fn orgn1(&self) -> CacheabilityAttributewhere
CacheabilityAttribute: TryFromBytes,
pub fn orgn1(&self) -> CacheabilityAttributewhere
CacheabilityAttribute: TryFromBytes,
The value of TranslationControlRegisterEl1[27:26].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_orgn1 to recover from invalid bit patterns.
Sourcepub fn try_orgn1(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>where
CacheabilityAttribute: TryFromBytes,
pub fn try_orgn1(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>where
CacheabilityAttribute: TryFromBytes,
Fallible variant of Self::orgn1.
Sourcepub fn set_orgn1(&mut self, value: CacheabilityAttribute) -> &mut Self
pub fn set_orgn1(&mut self, value: CacheabilityAttribute) -> &mut Self
Sets the value of TranslationControlRegisterEl1[27:26].
Sourcepub fn irgn1(&self) -> CacheabilityAttributewhere
CacheabilityAttribute: TryFromBytes,
pub fn irgn1(&self) -> CacheabilityAttributewhere
CacheabilityAttribute: TryFromBytes,
The value of TranslationControlRegisterEl1[25:24].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_irgn1 to recover from invalid bit patterns.
Sourcepub fn try_irgn1(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>where
CacheabilityAttribute: TryFromBytes,
pub fn try_irgn1(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>where
CacheabilityAttribute: TryFromBytes,
Fallible variant of Self::irgn1.
Sourcepub fn set_irgn1(&mut self, value: CacheabilityAttribute) -> &mut Self
pub fn set_irgn1(&mut self, value: CacheabilityAttribute) -> &mut Self
Sets the value of TranslationControlRegisterEl1[25:24].
Sourcepub const fn set_epd1(&mut self, value: bool) -> &mut Self
pub const fn set_epd1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl123.
Sourcepub const fn set_a1(&mut self, value: bool) -> &mut Self
pub const fn set_a1(&mut self, value: bool) -> &mut Self
Sets the value of TranslationControlRegisterEl122.
Sourcepub const fn set_t1sz(&mut self, value: u8) -> &mut Self
pub const fn set_t1sz(&mut self, value: u8) -> &mut Self
Sets the value of TranslationControlRegisterEl1[21:16].
Sourcepub fn tg0(&self) -> TcrTg0Valuewhere
TcrTg0Value: TryFromBytes,
pub fn tg0(&self) -> TcrTg0Valuewhere
TcrTg0Value: TryFromBytes,
The value of TranslationControlRegisterEl1[15:14].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_tg0 to recover from invalid bit patterns.
Sourcepub fn try_tg0(&self) -> Result<TcrTg0Value, InvalidBits<u8>>where
TcrTg0Value: TryFromBytes,
pub fn try_tg0(&self) -> Result<TcrTg0Value, InvalidBits<u8>>where
TcrTg0Value: TryFromBytes,
Fallible variant of Self::tg0.
Sourcepub fn set_tg0(&mut self, value: TcrTg0Value) -> &mut Self
pub fn set_tg0(&mut self, value: TcrTg0Value) -> &mut Self
Sets the value of TranslationControlRegisterEl1[15:14].
Sourcepub fn sh0(&self) -> ShareabilityAttributewhere
ShareabilityAttribute: TryFromBytes,
pub fn sh0(&self) -> ShareabilityAttributewhere
ShareabilityAttribute: TryFromBytes,
The value of TranslationControlRegisterEl1[13:12].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_sh0 to recover from invalid bit patterns.
Sourcepub fn try_sh0(&self) -> Result<ShareabilityAttribute, InvalidBits<u8>>where
ShareabilityAttribute: TryFromBytes,
pub fn try_sh0(&self) -> Result<ShareabilityAttribute, InvalidBits<u8>>where
ShareabilityAttribute: TryFromBytes,
Fallible variant of Self::sh0.
Sourcepub fn set_sh0(&mut self, value: ShareabilityAttribute) -> &mut Self
pub fn set_sh0(&mut self, value: ShareabilityAttribute) -> &mut Self
Sets the value of TranslationControlRegisterEl1[13:12].
Sourcepub fn orgn0(&self) -> CacheabilityAttributewhere
CacheabilityAttribute: TryFromBytes,
pub fn orgn0(&self) -> CacheabilityAttributewhere
CacheabilityAttribute: TryFromBytes,
The value of TranslationControlRegisterEl1[11:10].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_orgn0 to recover from invalid bit patterns.
Sourcepub fn try_orgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>where
CacheabilityAttribute: TryFromBytes,
pub fn try_orgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>where
CacheabilityAttribute: TryFromBytes,
Fallible variant of Self::orgn0.
Sourcepub fn set_orgn0(&mut self, value: CacheabilityAttribute) -> &mut Self
pub fn set_orgn0(&mut self, value: CacheabilityAttribute) -> &mut Self
Sets the value of TranslationControlRegisterEl1[11:10].
Sourcepub fn irgn0(&self) -> CacheabilityAttributewhere
CacheabilityAttribute: TryFromBytes,
pub fn irgn0(&self) -> CacheabilityAttributewhere
CacheabilityAttribute: TryFromBytes,
The value of TranslationControlRegisterEl1[9:8].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_irgn0 to recover from invalid bit patterns.
Sourcepub fn try_irgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>where
CacheabilityAttribute: TryFromBytes,
pub fn try_irgn0(&self) -> Result<CacheabilityAttribute, InvalidBits<u8>>where
CacheabilityAttribute: TryFromBytes,
Fallible variant of Self::irgn0.
Sourcepub fn set_irgn0(&mut self, value: CacheabilityAttribute) -> &mut Self
pub fn set_irgn0(&mut self, value: CacheabilityAttribute) -> &mut Self
Sets the value of TranslationControlRegisterEl1[9:8].