pub struct SupervisorAddressTranslationAndProtection(/* private fields */);Expand description
The layout of SATP.
Implementations
Sourceimpl SupervisorAddressTranslationAndProtection
impl SupervisorAddressTranslationAndProtection
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const MODE_SHIFT: usize = 60
pub const MODE_SHIFT: usize = 60
Bit shift (i.e., the low bit) of mode.
Sourcepub const ASID_SHIFT: usize = 44
pub const ASID_SHIFT: usize = 44
Bit shift (i.e., the low bit) of asid.
Sourcepub const FIELDS: [FieldMetadata<u64>; 3]
pub const FIELDS: [FieldMetadata<u64>; 3]
Metadata of all named fields in the layout.
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub fn mode(&self) -> TranslationModewhere
TranslationMode: TryFromBytes,
pub fn mode(&self) -> TranslationModewhere
TranslationMode: TryFromBytes,
The value of SupervisorAddressTranslationAndProtection[63:60].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_mode to recover from invalid bit patterns.
Sourcepub fn try_mode(&self) -> Result<TranslationMode, InvalidBits<u8>>where
TranslationMode: TryFromBytes,
pub fn try_mode(&self) -> Result<TranslationMode, InvalidBits<u8>>where
TranslationMode: TryFromBytes,
Fallible variant of Self::mode.
Sourcepub fn set_mode(&mut self, value: TranslationMode) -> &mut Self
pub fn set_mode(&mut self, value: TranslationMode) -> &mut Self
Sets the value of SupervisorAddressTranslationAndProtection[63:60].
Sourceimpl SupervisorAddressTranslationAndProtection
impl SupervisorAddressTranslationAndProtection
Sourcepub fn root_address(&self) -> u64
pub fn root_address(&self) -> u64
Returns the root page table physical address (PPN << 12).
Sourcepub fn set_root_address(&mut self, addr: u64) -> &mut Self
pub fn set_root_address(&mut self, addr: u64) -> &mut Self
Sets the root page table physical address (must be 4KiB-aligned).