pub struct SupervisorTrapVector(/* private fields */);Expand description
The layout of STVEC.
Implementations
Sourceimpl SupervisorTrapVector
impl SupervisorTrapVector
Sourcepub const RSVD1_MASK: u64
pub const RSVD1_MASK: u64
Mask of all reserved-as-1 bits.
Sourcepub const RSVD0_MASK: u64
pub const RSVD0_MASK: u64
Mask of all reserved-as-0 bits.
Sourcepub const DEFAULT: u64
pub const DEFAULT: u64
The default value of the layout, combining all field defaults and reserved-as values.
Sourcepub const BASE_SHIFT: usize = 2
pub const BASE_SHIFT: usize = 2
Bit shift (i.e., the low bit) of base.
Sourcepub const MODE_SHIFT: usize = 0
pub const MODE_SHIFT: usize = 0
Bit shift (i.e., the low bit) of mode.
Sourcepub const FIELDS: [FieldMetadata<u64>; 2]
pub const FIELDS: [FieldMetadata<u64>; 2]
Metadata of all named fields in the layout.
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance with reserved-as-1 bits set and
all other bits zeroed (i.e., with a value of
Self::RSVD1_MASK).
pub const fn bits(self) -> u64
Sourcepub const fn set_base(&mut self, value: u64) -> &mut Self
pub const fn set_base(&mut self, value: u64) -> &mut Self
Sets the unshifted value of SupervisorTrapVector[63:2].
Sourcepub fn mode(&self) -> TrapVectorModewhere
TrapVectorMode: TryFromBytes,
pub fn mode(&self) -> TrapVectorModewhere
TrapVectorMode: TryFromBytes,
The value of SupervisorTrapVector[1:0].
Panics
Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_mode to recover from invalid bit patterns.
Sourcepub fn try_mode(&self) -> Result<TrapVectorMode, InvalidBits<u8>>where
TrapVectorMode: TryFromBytes,
pub fn try_mode(&self) -> Result<TrapVectorMode, InvalidBits<u8>>where
TrapVectorMode: TryFromBytes,
Fallible variant of Self::mode.
Sourcepub fn set_mode(&mut self, value: TrapVectorMode) -> &mut Self
pub fn set_mode(&mut self, value: TrapVectorMode) -> &mut Self
Sets the value of SupervisorTrapVector[1:0].