pub enum Microarchitecture {
Show 26 variants
Unknown,
IntelCore2,
IntelNehalem,
IntelWestmere,
IntelSandyBridge,
IntelIvyBridge,
IntelHaswell,
IntelBroadwell,
IntelSkylake,
IntelSkylakeServer,
IntelCannonLake,
IntelIceLake,
IntelTigerLake,
IntelAlderLake,
IntelRaptorLake,
IntelBonnell,
IntelSaltwell,
IntelSilvermont,
IntelAirmont,
IntelGoldmont,
IntelGoldmontPlus,
IntelTremont,
AmdFamilyBulldozer,
AmdFamilyJaguar,
AmdFamilyZen,
AmdFamilyZen3,
}Expand description
The list is not exhaustive and is in chronological order within groupings. Microarchictectures that use the same processor (and, say, differ only in performance or SoC composition) are regarded as equivalent.
Variants
Unknown
IntelCore2
IntelNehalem
IntelWestmere
IntelSandyBridge
IntelIvyBridge
IntelHaswell
IntelBroadwell
IntelSkylake
Includes Kaby/Coffee/Whiskey/Amber/Comet Lake.
IntelSkylakeServer
Includes Cascade/Cooper Lake.
IntelCannonLake
A 10nm prototype only ever released on the Intel Core i3-8121U.
IntelIceLake
IntelTigerLake
IntelAlderLake
IntelRaptorLake
IntelBonnell
IntelSaltwell
IntelSilvermont
IntelAirmont
IntelGoldmont
IntelGoldmontPlus
IntelTremont
AmdFamilyBulldozer
Bulldozer/Piledriver/Steamroller/Excavator.
AmdFamilyJaguar
Jaguar.
AmdFamilyZen
Zen 1, 1+, 2.
AmdFamilyZen3
Zen 3, 4.