pub fn store_memory_barrier()Expand description
Ensure all stores that appear before this barrier (in program order) complete before any stores that appear after this barrier.
pub fn store_memory_barrier()Ensure all stores that appear before this barrier (in program order) complete before any stores that appear after this barrier.