pub struct CpuCacheLevelInfo {
pub level: usize,
pub cache_type: CacheType,
pub size_kb: usize,
pub number_of_sets: usize,
pub ways_of_associativity: usize,
pub fully_associative: Option<bool>,
pub share_id_shift: Option<usize>,
}Expand description
Represents a single cache.
Fields
level: usizecache_type: CacheTypesize_kb: usizeThe size, in KiB, of the cache available to each processor. In the case of the last-level cache, however, this field might report the aggregate size of all such caches on the package.
number_of_sets: usizeThe number of sets in the cache available to each processor. In the case of the last-level cache, however, this field might report the aggregate number of sets across all such caches in the package. Indeterminate if zero.
ways_of_associativity: usizeIndeterminate if zero.
fully_associative: Option<bool>Indeterminate if None.
The number of bits to shift an APIC ID to get the associated “share ID”: processors with coinciding share IDs share this cache. If None, then it is indeterminate what the cache’s shift is.